import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecActivationsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration to be activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#config_id AppsecActivations#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#id AppsecActivations#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Network on which to activate the configuration version (STAGING or PRODUCTION)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#network AppsecActivations#network}
    */
    readonly network?: string;
    /**
    * Note describing the activation. Will use timestamp if omitted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#note AppsecActivations#note}
    */
    readonly note?: string;
    /**
    * List of email addresses to be notified with the results of the activation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#notification_emails AppsecActivations#notification_emails}
    */
    readonly notificationEmails: string[];
    /**
    * Version of the security configuration to be activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#version AppsecActivations#version}
    */
    readonly version: number;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#timeouts AppsecActivations#timeouts}
    */
    readonly timeouts?: AppsecActivationsTimeouts;
}
export interface AppsecActivationsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#default AppsecActivations#default}
    */
    readonly default?: string;
}
export declare function appsecActivationsTimeoutsToTerraform(struct?: AppsecActivationsTimeouts | cdktf.IResolvable): any;
export declare function appsecActivationsTimeoutsToHclTerraform(struct?: AppsecActivationsTimeouts | cdktf.IResolvable): any;
export declare class AppsecActivationsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AppsecActivationsTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: AppsecActivationsTimeouts | cdktf.IResolvable | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations akamai_appsec_activations}
*/
export declare class AppsecActivations extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_activations";
    /**
    * Generates CDKTF code for importing a AppsecActivations resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecActivations to import
    * @param importFromId The id of the existing AppsecActivations that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecActivations to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_activations akamai_appsec_activations} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecActivationsConfig
    */
    constructor(scope: Construct, id: string, config: AppsecActivationsConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _note?;
    get note(): string;
    set note(value: string);
    resetNote(): void;
    get noteInput(): string | undefined;
    private _notificationEmails?;
    get notificationEmails(): string[];
    set notificationEmails(value: string[]);
    get notificationEmailsInput(): string[] | undefined;
    get status(): string;
    private _version?;
    get version(): number;
    set version(value: number);
    get versionInput(): number | undefined;
    private _timeouts;
    get timeouts(): AppsecActivationsTimeoutsOutputReference;
    putTimeouts(value: AppsecActivationsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): AppsecActivationsTimeouts | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
