import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecAdvancedSettingsPrefetchConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether to enable prefetch requests for all file extensions
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#all_extensions AppsecAdvancedSettingsPrefetch#all_extensions}
    */
    readonly allExtensions: boolean | cdktf.IResolvable;
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#config_id AppsecAdvancedSettingsPrefetch#config_id}
    */
    readonly configId: number;
    /**
    * Whether to enable or disable prefetch requests
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#enable_app_layer AppsecAdvancedSettingsPrefetch#enable_app_layer}
    */
    readonly enableAppLayer: boolean | cdktf.IResolvable;
    /**
    * Whether to enable prefetch requests for rate controls
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#enable_rate_controls AppsecAdvancedSettingsPrefetch#enable_rate_controls}
    */
    readonly enableRateControls: boolean | cdktf.IResolvable;
    /**
    * List of file extensions
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#extensions AppsecAdvancedSettingsPrefetch#extensions}
    */
    readonly extensions: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#id AppsecAdvancedSettingsPrefetch#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch akamai_appsec_advanced_settings_prefetch}
*/
export declare class AppsecAdvancedSettingsPrefetch extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_advanced_settings_prefetch";
    /**
    * Generates CDKTF code for importing a AppsecAdvancedSettingsPrefetch resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecAdvancedSettingsPrefetch to import
    * @param importFromId The id of the existing AppsecAdvancedSettingsPrefetch that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecAdvancedSettingsPrefetch to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_advanced_settings_prefetch akamai_appsec_advanced_settings_prefetch} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecAdvancedSettingsPrefetchConfig
    */
    constructor(scope: Construct, id: string, config: AppsecAdvancedSettingsPrefetchConfig);
    private _allExtensions?;
    get allExtensions(): boolean | cdktf.IResolvable;
    set allExtensions(value: boolean | cdktf.IResolvable);
    get allExtensionsInput(): boolean | cdktf.IResolvable | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _enableAppLayer?;
    get enableAppLayer(): boolean | cdktf.IResolvable;
    set enableAppLayer(value: boolean | cdktf.IResolvable);
    get enableAppLayerInput(): boolean | cdktf.IResolvable | undefined;
    private _enableRateControls?;
    get enableRateControls(): boolean | cdktf.IResolvable;
    set enableRateControls(value: boolean | cdktf.IResolvable);
    get enableRateControlsInput(): boolean | cdktf.IResolvable | undefined;
    private _extensions?;
    get extensions(): string[];
    set extensions(value: string[]);
    get extensionsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
