import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecApiConstraintsProtectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection#config_id AppsecApiConstraintsProtection#config_id}
    */
    readonly configId: number;
    /**
    * Whether to enable API constraints protection
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection#enabled AppsecApiConstraintsProtection#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection#id AppsecApiConstraintsProtection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection#security_policy_id AppsecApiConstraintsProtection#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection akamai_appsec_api_constraints_protection}
*/
export declare class AppsecApiConstraintsProtection extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_api_constraints_protection";
    /**
    * Generates CDKTF code for importing a AppsecApiConstraintsProtection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecApiConstraintsProtection to import
    * @param importFromId The id of the existing AppsecApiConstraintsProtection that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecApiConstraintsProtection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_constraints_protection akamai_appsec_api_constraints_protection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecApiConstraintsProtectionConfig
    */
    constructor(scope: Construct, id: string, config: AppsecApiConstraintsProtectionConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get outputText(): string;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
