import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecApiRequestConstraintsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Action to be taken when the API request constraint is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints#action AppsecApiRequestConstraints#action}
    */
    readonly action: string;
    /**
    * Unique identifier of the API endpoint to which the constraint will be assigned
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints#api_endpoint_id AppsecApiRequestConstraints#api_endpoint_id}
    */
    readonly apiEndpointId?: number;
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints#config_id AppsecApiRequestConstraints#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints#id AppsecApiRequestConstraints#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints#security_policy_id AppsecApiRequestConstraints#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints akamai_appsec_api_request_constraints}
*/
export declare class AppsecApiRequestConstraints extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_api_request_constraints";
    /**
    * Generates CDKTF code for importing a AppsecApiRequestConstraints resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecApiRequestConstraints to import
    * @param importFromId The id of the existing AppsecApiRequestConstraints that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecApiRequestConstraints to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_api_request_constraints akamai_appsec_api_request_constraints} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecApiRequestConstraintsConfig
    */
    constructor(scope: Construct, id: string, config: AppsecApiRequestConstraintsConfig);
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _apiEndpointId?;
    get apiEndpointId(): number;
    set apiEndpointId(value: number);
    resetApiEndpointId(): void;
    get apiEndpointIdInput(): number | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
