import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecBypassNetworkListsConfig extends cdktf.TerraformMetaArguments {
    /**
    * List of network list IDs that compose the bypass list
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists#bypass_network_list AppsecBypassNetworkLists#bypass_network_list}
    */
    readonly bypassNetworkList: string[];
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists#config_id AppsecBypassNetworkLists#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists#id AppsecBypassNetworkLists#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier of the security policy governing the bypass network lists
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists#security_policy_id AppsecBypassNetworkLists#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists akamai_appsec_bypass_network_lists}
*/
export declare class AppsecBypassNetworkLists extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_bypass_network_lists";
    /**
    * Generates CDKTF code for importing a AppsecBypassNetworkLists resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecBypassNetworkLists to import
    * @param importFromId The id of the existing AppsecBypassNetworkLists that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecBypassNetworkLists to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_bypass_network_lists akamai_appsec_bypass_network_lists} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecBypassNetworkListsConfig
    */
    constructor(scope: Construct, id: string, config: AppsecBypassNetworkListsConfig);
    private _bypassNetworkList?;
    get bypassNetworkList(): string[];
    set bypassNetworkList(value: string[]);
    get bypassNetworkListInput(): string[] | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
