import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the Akamai contract associated with the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#contract_id AppsecConfiguration#contract_id}
    */
    readonly contractId: string;
    /**
    * Unique identifier of the existing configuration being cloned to create the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#create_from_config_id AppsecConfiguration#create_from_config_id}
    */
    readonly createFromConfigId?: number;
    /**
    * Version number of the existing configuration being cloned to create the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#create_from_version AppsecConfiguration#create_from_version}
    */
    readonly createFromVersion?: number;
    /**
    * Brief description of the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#description AppsecConfiguration#description}
    */
    readonly description: string;
    /**
    * Unique identifier of the contract group associated with the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#group_id AppsecConfiguration#group_id}
    */
    readonly groupId: number;
    /**
    * Hostnames to be protected by the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#host_names AppsecConfiguration#host_names}
    */
    readonly hostNames: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#id AppsecConfiguration#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the new configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#name AppsecConfiguration#name}
    */
    readonly name: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration akamai_appsec_configuration}
*/
export declare class AppsecConfiguration extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_configuration";
    /**
    * Generates CDKTF code for importing a AppsecConfiguration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecConfiguration to import
    * @param importFromId The id of the existing AppsecConfiguration that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecConfiguration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_configuration akamai_appsec_configuration} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecConfigurationConfig
    */
    constructor(scope: Construct, id: string, config: AppsecConfigurationConfig);
    get configId(): number;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _createFromConfigId?;
    get createFromConfigId(): number;
    set createFromConfigId(value: number);
    resetCreateFromConfigId(): void;
    get createFromConfigIdInput(): number | undefined;
    private _createFromVersion?;
    get createFromVersion(): number;
    set createFromVersion(value: number);
    resetCreateFromVersion(): void;
    get createFromVersionInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _groupId?;
    get groupId(): number;
    set groupId(value: number);
    get groupIdInput(): number | undefined;
    private _hostNames?;
    get hostNames(): string[];
    set hostNames(value: string[]);
    get hostNamesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
