import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecCustomRuleActionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action#config_id AppsecCustomRuleAction#config_id}
    */
    readonly configId: number;
    /**
    * Action to be taken when the custom rule is invoked
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action#custom_rule_action AppsecCustomRuleAction#custom_rule_action}
    */
    readonly customRuleAction: string;
    /**
    * Unique identifier of the custom rule whose action is being modified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action#custom_rule_id AppsecCustomRuleAction#custom_rule_id}
    */
    readonly customRuleId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action#id AppsecCustomRuleAction#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action#security_policy_id AppsecCustomRuleAction#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action akamai_appsec_custom_rule_action}
*/
export declare class AppsecCustomRuleAction extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_custom_rule_action";
    /**
    * Generates CDKTF code for importing a AppsecCustomRuleAction resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecCustomRuleAction to import
    * @param importFromId The id of the existing AppsecCustomRuleAction that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecCustomRuleAction to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_custom_rule_action akamai_appsec_custom_rule_action} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecCustomRuleActionConfig
    */
    constructor(scope: Construct, id: string, config: AppsecCustomRuleActionConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _customRuleAction?;
    get customRuleAction(): string;
    set customRuleAction(value: string);
    get customRuleActionInput(): string | undefined;
    private _customRuleId?;
    get customRuleId(): number;
    set customRuleId(value: number);
    get customRuleIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
