import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecEvalGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the evaluation attack group being modified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#attack_group AppsecEvalGroup#attack_group}
    */
    readonly attackGroup: string;
    /**
    * Action to be taken when the attack group is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#attack_group_action AppsecEvalGroup#attack_group_action}
    */
    readonly attackGroupAction: string;
    /**
    * JSON-formatted condition and exception information for the evaluation attack group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#condition_exception AppsecEvalGroup#condition_exception}
    */
    readonly conditionException?: string;
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#config_id AppsecEvalGroup#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#id AppsecEvalGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#security_policy_id AppsecEvalGroup#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group akamai_appsec_eval_group}
*/
export declare class AppsecEvalGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_eval_group";
    /**
    * Generates CDKTF code for importing a AppsecEvalGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecEvalGroup to import
    * @param importFromId The id of the existing AppsecEvalGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecEvalGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval_group akamai_appsec_eval_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecEvalGroupConfig
    */
    constructor(scope: Construct, id: string, config: AppsecEvalGroupConfig);
    private _attackGroup?;
    get attackGroup(): string;
    set attackGroup(value: string);
    get attackGroupInput(): string | undefined;
    private _attackGroupAction?;
    get attackGroupAction(): string;
    set attackGroupAction(value: string);
    get attackGroupActionInput(): string | undefined;
    private _conditionException?;
    get conditionException(): string;
    set conditionException(value: string);
    resetConditionException(): void;
    get conditionExceptionInput(): string | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
