import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecEvalConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval#config_id AppsecEval#config_id}
    */
    readonly configId: number;
    /**
    * Evaluation mode (ASE_AUTO or ASE_MANUAL)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval#eval_mode AppsecEval#eval_mode}
    */
    readonly evalMode?: string;
    /**
    * Evaluation mode operation (START, STOP, RESTART, UPDATE or COMPLETE)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval#eval_operation AppsecEval#eval_operation}
    */
    readonly evalOperation: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval#id AppsecEval#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval#security_policy_id AppsecEval#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval akamai_appsec_eval}
*/
export declare class AppsecEval extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_eval";
    /**
    * Generates CDKTF code for importing a AppsecEval resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecEval to import
    * @param importFromId The id of the existing AppsecEval that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecEval to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_eval akamai_appsec_eval} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecEvalConfig
    */
    constructor(scope: Construct, id: string, config: AppsecEvalConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    get currentRuleset(): string;
    private _evalMode?;
    get evalMode(): string;
    set evalMode(value: string);
    resetEvalMode(): void;
    get evalModeInput(): string | undefined;
    private _evalOperation?;
    get evalOperation(): string;
    set evalOperation(value: string);
    get evalOperationInput(): string | undefined;
    get evalStatus(): string;
    get evaluatingRuleset(): string;
    get expirationDate(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
