import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecIpGeoConfig extends cdktf.TerraformMetaArguments {
    /**
    * List of IDs of ASN network list to be blocked
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#asn_network_lists AppsecIpGeo#asn_network_lists}
    */
    readonly asnNetworkLists?: string[];
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#config_id AppsecIpGeo#config_id}
    */
    readonly configId: number;
    /**
    * List of IDs of network list that are always allowed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#exception_ip_network_lists AppsecIpGeo#exception_ip_network_lists}
    */
    readonly exceptionIpNetworkLists?: string[];
    /**
    * List of IDs of geographic network list to be blocked
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#geo_network_lists AppsecIpGeo#geo_network_lists}
    */
    readonly geoNetworkLists?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#id AppsecIpGeo#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of IDs of IP network list to be blocked
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#ip_network_lists AppsecIpGeo#ip_network_lists}
    */
    readonly ipNetworkLists?: string[];
    /**
    * Protection mode (block or allow)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#mode AppsecIpGeo#mode}
    */
    readonly mode: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#security_policy_id AppsecIpGeo#security_policy_id}
    */
    readonly securityPolicyId: string;
    /**
    * Action set for Ukraine geo control
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#ukraine_geo_control_action AppsecIpGeo#ukraine_geo_control_action}
    */
    readonly ukraineGeoControlAction?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo akamai_appsec_ip_geo}
*/
export declare class AppsecIpGeo extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_ip_geo";
    /**
    * Generates CDKTF code for importing a AppsecIpGeo resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecIpGeo to import
    * @param importFromId The id of the existing AppsecIpGeo that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecIpGeo to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_ip_geo akamai_appsec_ip_geo} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecIpGeoConfig
    */
    constructor(scope: Construct, id: string, config: AppsecIpGeoConfig);
    private _asnNetworkLists?;
    get asnNetworkLists(): string[];
    set asnNetworkLists(value: string[]);
    resetAsnNetworkLists(): void;
    get asnNetworkListsInput(): string[] | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _exceptionIpNetworkLists?;
    get exceptionIpNetworkLists(): string[];
    set exceptionIpNetworkLists(value: string[]);
    resetExceptionIpNetworkLists(): void;
    get exceptionIpNetworkListsInput(): string[] | undefined;
    private _geoNetworkLists?;
    get geoNetworkLists(): string[];
    set geoNetworkLists(value: string[]);
    resetGeoNetworkLists(): void;
    get geoNetworkListsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipNetworkLists?;
    get ipNetworkLists(): string[];
    set ipNetworkLists(value: string[]);
    resetIpNetworkLists(): void;
    get ipNetworkListsInput(): string[] | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    private _ukraineGeoControlAction?;
    get ukraineGeoControlAction(): string;
    set ukraineGeoControlAction(value: string);
    resetUkraineGeoControlAction(): void;
    get ukraineGeoControlActionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
