import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecPenaltyBoxConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box#config_id AppsecPenaltyBox#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box#id AppsecPenaltyBox#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The action to be taken when the penalty box is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box#penalty_box_action AppsecPenaltyBox#penalty_box_action}
    */
    readonly penaltyBoxAction: string;
    /**
    * Whether to enable the penalty box for the specified security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box#penalty_box_protection AppsecPenaltyBox#penalty_box_protection}
    */
    readonly penaltyBoxProtection: boolean | cdktf.IResolvable;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box#security_policy_id AppsecPenaltyBox#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box akamai_appsec_penalty_box}
*/
export declare class AppsecPenaltyBox extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_penalty_box";
    /**
    * Generates CDKTF code for importing a AppsecPenaltyBox resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecPenaltyBox to import
    * @param importFromId The id of the existing AppsecPenaltyBox that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecPenaltyBox to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_penalty_box akamai_appsec_penalty_box} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecPenaltyBoxConfig
    */
    constructor(scope: Construct, id: string, config: AppsecPenaltyBoxConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _penaltyBoxAction?;
    get penaltyBoxAction(): string;
    set penaltyBoxAction(value: string);
    get penaltyBoxActionInput(): string | undefined;
    private _penaltyBoxProtection?;
    get penaltyBoxProtection(): boolean | cdktf.IResolvable;
    set penaltyBoxProtection(value: boolean | cdktf.IResolvable);
    get penaltyBoxProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
