import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecRatePolicyActionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#config_id AppsecRatePolicyAction#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#id AppsecRatePolicyAction#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Action to be taken for requests coming from an IPv4 address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#ipv4_action AppsecRatePolicyAction#ipv4_action}
    */
    readonly ipv4Action: string;
    /**
    * Action to be taken for requests coming from an IPv6 address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#ipv6_action AppsecRatePolicyAction#ipv6_action}
    */
    readonly ipv6Action: string;
    /**
    * Unique identifier of the rate policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#rate_policy_id AppsecRatePolicyAction#rate_policy_id}
    */
    readonly ratePolicyId: number;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#security_policy_id AppsecRatePolicyAction#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action akamai_appsec_rate_policy_action}
*/
export declare class AppsecRatePolicyAction extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_rate_policy_action";
    /**
    * Generates CDKTF code for importing a AppsecRatePolicyAction resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecRatePolicyAction to import
    * @param importFromId The id of the existing AppsecRatePolicyAction that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecRatePolicyAction to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rate_policy_action akamai_appsec_rate_policy_action} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecRatePolicyActionConfig
    */
    constructor(scope: Construct, id: string, config: AppsecRatePolicyActionConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipv4Action?;
    get ipv4Action(): string;
    set ipv4Action(value: string);
    get ipv4ActionInput(): string | undefined;
    private _ipv6Action?;
    get ipv6Action(): string;
    set ipv6Action(value: string);
    get ipv6ActionInput(): string | undefined;
    private _ratePolicyId?;
    get ratePolicyId(): number;
    set ratePolicyId(value: number);
    get ratePolicyIdInput(): number | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
