import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecReputationProfileActionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Action to be taken when the reputation profile is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action#action AppsecReputationProfileAction#action}
    */
    readonly action: string;
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action#config_id AppsecReputationProfileAction#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action#id AppsecReputationProfileAction#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the reputation profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action#reputation_profile_id AppsecReputationProfileAction#reputation_profile_id}
    */
    readonly reputationProfileId: number;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action#security_policy_id AppsecReputationProfileAction#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action akamai_appsec_reputation_profile_action}
*/
export declare class AppsecReputationProfileAction extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_reputation_profile_action";
    /**
    * Generates CDKTF code for importing a AppsecReputationProfileAction resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecReputationProfileAction to import
    * @param importFromId The id of the existing AppsecReputationProfileAction that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecReputationProfileAction to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_action akamai_appsec_reputation_profile_action} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecReputationProfileActionConfig
    */
    constructor(scope: Construct, id: string, config: AppsecReputationProfileActionConfig);
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _reputationProfileId?;
    get reputationProfileId(): number;
    set reputationProfileId(value: number);
    get reputationProfileIdInput(): number | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
