import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecReputationProfileAnalysisConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis#config_id AppsecReputationProfileAnalysis#config_id}
    */
    readonly configId: number;
    /**
    * Whether to add a value indicating that shared IPs are included in HTTP header and SIEM integration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis#forward_shared_ip_to_http_header_siem AppsecReputationProfileAnalysis#forward_shared_ip_to_http_header_siem}
    */
    readonly forwardSharedIpToHttpHeaderSiem: boolean | cdktf.IResolvable;
    /**
    * Whether to add client reputation details to requests forwarded to the origin server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis#forward_to_http_header AppsecReputationProfileAnalysis#forward_to_http_header}
    */
    readonly forwardToHttpHeader: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis#id AppsecReputationProfileAnalysis#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis#security_policy_id AppsecReputationProfileAnalysis#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis akamai_appsec_reputation_profile_analysis}
*/
export declare class AppsecReputationProfileAnalysis extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_reputation_profile_analysis";
    /**
    * Generates CDKTF code for importing a AppsecReputationProfileAnalysis resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecReputationProfileAnalysis to import
    * @param importFromId The id of the existing AppsecReputationProfileAnalysis that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecReputationProfileAnalysis to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_reputation_profile_analysis akamai_appsec_reputation_profile_analysis} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecReputationProfileAnalysisConfig
    */
    constructor(scope: Construct, id: string, config: AppsecReputationProfileAnalysisConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _forwardSharedIpToHttpHeaderSiem?;
    get forwardSharedIpToHttpHeaderSiem(): boolean | cdktf.IResolvable;
    set forwardSharedIpToHttpHeaderSiem(value: boolean | cdktf.IResolvable);
    get forwardSharedIpToHttpHeaderSiemInput(): boolean | cdktf.IResolvable | undefined;
    private _forwardToHttpHeader?;
    get forwardToHttpHeader(): boolean | cdktf.IResolvable;
    set forwardToHttpHeader(value: boolean | cdktf.IResolvable);
    get forwardToHttpHeaderInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
