import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecRuleUpgradeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade#config_id AppsecRuleUpgrade#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade#id AppsecRuleUpgrade#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade#security_policy_id AppsecRuleUpgrade#security_policy_id}
    */
    readonly securityPolicyId: string;
    /**
    * Modifies the upgrade type for organizations running the ASE beta (ASE_AUTO or ASE_MANUAL)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade#upgrade_mode AppsecRuleUpgrade#upgrade_mode}
    */
    readonly upgradeMode?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade akamai_appsec_rule_upgrade}
*/
export declare class AppsecRuleUpgrade extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_rule_upgrade";
    /**
    * Generates CDKTF code for importing a AppsecRuleUpgrade resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecRuleUpgrade to import
    * @param importFromId The id of the existing AppsecRuleUpgrade that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecRuleUpgrade to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule_upgrade akamai_appsec_rule_upgrade} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecRuleUpgradeConfig
    */
    constructor(scope: Construct, id: string, config: AppsecRuleUpgradeConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    get currentRuleset(): string;
    get evalStatus(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get mode(): string;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    private _upgradeMode?;
    get upgradeMode(): string;
    set upgradeMode(value: string);
    resetUpgradeMode(): void;
    get upgradeModeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
