import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * JSON-formatted condition and exception information for the rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#condition_exception AppsecRule#condition_exception}
    */
    readonly conditionException?: string;
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#config_id AppsecRule#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#id AppsecRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Action to be taken when the rule is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#rule_action AppsecRule#rule_action}
    */
    readonly ruleAction?: string;
    /**
    * Unique identifier of the rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#rule_id AppsecRule#rule_id}
    */
    readonly ruleId: number;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#security_policy_id AppsecRule#security_policy_id}
    */
    readonly securityPolicyId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule akamai_appsec_rule}
*/
export declare class AppsecRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_rule";
    /**
    * Generates CDKTF code for importing a AppsecRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecRule to import
    * @param importFromId The id of the existing AppsecRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_rule akamai_appsec_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecRuleConfig
    */
    constructor(scope: Construct, id: string, config: AppsecRuleConfig);
    private _conditionException?;
    get conditionException(): string;
    set conditionException(value: string);
    resetConditionException(): void;
    get conditionExceptionInput(): string | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ruleAction?;
    get ruleAction(): string;
    set ruleAction(value: string);
    resetRuleAction(): void;
    get ruleActionInput(): string | undefined;
    private _ruleId?;
    get ruleId(): number;
    set ruleId(value: number);
    get ruleIdInput(): number | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
