import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecSecurityPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#config_id AppsecSecurityPolicy#config_id}
    */
    readonly configId: number;
    /**
    * Unique identifier of the existing security policy being cloned
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#create_from_security_policy_id AppsecSecurityPolicy#create_from_security_policy_id}
    */
    readonly createFromSecurityPolicyId?: string;
    /**
    * Whether to assign default settings to the new security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#default_settings AppsecSecurityPolicy#default_settings}
    */
    readonly defaultSettings?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#id AppsecSecurityPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the new security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#security_policy_name AppsecSecurityPolicy#security_policy_name}
    */
    readonly securityPolicyName: string;
    /**
    * Four-character alphanumeric string prefix used in creating the security policy ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#security_policy_prefix AppsecSecurityPolicy#security_policy_prefix}
    */
    readonly securityPolicyPrefix: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy akamai_appsec_security_policy}
*/
export declare class AppsecSecurityPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_security_policy";
    /**
    * Generates CDKTF code for importing a AppsecSecurityPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecSecurityPolicy to import
    * @param importFromId The id of the existing AppsecSecurityPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecSecurityPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_security_policy akamai_appsec_security_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecSecurityPolicyConfig
    */
    constructor(scope: Construct, id: string, config: AppsecSecurityPolicyConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _createFromSecurityPolicyId?;
    get createFromSecurityPolicyId(): string;
    set createFromSecurityPolicyId(value: string);
    resetCreateFromSecurityPolicyId(): void;
    get createFromSecurityPolicyIdInput(): string | undefined;
    private _defaultSettings?;
    get defaultSettings(): boolean | cdktf.IResolvable;
    set defaultSettings(value: boolean | cdktf.IResolvable);
    resetDefaultSettings(): void;
    get defaultSettingsInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get securityPolicyId(): string;
    private _securityPolicyName?;
    get securityPolicyName(): string;
    set securityPolicyName(value: string);
    get securityPolicyNameInput(): string | undefined;
    private _securityPolicyPrefix?;
    get securityPolicyPrefix(): string;
    set securityPolicyPrefix(value: string);
    get securityPolicyPrefixInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
