import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecSiemSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#config_id AppsecSiemSettings#config_id}
    */
    readonly configId: number;
    /**
    * Whether Bot Manager events should be included in SIEM events
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#enable_botman_siem AppsecSiemSettings#enable_botman_siem}
    */
    readonly enableBotmanSiem: boolean | cdktf.IResolvable;
    /**
    * Whether to enable SIEM on all security policies in the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#enable_for_all_policies AppsecSiemSettings#enable_for_all_policies}
    */
    readonly enableForAllPolicies: boolean | cdktf.IResolvable;
    /**
    * Whether to enable SIEM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#enable_siem AppsecSiemSettings#enable_siem}
    */
    readonly enableSiem: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#id AppsecSiemSettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of IDs of security policy for which SIEM integration is to be enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#security_policy_ids AppsecSiemSettings#security_policy_ids}
    */
    readonly securityPolicyIds?: string[];
    /**
    * Unique identifier of the SIEM settings being modified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#siem_id AppsecSiemSettings#siem_id}
    */
    readonly siemId: number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings akamai_appsec_siem_settings}
*/
export declare class AppsecSiemSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_siem_settings";
    /**
    * Generates CDKTF code for importing a AppsecSiemSettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecSiemSettings to import
    * @param importFromId The id of the existing AppsecSiemSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecSiemSettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_siem_settings akamai_appsec_siem_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecSiemSettingsConfig
    */
    constructor(scope: Construct, id: string, config: AppsecSiemSettingsConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _enableBotmanSiem?;
    get enableBotmanSiem(): boolean | cdktf.IResolvable;
    set enableBotmanSiem(value: boolean | cdktf.IResolvable);
    get enableBotmanSiemInput(): boolean | cdktf.IResolvable | undefined;
    private _enableForAllPolicies?;
    get enableForAllPolicies(): boolean | cdktf.IResolvable;
    set enableForAllPolicies(value: boolean | cdktf.IResolvable);
    get enableForAllPoliciesInput(): boolean | cdktf.IResolvable | undefined;
    private _enableSiem?;
    get enableSiem(): boolean | cdktf.IResolvable;
    set enableSiem(value: boolean | cdktf.IResolvable);
    get enableSiemInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyIds?;
    get securityPolicyIds(): string[];
    set securityPolicyIds(value: string[]);
    resetSecurityPolicyIds(): void;
    get securityPolicyIdsInput(): string[] | undefined;
    private _siemId?;
    get siemId(): number;
    set siemId(value: number);
    get siemIdInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
