import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecSlowPostConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#config_id AppsecSlowPost#config_id}
    */
    readonly configId: number;
    /**
    * Maximum amount of time (in seconds) within which the first 8KB of the POST body must be received to avoid triggering the specified action
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#duration_threshold_timeout AppsecSlowPost#duration_threshold_timeout}
    */
    readonly durationThresholdTimeout?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#id AppsecSlowPost#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#security_policy_id AppsecSlowPost#security_policy_id}
    */
    readonly securityPolicyId: string;
    /**
    * Action to be taken when slow POST protection is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#slow_rate_action AppsecSlowPost#slow_rate_action}
    */
    readonly slowRateAction: string;
    /**
    * Amount of time (in seconds) that the server should allow a request before marking the request as being too slow
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#slow_rate_threshold_period AppsecSlowPost#slow_rate_threshold_period}
    */
    readonly slowRateThresholdPeriod?: number;
    /**
    * Average rate (in bytes per second over the specified time period) allowed before the specified action is triggered
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#slow_rate_threshold_rate AppsecSlowPost#slow_rate_threshold_rate}
    */
    readonly slowRateThresholdRate?: number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post akamai_appsec_slow_post}
*/
export declare class AppsecSlowPost extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_slow_post";
    /**
    * Generates CDKTF code for importing a AppsecSlowPost resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecSlowPost to import
    * @param importFromId The id of the existing AppsecSlowPost that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecSlowPost to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_slow_post akamai_appsec_slow_post} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecSlowPostConfig
    */
    constructor(scope: Construct, id: string, config: AppsecSlowPostConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _durationThresholdTimeout?;
    get durationThresholdTimeout(): number;
    set durationThresholdTimeout(value: number);
    resetDurationThresholdTimeout(): void;
    get durationThresholdTimeoutInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    private _slowRateAction?;
    get slowRateAction(): string;
    set slowRateAction(value: string);
    get slowRateActionInput(): string | undefined;
    private _slowRateThresholdPeriod?;
    get slowRateThresholdPeriod(): number;
    set slowRateThresholdPeriod(value: number);
    resetSlowRateThresholdPeriod(): void;
    get slowRateThresholdPeriodInput(): number | undefined;
    private _slowRateThresholdRate?;
    get slowRateThresholdRate(): number;
    set slowRateThresholdRate(value: number);
    resetSlowRateThresholdRate(): void;
    get slowRateThresholdRateInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
