import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ClientlistListConfig extends cdktf.TerraformMetaArguments {
    /**
    * Contract ID for which client list is assigned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#contract_id ClientlistList#contract_id}
    */
    readonly contractId: string;
    /**
    * Group ID for which client list is assigned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#group_id ClientlistList#group_id}
    */
    readonly groupId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#id ClientlistList#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the client list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#name ClientlistList#name}
    */
    readonly name: string;
    /**
    * The client list notes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#notes ClientlistList#notes}
    */
    readonly notes?: string;
    /**
    * The client list tags.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#tags ClientlistList#tags}
    */
    readonly tags?: string[];
    /**
    * The type of the client list. Valid types: [IP GEO ASN TLS_FINGERPRINT FILE_HASH]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#type ClientlistList#type}
    */
    readonly type: string;
    /**
    * items block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#items ClientlistList#items}
    */
    readonly items?: ClientlistListItems[] | cdktf.IResolvable;
}
export interface ClientlistListItems {
    /**
    * A description of the item.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#description ClientlistList#description}
    */
    readonly description?: string;
    /**
    * The item expiration date.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#expiration_date ClientlistList#expiration_date}
    */
    readonly expirationDate?: string;
    /**
    * The item tags.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#tags ClientlistList#tags}
    */
    readonly tags?: string[];
    /**
    * Value of the item. (i.e. IP address, AS Number, GEO, ...etc)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#value ClientlistList#value}
    */
    readonly value: string;
}
export declare function clientlistListItemsToTerraform(struct?: ClientlistListItems | cdktf.IResolvable): any;
export declare function clientlistListItemsToHclTerraform(struct?: ClientlistListItems | cdktf.IResolvable): any;
export declare class ClientlistListItemsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ClientlistListItems | cdktf.IResolvable | undefined;
    set internalValue(value: ClientlistListItems | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expirationDate?;
    get expirationDate(): string;
    set expirationDate(value: string);
    resetExpirationDate(): void;
    get expirationDateInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ClientlistListItemsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ClientlistListItems[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ClientlistListItemsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list akamai_clientlist_list}
*/
export declare class ClientlistList extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_clientlist_list";
    /**
    * Generates CDKTF code for importing a ClientlistList resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ClientlistList to import
    * @param importFromId The id of the existing ClientlistList that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ClientlistList to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/clientlist_list akamai_clientlist_list} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ClientlistListConfig
    */
    constructor(scope: Construct, id: string, config: ClientlistListConfig);
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _groupId?;
    get groupId(): number;
    set groupId(value: number);
    get groupIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get itemsCount(): number;
    get listId(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _notes?;
    get notes(): string;
    set notes(value: string);
    resetNotes(): void;
    get notesInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    get version(): number;
    private _items;
    get items(): ClientlistListItemsList;
    putItems(value: ClientlistListItems[] | cdktf.IResolvable): void;
    resetItems(): void;
    get itemsInput(): cdktf.IResolvable | ClientlistListItems[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
