import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudletsApplicationLoadBalancerConfig extends cdktf.TerraformMetaArguments {
    /**
    * The type of load balancing being performed. Options include WEIGHTED and PERFORMANCE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#balancing_type CloudletsApplicationLoadBalancer#balancing_type}
    */
    readonly balancingType?: string;
    /**
    * The load balancer configuration version description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#description CloudletsApplicationLoadBalancer#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#id CloudletsApplicationLoadBalancer#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The load balancer configuration description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#origin_description CloudletsApplicationLoadBalancer#origin_description}
    */
    readonly originDescription?: string;
    /**
    * The conditional origin's unique identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#origin_id CloudletsApplicationLoadBalancer#origin_id}
    */
    readonly originId: string;
    /**
    * data_centers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#data_centers CloudletsApplicationLoadBalancer#data_centers}
    */
    readonly dataCenters: CloudletsApplicationLoadBalancerDataCenters[] | cdktf.IResolvable;
    /**
    * liveness_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#liveness_settings CloudletsApplicationLoadBalancer#liveness_settings}
    */
    readonly livenessSettings?: CloudletsApplicationLoadBalancerLivenessSettings;
}
export interface CloudletsApplicationLoadBalancerDataCenters {
    /**
    * The city in which the data center is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#city CloudletsApplicationLoadBalancer#city}
    */
    readonly city?: string;
    /**
    * Describes if cloud server host header is overridden
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#cloud_server_host_header_override CloudletsApplicationLoadBalancer#cloud_server_host_header_override}
    */
    readonly cloudServerHostHeaderOverride?: boolean | cdktf.IResolvable;
    /**
    * Describes if this datacenter is a cloud service
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#cloud_service CloudletsApplicationLoadBalancer#cloud_service}
    */
    readonly cloudService?: boolean | cdktf.IResolvable;
    /**
    * The continent on which the data center is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#continent CloudletsApplicationLoadBalancer#continent}
    */
    readonly continent: string;
    /**
    * The country in which the data center is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#country CloudletsApplicationLoadBalancer#country}
    */
    readonly country: string;
    /**
    * This should match the 'hostname' value defined for this datacenter in Property Manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#hostname CloudletsApplicationLoadBalancer#hostname}
    */
    readonly hostname?: string;
    /**
    * The latitude value for the data center. This member supports six decimal places of precision.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#latitude CloudletsApplicationLoadBalancer#latitude}
    */
    readonly latitude: number;
    /**
    * An array of strings that represent the origin servers used to poll the data centers in an application load balancer configuration. These servers support basic HTTP polling.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#liveness_hosts CloudletsApplicationLoadBalancer#liveness_hosts}
    */
    readonly livenessHosts?: string[];
    /**
    * The longitude value for the data center. This member supports six decimal places of precision.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#longitude CloudletsApplicationLoadBalancer#longitude}
    */
    readonly longitude: number;
    /**
    * The ID of an origin that represents the data center. The conditional origin, which is defined in the Property Manager API, must have an originType of either CUSTOMER or NET_STORAGE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#origin_id CloudletsApplicationLoadBalancer#origin_id}
    */
    readonly originId: string;
    /**
    * The percent of traffic that is sent to the data center. The total for all data centers must equal 100%.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#percent CloudletsApplicationLoadBalancer#percent}
    */
    readonly percent: number;
    /**
    * The state, province, or region where the data center is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#state_or_province CloudletsApplicationLoadBalancer#state_or_province}
    */
    readonly stateOrProvince?: string;
}
export declare function cloudletsApplicationLoadBalancerDataCentersToTerraform(struct?: CloudletsApplicationLoadBalancerDataCenters | cdktf.IResolvable): any;
export declare function cloudletsApplicationLoadBalancerDataCentersToHclTerraform(struct?: CloudletsApplicationLoadBalancerDataCenters | cdktf.IResolvable): any;
export declare class CloudletsApplicationLoadBalancerDataCentersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudletsApplicationLoadBalancerDataCenters | cdktf.IResolvable | undefined;
    set internalValue(value: CloudletsApplicationLoadBalancerDataCenters | cdktf.IResolvable | undefined);
    private _city?;
    get city(): string;
    set city(value: string);
    resetCity(): void;
    get cityInput(): string | undefined;
    private _cloudServerHostHeaderOverride?;
    get cloudServerHostHeaderOverride(): boolean | cdktf.IResolvable;
    set cloudServerHostHeaderOverride(value: boolean | cdktf.IResolvable);
    resetCloudServerHostHeaderOverride(): void;
    get cloudServerHostHeaderOverrideInput(): boolean | cdktf.IResolvable | undefined;
    private _cloudService?;
    get cloudService(): boolean | cdktf.IResolvable;
    set cloudService(value: boolean | cdktf.IResolvable);
    resetCloudService(): void;
    get cloudServiceInput(): boolean | cdktf.IResolvable | undefined;
    private _continent?;
    get continent(): string;
    set continent(value: string);
    get continentInput(): string | undefined;
    private _country?;
    get country(): string;
    set country(value: string);
    get countryInput(): string | undefined;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    resetHostname(): void;
    get hostnameInput(): string | undefined;
    private _latitude?;
    get latitude(): number;
    set latitude(value: number);
    get latitudeInput(): number | undefined;
    private _livenessHosts?;
    get livenessHosts(): string[];
    set livenessHosts(value: string[]);
    resetLivenessHosts(): void;
    get livenessHostsInput(): string[] | undefined;
    private _longitude?;
    get longitude(): number;
    set longitude(value: number);
    get longitudeInput(): number | undefined;
    private _originId?;
    get originId(): string;
    set originId(value: string);
    get originIdInput(): string | undefined;
    private _percent?;
    get percent(): number;
    set percent(value: number);
    get percentInput(): number | undefined;
    private _stateOrProvince?;
    get stateOrProvince(): string;
    set stateOrProvince(value: string);
    resetStateOrProvince(): void;
    get stateOrProvinceInput(): string | undefined;
}
export declare class CloudletsApplicationLoadBalancerDataCentersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CloudletsApplicationLoadBalancerDataCenters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudletsApplicationLoadBalancerDataCentersOutputReference;
}
export interface CloudletsApplicationLoadBalancerLivenessSettings {
    /**
    * Maps additional case-insensitive HTTP header names included to the liveness testing requests
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#additional_headers CloudletsApplicationLoadBalancer#additional_headers}
    */
    readonly additionalHeaders?: {
        [key: string]: string;
    };
    /**
    * The Host header for the liveness HTTP request
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#host_header CloudletsApplicationLoadBalancer#host_header}
    */
    readonly hostHeader?: string;
    /**
    * Describes how often the liveness test will be performed. Optional defaults to 60 seconds, minimum is 10 seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#interval CloudletsApplicationLoadBalancer#interval}
    */
    readonly interval?: number;
    /**
    * The path to the test object used for liveness testing. The function of the test object is to help determine whether the data center is functioning.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#path CloudletsApplicationLoadBalancer#path}
    */
    readonly path: string;
    /**
    * Describes whether or not to validate the origin certificate for an HTTPS request
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#peer_certificate_verification CloudletsApplicationLoadBalancer#peer_certificate_verification}
    */
    readonly peerCertificateVerification?: boolean | cdktf.IResolvable;
    /**
    * The port for the test object. The default port is 80, which is standard for HTTP. Enter 443 if you are using HTTPS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#port CloudletsApplicationLoadBalancer#port}
    */
    readonly port: number;
    /**
    * The protocol or scheme for the database, either HTTP or HTTPS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#protocol CloudletsApplicationLoadBalancer#protocol}
    */
    readonly protocol: string;
    /**
    * The request which will be used for TCP(S) tests
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#request_string CloudletsApplicationLoadBalancer#request_string}
    */
    readonly requestString?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#response_string CloudletsApplicationLoadBalancer#response_string}
    */
    readonly responseString?: string;
    /**
    * Set to true to mark the liveness test as failed when the request returns a 3xx (redirection) status code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#status_3xx_failure CloudletsApplicationLoadBalancer#status_3xx_failure}
    */
    readonly status3XxFailure?: boolean | cdktf.IResolvable;
    /**
    * Set to true to mark the liveness test as failed when the request returns a 4xx (client error) status code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#status_4xx_failure CloudletsApplicationLoadBalancer#status_4xx_failure}
    */
    readonly status4XxFailure?: boolean | cdktf.IResolvable;
    /**
    * Set to true to mark the liveness test as failed when the request returns a 5xx (server error) status code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#status_5xx_failure CloudletsApplicationLoadBalancer#status_5xx_failure}
    */
    readonly status5XxFailure?: boolean | cdktf.IResolvable;
    /**
    * The number of seconds the system waits before failing the liveness test. The default is 25 seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#timeout CloudletsApplicationLoadBalancer#timeout}
    */
    readonly timeout?: number;
}
export declare function cloudletsApplicationLoadBalancerLivenessSettingsToTerraform(struct?: CloudletsApplicationLoadBalancerLivenessSettingsOutputReference | CloudletsApplicationLoadBalancerLivenessSettings): any;
export declare function cloudletsApplicationLoadBalancerLivenessSettingsToHclTerraform(struct?: CloudletsApplicationLoadBalancerLivenessSettingsOutputReference | CloudletsApplicationLoadBalancerLivenessSettings): any;
export declare class CloudletsApplicationLoadBalancerLivenessSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudletsApplicationLoadBalancerLivenessSettings | undefined;
    set internalValue(value: CloudletsApplicationLoadBalancerLivenessSettings | undefined);
    private _additionalHeaders?;
    get additionalHeaders(): {
        [key: string]: string;
    };
    set additionalHeaders(value: {
        [key: string]: string;
    });
    resetAdditionalHeaders(): void;
    get additionalHeadersInput(): {
        [key: string]: string;
    } | undefined;
    private _hostHeader?;
    get hostHeader(): string;
    set hostHeader(value: string);
    resetHostHeader(): void;
    get hostHeaderInput(): string | undefined;
    private _interval?;
    get interval(): number;
    set interval(value: number);
    resetInterval(): void;
    get intervalInput(): number | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
    private _peerCertificateVerification?;
    get peerCertificateVerification(): boolean | cdktf.IResolvable;
    set peerCertificateVerification(value: boolean | cdktf.IResolvable);
    resetPeerCertificateVerification(): void;
    get peerCertificateVerificationInput(): boolean | cdktf.IResolvable | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
    private _requestString?;
    get requestString(): string;
    set requestString(value: string);
    resetRequestString(): void;
    get requestStringInput(): string | undefined;
    private _responseString?;
    get responseString(): string;
    set responseString(value: string);
    resetResponseString(): void;
    get responseStringInput(): string | undefined;
    private _status3XxFailure?;
    get status3XxFailure(): boolean | cdktf.IResolvable;
    set status3XxFailure(value: boolean | cdktf.IResolvable);
    resetStatus3XxFailure(): void;
    get status3XxFailureInput(): boolean | cdktf.IResolvable | undefined;
    private _status4XxFailure?;
    get status4XxFailure(): boolean | cdktf.IResolvable;
    set status4XxFailure(value: boolean | cdktf.IResolvable);
    resetStatus4XxFailure(): void;
    get status4XxFailureInput(): boolean | cdktf.IResolvable | undefined;
    private _status5XxFailure?;
    get status5XxFailure(): boolean | cdktf.IResolvable;
    set status5XxFailure(value: boolean | cdktf.IResolvable);
    resetStatus5XxFailure(): void;
    get status5XxFailureInput(): boolean | cdktf.IResolvable | undefined;
    private _timeout?;
    get timeout(): number;
    set timeout(value: number);
    resetTimeout(): void;
    get timeoutInput(): number | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer akamai_cloudlets_application_load_balancer}
*/
export declare class CloudletsApplicationLoadBalancer extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cloudlets_application_load_balancer";
    /**
    * Generates CDKTF code for importing a CloudletsApplicationLoadBalancer resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CloudletsApplicationLoadBalancer to import
    * @param importFromId The id of the existing CloudletsApplicationLoadBalancer that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CloudletsApplicationLoadBalancer to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_application_load_balancer akamai_cloudlets_application_load_balancer} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudletsApplicationLoadBalancerConfig
    */
    constructor(scope: Construct, id: string, config: CloudletsApplicationLoadBalancerConfig);
    private _balancingType?;
    get balancingType(): string;
    set balancingType(value: string);
    resetBalancingType(): void;
    get balancingTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _originDescription?;
    get originDescription(): string;
    set originDescription(value: string);
    resetOriginDescription(): void;
    get originDescriptionInput(): string | undefined;
    private _originId?;
    get originId(): string;
    set originId(value: string);
    get originIdInput(): string | undefined;
    get version(): number;
    get warnings(): string;
    private _dataCenters;
    get dataCenters(): CloudletsApplicationLoadBalancerDataCentersList;
    putDataCenters(value: CloudletsApplicationLoadBalancerDataCenters[] | cdktf.IResolvable): void;
    get dataCentersInput(): cdktf.IResolvable | CloudletsApplicationLoadBalancerDataCenters[] | undefined;
    private _livenessSettings;
    get livenessSettings(): CloudletsApplicationLoadBalancerLivenessSettingsOutputReference;
    putLivenessSettings(value: CloudletsApplicationLoadBalancerLivenessSettings): void;
    resetLivenessSettings(): void;
    get livenessSettingsInput(): CloudletsApplicationLoadBalancerLivenessSettings | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
