import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudletsPolicyActivationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Set of property IDs to link to this Cloudlets policy. It is required for non-shared policies
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#associated_properties CloudletsPolicyActivation#associated_properties}
    */
    readonly associatedProperties?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#id CloudletsPolicyActivation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The network you want to activate the policy version on (options are Staging and Production)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#network CloudletsPolicyActivation#network}
    */
    readonly network: string;
    /**
    * ID of the Cloudlets policy you want to activate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#policy_id CloudletsPolicyActivation#policy_id}
    */
    readonly policyId: number;
    /**
    * Cloudlets policy version you want to activate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#version CloudletsPolicyActivation#version}
    */
    readonly version: number;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#timeouts CloudletsPolicyActivation#timeouts}
    */
    readonly timeouts?: CloudletsPolicyActivationTimeouts;
}
export interface CloudletsPolicyActivationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#default CloudletsPolicyActivation#default}
    */
    readonly default?: string;
}
export declare function cloudletsPolicyActivationTimeoutsToTerraform(struct?: CloudletsPolicyActivationTimeoutsOutputReference | CloudletsPolicyActivationTimeouts): any;
export declare function cloudletsPolicyActivationTimeoutsToHclTerraform(struct?: CloudletsPolicyActivationTimeoutsOutputReference | CloudletsPolicyActivationTimeouts): any;
export declare class CloudletsPolicyActivationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudletsPolicyActivationTimeouts | undefined;
    set internalValue(value: CloudletsPolicyActivationTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation akamai_cloudlets_policy_activation}
*/
export declare class CloudletsPolicyActivation extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cloudlets_policy_activation";
    /**
    * Generates CDKTF code for importing a CloudletsPolicyActivation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CloudletsPolicyActivation to import
    * @param importFromId The id of the existing CloudletsPolicyActivation that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CloudletsPolicyActivation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy_activation akamai_cloudlets_policy_activation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudletsPolicyActivationConfig
    */
    constructor(scope: Construct, id: string, config: CloudletsPolicyActivationConfig);
    private _associatedProperties?;
    get associatedProperties(): string[];
    set associatedProperties(value: string[]);
    resetAssociatedProperties(): void;
    get associatedPropertiesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isShared(): cdktf.IResolvable;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _policyId?;
    get policyId(): number;
    set policyId(value: number);
    get policyIdInput(): number | undefined;
    get status(): string;
    private _version?;
    get version(): number;
    set version(value: number);
    get versionInput(): number | undefined;
    private _timeouts;
    get timeouts(): CloudletsPolicyActivationTimeoutsOutputReference;
    putTimeouts(value: CloudletsPolicyActivationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CloudletsPolicyActivationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
