import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudletsPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Code for the type of Cloudlet (ALB, AP, AS, CD, ER, FR, IG, or VP)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#cloudlet_code CloudletsPolicy#cloudlet_code}
    */
    readonly cloudletCode: string;
    /**
    * The description of this specific policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#description CloudletsPolicy#description}
    */
    readonly description?: string;
    /**
    * Defines the group association for the policy. You must have edit privileges for the group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#group_id CloudletsPolicy#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#id CloudletsPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The type of policy that you want to create
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#is_shared CloudletsPolicy#is_shared}
    */
    readonly isShared?: boolean | cdktf.IResolvable;
    /**
    * The version of the Cloudlet specific matchRules
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#match_rule_format CloudletsPolicy#match_rule_format}
    */
    readonly matchRuleFormat?: string;
    /**
    * A JSON structure that defines the rules for this policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#match_rules CloudletsPolicy#match_rules}
    */
    readonly matchRules?: string;
    /**
    * The name of the policy. The name must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#name CloudletsPolicy#name}
    */
    readonly name: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#timeouts CloudletsPolicy#timeouts}
    */
    readonly timeouts?: CloudletsPolicyTimeouts;
}
export interface CloudletsPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#default CloudletsPolicy#default}
    */
    readonly default?: string;
}
export declare function cloudletsPolicyTimeoutsToTerraform(struct?: CloudletsPolicyTimeoutsOutputReference | CloudletsPolicyTimeouts): any;
export declare function cloudletsPolicyTimeoutsToHclTerraform(struct?: CloudletsPolicyTimeoutsOutputReference | CloudletsPolicyTimeouts): any;
export declare class CloudletsPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudletsPolicyTimeouts | undefined;
    set internalValue(value: CloudletsPolicyTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy akamai_cloudlets_policy}
*/
export declare class CloudletsPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cloudlets_policy";
    /**
    * Generates CDKTF code for importing a CloudletsPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CloudletsPolicy to import
    * @param importFromId The id of the existing CloudletsPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CloudletsPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudlets_policy akamai_cloudlets_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudletsPolicyConfig
    */
    constructor(scope: Construct, id: string, config: CloudletsPolicyConfig);
    private _cloudletCode?;
    get cloudletCode(): string;
    set cloudletCode(value: string);
    get cloudletCodeInput(): string | undefined;
    get cloudletId(): number;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isShared?;
    get isShared(): boolean | cdktf.IResolvable;
    set isShared(value: boolean | cdktf.IResolvable);
    resetIsShared(): void;
    get isSharedInput(): boolean | cdktf.IResolvable | undefined;
    private _matchRuleFormat?;
    get matchRuleFormat(): string;
    set matchRuleFormat(value: string);
    resetMatchRuleFormat(): void;
    get matchRuleFormatInput(): string | undefined;
    private _matchRules?;
    get matchRules(): string;
    set matchRules(value: string);
    resetMatchRules(): void;
    get matchRulesInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get version(): number;
    get warnings(): string;
    private _timeouts;
    get timeouts(): CloudletsPolicyTimeoutsOutputReference;
    putTimeouts(value: CloudletsPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CloudletsPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
