import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudwrapperActivationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The configuration you want to activate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation#config_id CloudwrapperActivation#config_id}
    */
    readonly configId: number;
    /**
    * Unique hash value of the configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation#revision CloudwrapperActivation#revision}
    */
    readonly revision: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation#timeouts CloudwrapperActivation#timeouts}
    */
    readonly timeouts?: CloudwrapperActivationTimeouts;
}
export interface CloudwrapperActivationTimeouts {
    /**
    * Optional configurable activation timeout to be used on resource create. By default it's 4h with 1m pooling interval.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation#create CloudwrapperActivation#create}
    */
    readonly create?: string;
    /**
    * Optional configurable activation timeout to be used on resource update. By default it's 4h with 1m pooling interval.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation#update CloudwrapperActivation#update}
    */
    readonly update?: string;
}
export declare function cloudwrapperActivationTimeoutsToTerraform(struct?: CloudwrapperActivationTimeouts | cdktf.IResolvable): any;
export declare function cloudwrapperActivationTimeoutsToHclTerraform(struct?: CloudwrapperActivationTimeouts | cdktf.IResolvable): any;
export declare class CloudwrapperActivationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudwrapperActivationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: CloudwrapperActivationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation akamai_cloudwrapper_activation}
*/
export declare class CloudwrapperActivation extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cloudwrapper_activation";
    /**
    * Generates CDKTF code for importing a CloudwrapperActivation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CloudwrapperActivation to import
    * @param importFromId The id of the existing CloudwrapperActivation that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CloudwrapperActivation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_activation akamai_cloudwrapper_activation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudwrapperActivationConfig
    */
    constructor(scope: Construct, id: string, config: CloudwrapperActivationConfig);
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    get id(): string;
    private _revision?;
    get revision(): string;
    set revision(value: string);
    get revisionInput(): string | undefined;
    private _timeouts;
    get timeouts(): CloudwrapperActivationTimeoutsOutputReference;
    putTimeouts(value: CloudwrapperActivationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | CloudwrapperActivationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
