import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CloudwrapperConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Capacity Alerts enablement information for the configuration. The Alert Threshold should be between 50 and 100.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#capacity_alerts_threshold CloudwrapperConfiguration#capacity_alerts_threshold}
    */
    readonly capacityAlertsThreshold?: number;
    /**
    * Additional information you provide to differentiate or track changes of the configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#comments CloudwrapperConfiguration#comments}
    */
    readonly comments: string;
    /**
    * Name of the configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#config_name CloudwrapperConfiguration#config_name}
    */
    readonly configName: string;
    /**
    * Contract ID having Cloud Wrapper entitlement.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#contract_id CloudwrapperConfiguration#contract_id}
    */
    readonly contractId: string;
    /**
    * Email addresses to use for notifications.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#notification_emails CloudwrapperConfiguration#notification_emails}
    */
    readonly notificationEmails?: string[];
    /**
    * List of properties belonging to eligible products.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#property_ids CloudwrapperConfiguration#property_ids}
    */
    readonly propertyIds: string[];
    /**
    * Retain idle objects beyond their max idle lifetime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#retain_idle_objects CloudwrapperConfiguration#retain_idle_objects}
    */
    readonly retainIdleObjects?: boolean | cdktf.IResolvable;
    /**
    * location block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#location CloudwrapperConfiguration#location}
    */
    readonly location?: CloudwrapperConfigurationLocation[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#timeouts CloudwrapperConfiguration#timeouts}
    */
    readonly timeouts?: CloudwrapperConfigurationTimeouts;
}
export interface CloudwrapperConfigurationLocationCapacity {
    /**
    * Unit of capacity. Can be either 'GB' or 'TB'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#unit CloudwrapperConfiguration#unit}
    */
    readonly unit: string;
    /**
    * Value of capacity.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#value CloudwrapperConfiguration#value}
    */
    readonly value: number;
}
export declare function cloudwrapperConfigurationLocationCapacityToTerraform(struct?: CloudwrapperConfigurationLocationCapacity | cdktf.IResolvable): any;
export declare function cloudwrapperConfigurationLocationCapacityToHclTerraform(struct?: CloudwrapperConfigurationLocationCapacity | cdktf.IResolvable): any;
export declare class CloudwrapperConfigurationLocationCapacityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudwrapperConfigurationLocationCapacity | cdktf.IResolvable | undefined;
    set internalValue(value: CloudwrapperConfigurationLocationCapacity | cdktf.IResolvable | undefined);
    private _unit?;
    get unit(): string;
    set unit(value: string);
    get unitInput(): string | undefined;
    private _value?;
    get value(): number;
    set value(value: number);
    get valueInput(): number | undefined;
}
export interface CloudwrapperConfigurationLocation {
    /**
    * Additional comments provided by the user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#comments CloudwrapperConfiguration#comments}
    */
    readonly comments: string;
    /**
    * Unique identifier for the location and traffic type combination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#traffic_type_id CloudwrapperConfiguration#traffic_type_id}
    */
    readonly trafficTypeId: number;
    /**
    * capacity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#capacity CloudwrapperConfiguration#capacity}
    */
    readonly capacity: CloudwrapperConfigurationLocationCapacity;
}
export declare function cloudwrapperConfigurationLocationToTerraform(struct?: CloudwrapperConfigurationLocation | cdktf.IResolvable): any;
export declare function cloudwrapperConfigurationLocationToHclTerraform(struct?: CloudwrapperConfigurationLocation | cdktf.IResolvable): any;
export declare class CloudwrapperConfigurationLocationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CloudwrapperConfigurationLocation | cdktf.IResolvable | undefined;
    set internalValue(value: CloudwrapperConfigurationLocation | cdktf.IResolvable | undefined);
    private _comments?;
    get comments(): string;
    set comments(value: string);
    get commentsInput(): string | undefined;
    private _trafficTypeId?;
    get trafficTypeId(): number;
    set trafficTypeId(value: number);
    get trafficTypeIdInput(): number | undefined;
    private _capacity;
    get capacity(): CloudwrapperConfigurationLocationCapacityOutputReference;
    putCapacity(value: CloudwrapperConfigurationLocationCapacity): void;
    get capacityInput(): cdktf.IResolvable | CloudwrapperConfigurationLocationCapacity | undefined;
}
export declare class CloudwrapperConfigurationLocationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CloudwrapperConfigurationLocation[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CloudwrapperConfigurationLocationOutputReference;
}
export interface CloudwrapperConfigurationTimeouts {
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#delete CloudwrapperConfiguration#delete}
    */
    readonly delete?: string;
}
export declare function cloudwrapperConfigurationTimeoutsToTerraform(struct?: CloudwrapperConfigurationTimeouts | cdktf.IResolvable): any;
export declare function cloudwrapperConfigurationTimeoutsToHclTerraform(struct?: CloudwrapperConfigurationTimeouts | cdktf.IResolvable): any;
export declare class CloudwrapperConfigurationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CloudwrapperConfigurationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: CloudwrapperConfigurationTimeouts | cdktf.IResolvable | undefined);
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration akamai_cloudwrapper_configuration}
*/
export declare class CloudwrapperConfiguration extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cloudwrapper_configuration";
    /**
    * Generates CDKTF code for importing a CloudwrapperConfiguration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CloudwrapperConfiguration to import
    * @param importFromId The id of the existing CloudwrapperConfiguration that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CloudwrapperConfiguration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cloudwrapper_configuration akamai_cloudwrapper_configuration} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CloudwrapperConfigurationConfig
    */
    constructor(scope: Construct, id: string, config: CloudwrapperConfigurationConfig);
    private _capacityAlertsThreshold?;
    get capacityAlertsThreshold(): number;
    set capacityAlertsThreshold(value: number);
    resetCapacityAlertsThreshold(): void;
    get capacityAlertsThresholdInput(): number | undefined;
    private _comments?;
    get comments(): string;
    set comments(value: string);
    get commentsInput(): string | undefined;
    private _configName?;
    get configName(): string;
    set configName(value: string);
    get configNameInput(): string | undefined;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    get id(): number;
    private _notificationEmails?;
    get notificationEmails(): string[];
    set notificationEmails(value: string[]);
    resetNotificationEmails(): void;
    get notificationEmailsInput(): string[] | undefined;
    private _propertyIds?;
    get propertyIds(): string[];
    set propertyIds(value: string[]);
    get propertyIdsInput(): string[] | undefined;
    private _retainIdleObjects?;
    get retainIdleObjects(): boolean | cdktf.IResolvable;
    set retainIdleObjects(value: boolean | cdktf.IResolvable);
    resetRetainIdleObjects(): void;
    get retainIdleObjectsInput(): boolean | cdktf.IResolvable | undefined;
    get revision(): string;
    private _location;
    get location(): CloudwrapperConfigurationLocationList;
    putLocation(value: CloudwrapperConfigurationLocation[] | cdktf.IResolvable): void;
    resetLocation(): void;
    get locationInput(): cdktf.IResolvable | CloudwrapperConfigurationLocation[] | undefined;
    private _timeouts;
    get timeouts(): CloudwrapperConfigurationTimeoutsOutputReference;
    putTimeouts(value: CloudwrapperConfigurationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | CloudwrapperConfigurationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
