import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CpsDvEnrollmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether acknowledge warnings before certificate verification
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#acknowledge_pre_verification_warnings CpsDvEnrollment#acknowledge_pre_verification_warnings}
    */
    readonly acknowledgePreVerificationWarnings?: boolean | cdktf.IResolvable;
    /**
    * Allow to duplicate common name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#allow_duplicate_common_name CpsDvEnrollment#allow_duplicate_common_name}
    */
    readonly allowDuplicateCommonName?: boolean | cdktf.IResolvable;
    /**
    * Certificate trust chain type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#certificate_chain_type CpsDvEnrollment#certificate_chain_type}
    */
    readonly certificateChainType?: string;
    /**
    * Common name used for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#common_name CpsDvEnrollment#common_name}
    */
    readonly commonName: string;
    /**
    * Contract ID for which enrollment is retrieved
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#contract_id CpsDvEnrollment#contract_id}
    */
    readonly contractId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#id CpsDvEnrollment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of SANs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#sans CpsDvEnrollment#sans}
    */
    readonly sans?: string[];
    /**
    * Type of TLS deployment network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#secure_network CpsDvEnrollment#secure_network}
    */
    readonly secureNetwork: string;
    /**
    * SHA algorithm type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#signature_algorithm CpsDvEnrollment#signature_algorithm}
    */
    readonly signatureAlgorithm: string;
    /**
    * Whether Server Name Indication is used for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#sni_only CpsDvEnrollment#sni_only}
    */
    readonly sniOnly: boolean | cdktf.IResolvable;
    /**
    * admin_contact block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#admin_contact CpsDvEnrollment#admin_contact}
    */
    readonly adminContact: CpsDvEnrollmentAdminContact;
    /**
    * csr block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#csr CpsDvEnrollment#csr}
    */
    readonly csr: CpsDvEnrollmentCsr;
    /**
    * network_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#network_configuration CpsDvEnrollment#network_configuration}
    */
    readonly networkConfiguration: CpsDvEnrollmentNetworkConfiguration;
    /**
    * organization block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#organization CpsDvEnrollment#organization}
    */
    readonly organization: CpsDvEnrollmentOrganization;
    /**
    * tech_contact block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#tech_contact CpsDvEnrollment#tech_contact}
    */
    readonly techContact: CpsDvEnrollmentTechContact;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#timeouts CpsDvEnrollment#timeouts}
    */
    readonly timeouts?: CpsDvEnrollmentTimeouts;
}
export interface CpsDvEnrollmentDnsChallenges {
}
export declare function cpsDvEnrollmentDnsChallengesToTerraform(struct?: CpsDvEnrollmentDnsChallenges): any;
export declare function cpsDvEnrollmentDnsChallengesToHclTerraform(struct?: CpsDvEnrollmentDnsChallenges): any;
export declare class CpsDvEnrollmentDnsChallengesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CpsDvEnrollmentDnsChallenges | undefined;
    set internalValue(value: CpsDvEnrollmentDnsChallenges | undefined);
    get domain(): string;
    get fullPath(): string;
    get responseBody(): string;
}
export declare class CpsDvEnrollmentDnsChallengesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CpsDvEnrollmentDnsChallengesOutputReference;
}
export interface CpsDvEnrollmentHttpChallenges {
}
export declare function cpsDvEnrollmentHttpChallengesToTerraform(struct?: CpsDvEnrollmentHttpChallenges): any;
export declare function cpsDvEnrollmentHttpChallengesToHclTerraform(struct?: CpsDvEnrollmentHttpChallenges): any;
export declare class CpsDvEnrollmentHttpChallengesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CpsDvEnrollmentHttpChallenges | undefined;
    set internalValue(value: CpsDvEnrollmentHttpChallenges | undefined);
    get domain(): string;
    get fullPath(): string;
    get responseBody(): string;
}
export declare class CpsDvEnrollmentHttpChallengesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CpsDvEnrollmentHttpChallengesOutputReference;
}
export interface CpsDvEnrollmentAdminContact {
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#address_line_one CpsDvEnrollment#address_line_one}
    */
    readonly addressLineOne: string;
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#address_line_two CpsDvEnrollment#address_line_two}
    */
    readonly addressLineTwo?: string;
    /**
    * City of residence of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#city CpsDvEnrollment#city}
    */
    readonly city: string;
    /**
    * Country code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#country_code CpsDvEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * E-mail address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#email CpsDvEnrollment#email}
    */
    readonly email: string;
    /**
    * First name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#first_name CpsDvEnrollment#first_name}
    */
    readonly firstName: string;
    /**
    * Last name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#last_name CpsDvEnrollment#last_name}
    */
    readonly lastName: string;
    /**
    * Organization where contact is hired
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#organization CpsDvEnrollment#organization}
    */
    readonly organization: string;
    /**
    * Phone number of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#phone CpsDvEnrollment#phone}
    */
    readonly phone: string;
    /**
    * Postal code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#postal_code CpsDvEnrollment#postal_code}
    */
    readonly postalCode: string;
    /**
    * The region of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#region CpsDvEnrollment#region}
    */
    readonly region: string;
    /**
    * Title of the the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#title CpsDvEnrollment#title}
    */
    readonly title?: string;
}
export declare function cpsDvEnrollmentAdminContactToTerraform(struct?: CpsDvEnrollmentAdminContactOutputReference | CpsDvEnrollmentAdminContact): any;
export declare function cpsDvEnrollmentAdminContactToHclTerraform(struct?: CpsDvEnrollmentAdminContactOutputReference | CpsDvEnrollmentAdminContact): any;
export declare class CpsDvEnrollmentAdminContactOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentAdminContact | undefined;
    set internalValue(value: CpsDvEnrollmentAdminContact | undefined);
    private _addressLineOne?;
    get addressLineOne(): string;
    set addressLineOne(value: string);
    get addressLineOneInput(): string | undefined;
    private _addressLineTwo?;
    get addressLineTwo(): string;
    set addressLineTwo(value: string);
    resetAddressLineTwo(): void;
    get addressLineTwoInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    get phoneInput(): string | undefined;
    private _postalCode?;
    get postalCode(): string;
    set postalCode(value: string);
    get postalCodeInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface CpsDvEnrollmentCsr {
    /**
    * City where organization is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#city CpsDvEnrollment#city}
    */
    readonly city: string;
    /**
    * The code of the country where organization is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#country_code CpsDvEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * Name of organization used in all legal documents
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#organization CpsDvEnrollment#organization}
    */
    readonly organization: string;
    /**
    * Organizational unit of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#organizational_unit CpsDvEnrollment#organizational_unit}
    */
    readonly organizationalUnit?: string;
    /**
    * For the Let's Encrypt Domain Validated (DV) SAN certificates, the preferred trust chain will be included by CPS with the leaf certificate in the TLS handshake. If the field does not have a value, whichever trust chain Akamai chooses will be used by default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#preferred_trust_chain CpsDvEnrollment#preferred_trust_chain}
    */
    readonly preferredTrustChain?: string;
    /**
    * State or province of organization location
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#state CpsDvEnrollment#state}
    */
    readonly state?: string;
}
export declare function cpsDvEnrollmentCsrToTerraform(struct?: CpsDvEnrollmentCsrOutputReference | CpsDvEnrollmentCsr): any;
export declare function cpsDvEnrollmentCsrToHclTerraform(struct?: CpsDvEnrollmentCsrOutputReference | CpsDvEnrollmentCsr): any;
export declare class CpsDvEnrollmentCsrOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentCsr | undefined;
    set internalValue(value: CpsDvEnrollmentCsr | undefined);
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _organizationalUnit?;
    get organizationalUnit(): string;
    set organizationalUnit(value: string);
    resetOrganizationalUnit(): void;
    get organizationalUnitInput(): string | undefined;
    private _preferredTrustChain?;
    get preferredTrustChain(): string;
    set preferredTrustChain(value: string);
    resetPreferredTrustChain(): void;
    get preferredTrustChainInput(): string | undefined;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
}
export interface CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication {
    /**
    * Enable OCSP stapling
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#ocsp_enabled CpsDvEnrollment#ocsp_enabled}
    */
    readonly ocspEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable the server to send the certificate authority (CA) list to the client
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#send_ca_list_to_client CpsDvEnrollment#send_ca_list_to_client}
    */
    readonly sendCaListToClient?: boolean | cdktf.IResolvable;
    /**
    * The identifier of the set of trust chains, created in the Trust Chain Manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#set_id CpsDvEnrollment#set_id}
    */
    readonly setId?: string;
}
export declare function cpsDvEnrollmentNetworkConfigurationClientMutualAuthenticationToTerraform(struct?: CpsDvEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference | CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication): any;
export declare function cpsDvEnrollmentNetworkConfigurationClientMutualAuthenticationToHclTerraform(struct?: CpsDvEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference | CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication): any;
export declare class CpsDvEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication | undefined;
    set internalValue(value: CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication | undefined);
    private _ocspEnabled?;
    get ocspEnabled(): boolean | cdktf.IResolvable;
    set ocspEnabled(value: boolean | cdktf.IResolvable);
    resetOcspEnabled(): void;
    get ocspEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _sendCaListToClient?;
    get sendCaListToClient(): boolean | cdktf.IResolvable;
    set sendCaListToClient(value: boolean | cdktf.IResolvable);
    resetSendCaListToClient(): void;
    get sendCaListToClientInput(): boolean | cdktf.IResolvable | undefined;
    private _setId?;
    get setId(): string;
    set setId(value: string);
    resetSetId(): void;
    get setIdInput(): string | undefined;
}
export interface CpsDvEnrollmentNetworkConfiguration {
    /**
    * Enable CPS to direct traffic using all the SANs listed in the SANs parameter when enrollment is created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#clone_dns_names CpsDvEnrollment#clone_dns_names}
    */
    readonly cloneDnsNames?: boolean | cdktf.IResolvable;
    /**
    * TLS versions which are disallowed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#disallowed_tls_versions CpsDvEnrollment#disallowed_tls_versions}
    */
    readonly disallowedTlsVersions?: string[];
    /**
    * Geography type used for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#geography CpsDvEnrollment#geography}
    */
    readonly geography: string;
    /**
    * Mandatory Ciphers which are included for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#must_have_ciphers CpsDvEnrollment#must_have_ciphers}
    */
    readonly mustHaveCiphers?: string;
    /**
    * Enable OCSP stapling
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#ocsp_stapling CpsDvEnrollment#ocsp_stapling}
    */
    readonly ocspStapling?: string;
    /**
    * Preferred Ciphers which are included for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#preferred_ciphers CpsDvEnrollment#preferred_ciphers}
    */
    readonly preferredCiphers?: string;
    /**
    * Enable QUIC protocol
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#quic_enabled CpsDvEnrollment#quic_enabled}
    */
    readonly quicEnabled?: boolean | cdktf.IResolvable;
    /**
    * client_mutual_authentication block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#client_mutual_authentication CpsDvEnrollment#client_mutual_authentication}
    */
    readonly clientMutualAuthentication?: CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication;
}
export declare function cpsDvEnrollmentNetworkConfigurationToTerraform(struct?: CpsDvEnrollmentNetworkConfigurationOutputReference | CpsDvEnrollmentNetworkConfiguration): any;
export declare function cpsDvEnrollmentNetworkConfigurationToHclTerraform(struct?: CpsDvEnrollmentNetworkConfigurationOutputReference | CpsDvEnrollmentNetworkConfiguration): any;
export declare class CpsDvEnrollmentNetworkConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentNetworkConfiguration | undefined;
    set internalValue(value: CpsDvEnrollmentNetworkConfiguration | undefined);
    private _cloneDnsNames?;
    get cloneDnsNames(): boolean | cdktf.IResolvable;
    set cloneDnsNames(value: boolean | cdktf.IResolvable);
    resetCloneDnsNames(): void;
    get cloneDnsNamesInput(): boolean | cdktf.IResolvable | undefined;
    private _disallowedTlsVersions?;
    get disallowedTlsVersions(): string[];
    set disallowedTlsVersions(value: string[]);
    resetDisallowedTlsVersions(): void;
    get disallowedTlsVersionsInput(): string[] | undefined;
    private _geography?;
    get geography(): string;
    set geography(value: string);
    get geographyInput(): string | undefined;
    private _mustHaveCiphers?;
    get mustHaveCiphers(): string;
    set mustHaveCiphers(value: string);
    resetMustHaveCiphers(): void;
    get mustHaveCiphersInput(): string | undefined;
    private _ocspStapling?;
    get ocspStapling(): string;
    set ocspStapling(value: string);
    resetOcspStapling(): void;
    get ocspStaplingInput(): string | undefined;
    private _preferredCiphers?;
    get preferredCiphers(): string;
    set preferredCiphers(value: string);
    resetPreferredCiphers(): void;
    get preferredCiphersInput(): string | undefined;
    private _quicEnabled?;
    get quicEnabled(): boolean | cdktf.IResolvable;
    set quicEnabled(value: boolean | cdktf.IResolvable);
    resetQuicEnabled(): void;
    get quicEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _clientMutualAuthentication;
    get clientMutualAuthentication(): CpsDvEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference;
    putClientMutualAuthentication(value: CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication): void;
    resetClientMutualAuthentication(): void;
    get clientMutualAuthenticationInput(): CpsDvEnrollmentNetworkConfigurationClientMutualAuthentication | undefined;
}
export interface CpsDvEnrollmentOrganization {
    /**
    * The address of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#address_line_one CpsDvEnrollment#address_line_one}
    */
    readonly addressLineOne: string;
    /**
    * The address of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#address_line_two CpsDvEnrollment#address_line_two}
    */
    readonly addressLineTwo?: string;
    /**
    * City of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#city CpsDvEnrollment#city}
    */
    readonly city: string;
    /**
    * Country code of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#country_code CpsDvEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * Name of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#name CpsDvEnrollment#name}
    */
    readonly name: string;
    /**
    * Phone number of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#phone CpsDvEnrollment#phone}
    */
    readonly phone: string;
    /**
    * Postal code of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#postal_code CpsDvEnrollment#postal_code}
    */
    readonly postalCode: string;
    /**
    * The region of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#region CpsDvEnrollment#region}
    */
    readonly region: string;
}
export declare function cpsDvEnrollmentOrganizationToTerraform(struct?: CpsDvEnrollmentOrganizationOutputReference | CpsDvEnrollmentOrganization): any;
export declare function cpsDvEnrollmentOrganizationToHclTerraform(struct?: CpsDvEnrollmentOrganizationOutputReference | CpsDvEnrollmentOrganization): any;
export declare class CpsDvEnrollmentOrganizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentOrganization | undefined;
    set internalValue(value: CpsDvEnrollmentOrganization | undefined);
    private _addressLineOne?;
    get addressLineOne(): string;
    set addressLineOne(value: string);
    get addressLineOneInput(): string | undefined;
    private _addressLineTwo?;
    get addressLineTwo(): string;
    set addressLineTwo(value: string);
    resetAddressLineTwo(): void;
    get addressLineTwoInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    get phoneInput(): string | undefined;
    private _postalCode?;
    get postalCode(): string;
    set postalCode(value: string);
    get postalCodeInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export interface CpsDvEnrollmentTechContact {
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#address_line_one CpsDvEnrollment#address_line_one}
    */
    readonly addressLineOne: string;
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#address_line_two CpsDvEnrollment#address_line_two}
    */
    readonly addressLineTwo?: string;
    /**
    * City of residence of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#city CpsDvEnrollment#city}
    */
    readonly city: string;
    /**
    * Country code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#country_code CpsDvEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * E-mail address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#email CpsDvEnrollment#email}
    */
    readonly email: string;
    /**
    * First name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#first_name CpsDvEnrollment#first_name}
    */
    readonly firstName: string;
    /**
    * Last name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#last_name CpsDvEnrollment#last_name}
    */
    readonly lastName: string;
    /**
    * Organization where contact is hired
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#organization CpsDvEnrollment#organization}
    */
    readonly organization: string;
    /**
    * Phone number of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#phone CpsDvEnrollment#phone}
    */
    readonly phone: string;
    /**
    * Postal code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#postal_code CpsDvEnrollment#postal_code}
    */
    readonly postalCode: string;
    /**
    * The region of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#region CpsDvEnrollment#region}
    */
    readonly region: string;
    /**
    * Title of the the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#title CpsDvEnrollment#title}
    */
    readonly title?: string;
}
export declare function cpsDvEnrollmentTechContactToTerraform(struct?: CpsDvEnrollmentTechContactOutputReference | CpsDvEnrollmentTechContact): any;
export declare function cpsDvEnrollmentTechContactToHclTerraform(struct?: CpsDvEnrollmentTechContactOutputReference | CpsDvEnrollmentTechContact): any;
export declare class CpsDvEnrollmentTechContactOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentTechContact | undefined;
    set internalValue(value: CpsDvEnrollmentTechContact | undefined);
    private _addressLineOne?;
    get addressLineOne(): string;
    set addressLineOne(value: string);
    get addressLineOneInput(): string | undefined;
    private _addressLineTwo?;
    get addressLineTwo(): string;
    set addressLineTwo(value: string);
    resetAddressLineTwo(): void;
    get addressLineTwoInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    get phoneInput(): string | undefined;
    private _postalCode?;
    get postalCode(): string;
    set postalCode(value: string);
    get postalCodeInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface CpsDvEnrollmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#default CpsDvEnrollment#default}
    */
    readonly default?: string;
}
export declare function cpsDvEnrollmentTimeoutsToTerraform(struct?: CpsDvEnrollmentTimeoutsOutputReference | CpsDvEnrollmentTimeouts): any;
export declare function cpsDvEnrollmentTimeoutsToHclTerraform(struct?: CpsDvEnrollmentTimeoutsOutputReference | CpsDvEnrollmentTimeouts): any;
export declare class CpsDvEnrollmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvEnrollmentTimeouts | undefined;
    set internalValue(value: CpsDvEnrollmentTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment akamai_cps_dv_enrollment}
*/
export declare class CpsDvEnrollment extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cps_dv_enrollment";
    /**
    * Generates CDKTF code for importing a CpsDvEnrollment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CpsDvEnrollment to import
    * @param importFromId The id of the existing CpsDvEnrollment that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CpsDvEnrollment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_enrollment akamai_cps_dv_enrollment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CpsDvEnrollmentConfig
    */
    constructor(scope: Construct, id: string, config: CpsDvEnrollmentConfig);
    private _acknowledgePreVerificationWarnings?;
    get acknowledgePreVerificationWarnings(): boolean | cdktf.IResolvable;
    set acknowledgePreVerificationWarnings(value: boolean | cdktf.IResolvable);
    resetAcknowledgePreVerificationWarnings(): void;
    get acknowledgePreVerificationWarningsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowDuplicateCommonName?;
    get allowDuplicateCommonName(): boolean | cdktf.IResolvable;
    set allowDuplicateCommonName(value: boolean | cdktf.IResolvable);
    resetAllowDuplicateCommonName(): void;
    get allowDuplicateCommonNameInput(): boolean | cdktf.IResolvable | undefined;
    private _certificateChainType?;
    get certificateChainType(): string;
    set certificateChainType(value: string);
    resetCertificateChainType(): void;
    get certificateChainTypeInput(): string | undefined;
    get certificateType(): string;
    private _commonName?;
    get commonName(): string;
    set commonName(value: string);
    get commonNameInput(): string | undefined;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _dnsChallenges;
    get dnsChallenges(): CpsDvEnrollmentDnsChallengesList;
    private _httpChallenges;
    get httpChallenges(): CpsDvEnrollmentHttpChallengesList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get registrationAuthority(): string;
    private _sans?;
    get sans(): string[];
    set sans(value: string[]);
    resetSans(): void;
    get sansInput(): string[] | undefined;
    private _secureNetwork?;
    get secureNetwork(): string;
    set secureNetwork(value: string);
    get secureNetworkInput(): string | undefined;
    private _signatureAlgorithm?;
    get signatureAlgorithm(): string;
    set signatureAlgorithm(value: string);
    get signatureAlgorithmInput(): string | undefined;
    private _sniOnly?;
    get sniOnly(): boolean | cdktf.IResolvable;
    set sniOnly(value: boolean | cdktf.IResolvable);
    get sniOnlyInput(): boolean | cdktf.IResolvable | undefined;
    get validationType(): string;
    private _adminContact;
    get adminContact(): CpsDvEnrollmentAdminContactOutputReference;
    putAdminContact(value: CpsDvEnrollmentAdminContact): void;
    get adminContactInput(): CpsDvEnrollmentAdminContact | undefined;
    private _csr;
    get csr(): CpsDvEnrollmentCsrOutputReference;
    putCsr(value: CpsDvEnrollmentCsr): void;
    get csrInput(): CpsDvEnrollmentCsr | undefined;
    private _networkConfiguration;
    get networkConfiguration(): CpsDvEnrollmentNetworkConfigurationOutputReference;
    putNetworkConfiguration(value: CpsDvEnrollmentNetworkConfiguration): void;
    get networkConfigurationInput(): CpsDvEnrollmentNetworkConfiguration | undefined;
    private _organization;
    get organization(): CpsDvEnrollmentOrganizationOutputReference;
    putOrganization(value: CpsDvEnrollmentOrganization): void;
    get organizationInput(): CpsDvEnrollmentOrganization | undefined;
    private _techContact;
    get techContact(): CpsDvEnrollmentTechContactOutputReference;
    putTechContact(value: CpsDvEnrollmentTechContact): void;
    get techContactInput(): CpsDvEnrollmentTechContact | undefined;
    private _timeouts;
    get timeouts(): CpsDvEnrollmentTimeoutsOutputReference;
    putTimeouts(value: CpsDvEnrollmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CpsDvEnrollmentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
