import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CpsDvValidationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique identifier of enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation#enrollment_id CpsDvValidation#enrollment_id}
    */
    readonly enrollmentId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation#id CpsDvValidation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of SANs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation#sans CpsDvValidation#sans}
    */
    readonly sans?: string[];
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation#timeouts CpsDvValidation#timeouts}
    */
    readonly timeouts?: CpsDvValidationTimeouts;
}
export interface CpsDvValidationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation#default CpsDvValidation#default}
    */
    readonly default?: string;
}
export declare function cpsDvValidationTimeoutsToTerraform(struct?: CpsDvValidationTimeoutsOutputReference | CpsDvValidationTimeouts): any;
export declare function cpsDvValidationTimeoutsToHclTerraform(struct?: CpsDvValidationTimeoutsOutputReference | CpsDvValidationTimeouts): any;
export declare class CpsDvValidationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsDvValidationTimeouts | undefined;
    set internalValue(value: CpsDvValidationTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation akamai_cps_dv_validation}
*/
export declare class CpsDvValidation extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cps_dv_validation";
    /**
    * Generates CDKTF code for importing a CpsDvValidation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CpsDvValidation to import
    * @param importFromId The id of the existing CpsDvValidation that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CpsDvValidation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_dv_validation akamai_cps_dv_validation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CpsDvValidationConfig
    */
    constructor(scope: Construct, id: string, config: CpsDvValidationConfig);
    private _enrollmentId?;
    get enrollmentId(): number;
    set enrollmentId(value: number);
    get enrollmentIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _sans?;
    get sans(): string[];
    set sans(value: string[]);
    resetSans(): void;
    get sansInput(): string[] | undefined;
    get status(): string;
    private _timeouts;
    get timeouts(): CpsDvValidationTimeoutsOutputReference;
    putTimeouts(value: CpsDvValidationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CpsDvValidationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
