import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CpsThirdPartyEnrollmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether acknowledge warnings before certificate verification
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#acknowledge_pre_verification_warnings CpsThirdPartyEnrollment#acknowledge_pre_verification_warnings}
    */
    readonly acknowledgePreVerificationWarnings?: boolean | cdktf.IResolvable;
    /**
    * Allow to duplicate common name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#allow_duplicate_common_name CpsThirdPartyEnrollment#allow_duplicate_common_name}
    */
    readonly allowDuplicateCommonName?: boolean | cdktf.IResolvable;
    /**
    * List of warnings to be automatically approved
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#auto_approve_warnings CpsThirdPartyEnrollment#auto_approve_warnings}
    */
    readonly autoApproveWarnings?: string[];
    /**
    * Certificate trust chain type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#certificate_chain_type CpsThirdPartyEnrollment#certificate_chain_type}
    */
    readonly certificateChainType?: string;
    /**
    * When set to false, the certificate will be deployed to both staging and production networks
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#change_management CpsThirdPartyEnrollment#change_management}
    */
    readonly changeManagement?: boolean | cdktf.IResolvable;
    /**
    * Common name used for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#common_name CpsThirdPartyEnrollment#common_name}
    */
    readonly commonName: string;
    /**
    * Contract ID for which enrollment is retrieved
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#contract_id CpsThirdPartyEnrollment#contract_id}
    */
    readonly contractId: string;
    /**
    * When true, SANs are excluded from the CSR
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#exclude_sans CpsThirdPartyEnrollment#exclude_sans}
    */
    readonly excludeSans?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#id CpsThirdPartyEnrollment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of SANs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#sans CpsThirdPartyEnrollment#sans}
    */
    readonly sans?: string[];
    /**
    * Type of TLS deployment network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#secure_network CpsThirdPartyEnrollment#secure_network}
    */
    readonly secureNetwork: string;
    /**
    * The SHA function. Changing this value may require running terraform destroy, terraform apply
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#signature_algorithm CpsThirdPartyEnrollment#signature_algorithm}
    */
    readonly signatureAlgorithm?: string;
    /**
    * Whether Server Name Indication is used for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#sni_only CpsThirdPartyEnrollment#sni_only}
    */
    readonly sniOnly: boolean | cdktf.IResolvable;
    /**
    * admin_contact block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#admin_contact CpsThirdPartyEnrollment#admin_contact}
    */
    readonly adminContact: CpsThirdPartyEnrollmentAdminContact;
    /**
    * csr block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#csr CpsThirdPartyEnrollment#csr}
    */
    readonly csr: CpsThirdPartyEnrollmentCsr;
    /**
    * network_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#network_configuration CpsThirdPartyEnrollment#network_configuration}
    */
    readonly networkConfiguration: CpsThirdPartyEnrollmentNetworkConfiguration;
    /**
    * organization block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#organization CpsThirdPartyEnrollment#organization}
    */
    readonly organization: CpsThirdPartyEnrollmentOrganization;
    /**
    * tech_contact block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#tech_contact CpsThirdPartyEnrollment#tech_contact}
    */
    readonly techContact: CpsThirdPartyEnrollmentTechContact;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#timeouts CpsThirdPartyEnrollment#timeouts}
    */
    readonly timeouts?: CpsThirdPartyEnrollmentTimeouts;
}
export interface CpsThirdPartyEnrollmentAdminContact {
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#address_line_one CpsThirdPartyEnrollment#address_line_one}
    */
    readonly addressLineOne: string;
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#address_line_two CpsThirdPartyEnrollment#address_line_two}
    */
    readonly addressLineTwo?: string;
    /**
    * City of residence of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#city CpsThirdPartyEnrollment#city}
    */
    readonly city: string;
    /**
    * Country code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#country_code CpsThirdPartyEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * E-mail address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#email CpsThirdPartyEnrollment#email}
    */
    readonly email: string;
    /**
    * First name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#first_name CpsThirdPartyEnrollment#first_name}
    */
    readonly firstName: string;
    /**
    * Last name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#last_name CpsThirdPartyEnrollment#last_name}
    */
    readonly lastName: string;
    /**
    * Organization where contact is hired
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#organization CpsThirdPartyEnrollment#organization}
    */
    readonly organization: string;
    /**
    * Phone number of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#phone CpsThirdPartyEnrollment#phone}
    */
    readonly phone: string;
    /**
    * Postal code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#postal_code CpsThirdPartyEnrollment#postal_code}
    */
    readonly postalCode: string;
    /**
    * The region of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#region CpsThirdPartyEnrollment#region}
    */
    readonly region: string;
    /**
    * Title of the the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#title CpsThirdPartyEnrollment#title}
    */
    readonly title?: string;
}
export declare function cpsThirdPartyEnrollmentAdminContactToTerraform(struct?: CpsThirdPartyEnrollmentAdminContactOutputReference | CpsThirdPartyEnrollmentAdminContact): any;
export declare function cpsThirdPartyEnrollmentAdminContactToHclTerraform(struct?: CpsThirdPartyEnrollmentAdminContactOutputReference | CpsThirdPartyEnrollmentAdminContact): any;
export declare class CpsThirdPartyEnrollmentAdminContactOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentAdminContact | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentAdminContact | undefined);
    private _addressLineOne?;
    get addressLineOne(): string;
    set addressLineOne(value: string);
    get addressLineOneInput(): string | undefined;
    private _addressLineTwo?;
    get addressLineTwo(): string;
    set addressLineTwo(value: string);
    resetAddressLineTwo(): void;
    get addressLineTwoInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    get phoneInput(): string | undefined;
    private _postalCode?;
    get postalCode(): string;
    set postalCode(value: string);
    get postalCodeInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface CpsThirdPartyEnrollmentCsr {
    /**
    * City where organization is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#city CpsThirdPartyEnrollment#city}
    */
    readonly city: string;
    /**
    * The code of the country where organization is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#country_code CpsThirdPartyEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * Name of organization used in all legal documents
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#organization CpsThirdPartyEnrollment#organization}
    */
    readonly organization: string;
    /**
    * Organizational unit of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#organizational_unit CpsThirdPartyEnrollment#organizational_unit}
    */
    readonly organizationalUnit?: string;
    /**
    * For the Let's Encrypt Domain Validated (DV) SAN certificates, the preferred trust chain will be included by CPS with the leaf certificate in the TLS handshake. If the field does not have a value, whichever trust chain Akamai chooses will be used by default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#preferred_trust_chain CpsThirdPartyEnrollment#preferred_trust_chain}
    */
    readonly preferredTrustChain?: string;
    /**
    * State or province of organization location
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#state CpsThirdPartyEnrollment#state}
    */
    readonly state?: string;
}
export declare function cpsThirdPartyEnrollmentCsrToTerraform(struct?: CpsThirdPartyEnrollmentCsrOutputReference | CpsThirdPartyEnrollmentCsr): any;
export declare function cpsThirdPartyEnrollmentCsrToHclTerraform(struct?: CpsThirdPartyEnrollmentCsrOutputReference | CpsThirdPartyEnrollmentCsr): any;
export declare class CpsThirdPartyEnrollmentCsrOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentCsr | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentCsr | undefined);
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _organizationalUnit?;
    get organizationalUnit(): string;
    set organizationalUnit(value: string);
    resetOrganizationalUnit(): void;
    get organizationalUnitInput(): string | undefined;
    private _preferredTrustChain?;
    get preferredTrustChain(): string;
    set preferredTrustChain(value: string);
    resetPreferredTrustChain(): void;
    get preferredTrustChainInput(): string | undefined;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
}
export interface CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication {
    /**
    * Enable OCSP stapling
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#ocsp_enabled CpsThirdPartyEnrollment#ocsp_enabled}
    */
    readonly ocspEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable the server to send the certificate authority (CA) list to the client
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#send_ca_list_to_client CpsThirdPartyEnrollment#send_ca_list_to_client}
    */
    readonly sendCaListToClient?: boolean | cdktf.IResolvable;
    /**
    * The identifier of the set of trust chains, created in the Trust Chain Manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#set_id CpsThirdPartyEnrollment#set_id}
    */
    readonly setId?: string;
}
export declare function cpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthenticationToTerraform(struct?: CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference | CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication): any;
export declare function cpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthenticationToHclTerraform(struct?: CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference | CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication): any;
export declare class CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication | undefined);
    private _ocspEnabled?;
    get ocspEnabled(): boolean | cdktf.IResolvable;
    set ocspEnabled(value: boolean | cdktf.IResolvable);
    resetOcspEnabled(): void;
    get ocspEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _sendCaListToClient?;
    get sendCaListToClient(): boolean | cdktf.IResolvable;
    set sendCaListToClient(value: boolean | cdktf.IResolvable);
    resetSendCaListToClient(): void;
    get sendCaListToClientInput(): boolean | cdktf.IResolvable | undefined;
    private _setId?;
    get setId(): string;
    set setId(value: string);
    resetSetId(): void;
    get setIdInput(): string | undefined;
}
export interface CpsThirdPartyEnrollmentNetworkConfiguration {
    /**
    * Enable CPS to direct traffic using all the SANs listed in the SANs parameter when enrollment is created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#clone_dns_names CpsThirdPartyEnrollment#clone_dns_names}
    */
    readonly cloneDnsNames?: boolean | cdktf.IResolvable;
    /**
    * TLS versions which are disallowed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#disallowed_tls_versions CpsThirdPartyEnrollment#disallowed_tls_versions}
    */
    readonly disallowedTlsVersions?: string[];
    /**
    * Geography type used for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#geography CpsThirdPartyEnrollment#geography}
    */
    readonly geography: string;
    /**
    * Mandatory Ciphers which are included for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#must_have_ciphers CpsThirdPartyEnrollment#must_have_ciphers}
    */
    readonly mustHaveCiphers?: string;
    /**
    * Enable OCSP stapling
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#ocsp_stapling CpsThirdPartyEnrollment#ocsp_stapling}
    */
    readonly ocspStapling?: string;
    /**
    * Preferred Ciphers which are included for enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#preferred_ciphers CpsThirdPartyEnrollment#preferred_ciphers}
    */
    readonly preferredCiphers?: string;
    /**
    * Enable QUIC protocol
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#quic_enabled CpsThirdPartyEnrollment#quic_enabled}
    */
    readonly quicEnabled?: boolean | cdktf.IResolvable;
    /**
    * client_mutual_authentication block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#client_mutual_authentication CpsThirdPartyEnrollment#client_mutual_authentication}
    */
    readonly clientMutualAuthentication?: CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication;
}
export declare function cpsThirdPartyEnrollmentNetworkConfigurationToTerraform(struct?: CpsThirdPartyEnrollmentNetworkConfigurationOutputReference | CpsThirdPartyEnrollmentNetworkConfiguration): any;
export declare function cpsThirdPartyEnrollmentNetworkConfigurationToHclTerraform(struct?: CpsThirdPartyEnrollmentNetworkConfigurationOutputReference | CpsThirdPartyEnrollmentNetworkConfiguration): any;
export declare class CpsThirdPartyEnrollmentNetworkConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentNetworkConfiguration | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentNetworkConfiguration | undefined);
    private _cloneDnsNames?;
    get cloneDnsNames(): boolean | cdktf.IResolvable;
    set cloneDnsNames(value: boolean | cdktf.IResolvable);
    resetCloneDnsNames(): void;
    get cloneDnsNamesInput(): boolean | cdktf.IResolvable | undefined;
    private _disallowedTlsVersions?;
    get disallowedTlsVersions(): string[];
    set disallowedTlsVersions(value: string[]);
    resetDisallowedTlsVersions(): void;
    get disallowedTlsVersionsInput(): string[] | undefined;
    private _geography?;
    get geography(): string;
    set geography(value: string);
    get geographyInput(): string | undefined;
    private _mustHaveCiphers?;
    get mustHaveCiphers(): string;
    set mustHaveCiphers(value: string);
    resetMustHaveCiphers(): void;
    get mustHaveCiphersInput(): string | undefined;
    private _ocspStapling?;
    get ocspStapling(): string;
    set ocspStapling(value: string);
    resetOcspStapling(): void;
    get ocspStaplingInput(): string | undefined;
    private _preferredCiphers?;
    get preferredCiphers(): string;
    set preferredCiphers(value: string);
    resetPreferredCiphers(): void;
    get preferredCiphersInput(): string | undefined;
    private _quicEnabled?;
    get quicEnabled(): boolean | cdktf.IResolvable;
    set quicEnabled(value: boolean | cdktf.IResolvable);
    resetQuicEnabled(): void;
    get quicEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _clientMutualAuthentication;
    get clientMutualAuthentication(): CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthenticationOutputReference;
    putClientMutualAuthentication(value: CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication): void;
    resetClientMutualAuthentication(): void;
    get clientMutualAuthenticationInput(): CpsThirdPartyEnrollmentNetworkConfigurationClientMutualAuthentication | undefined;
}
export interface CpsThirdPartyEnrollmentOrganization {
    /**
    * The address of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#address_line_one CpsThirdPartyEnrollment#address_line_one}
    */
    readonly addressLineOne: string;
    /**
    * The address of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#address_line_two CpsThirdPartyEnrollment#address_line_two}
    */
    readonly addressLineTwo?: string;
    /**
    * City of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#city CpsThirdPartyEnrollment#city}
    */
    readonly city: string;
    /**
    * Country code of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#country_code CpsThirdPartyEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * Name of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#name CpsThirdPartyEnrollment#name}
    */
    readonly name: string;
    /**
    * Phone number of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#phone CpsThirdPartyEnrollment#phone}
    */
    readonly phone: string;
    /**
    * Postal code of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#postal_code CpsThirdPartyEnrollment#postal_code}
    */
    readonly postalCode: string;
    /**
    * The region of organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#region CpsThirdPartyEnrollment#region}
    */
    readonly region: string;
}
export declare function cpsThirdPartyEnrollmentOrganizationToTerraform(struct?: CpsThirdPartyEnrollmentOrganizationOutputReference | CpsThirdPartyEnrollmentOrganization): any;
export declare function cpsThirdPartyEnrollmentOrganizationToHclTerraform(struct?: CpsThirdPartyEnrollmentOrganizationOutputReference | CpsThirdPartyEnrollmentOrganization): any;
export declare class CpsThirdPartyEnrollmentOrganizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentOrganization | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentOrganization | undefined);
    private _addressLineOne?;
    get addressLineOne(): string;
    set addressLineOne(value: string);
    get addressLineOneInput(): string | undefined;
    private _addressLineTwo?;
    get addressLineTwo(): string;
    set addressLineTwo(value: string);
    resetAddressLineTwo(): void;
    get addressLineTwoInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    get phoneInput(): string | undefined;
    private _postalCode?;
    get postalCode(): string;
    set postalCode(value: string);
    get postalCodeInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export interface CpsThirdPartyEnrollmentTechContact {
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#address_line_one CpsThirdPartyEnrollment#address_line_one}
    */
    readonly addressLineOne: string;
    /**
    * The address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#address_line_two CpsThirdPartyEnrollment#address_line_two}
    */
    readonly addressLineTwo?: string;
    /**
    * City of residence of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#city CpsThirdPartyEnrollment#city}
    */
    readonly city: string;
    /**
    * Country code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#country_code CpsThirdPartyEnrollment#country_code}
    */
    readonly countryCode: string;
    /**
    * E-mail address of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#email CpsThirdPartyEnrollment#email}
    */
    readonly email: string;
    /**
    * First name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#first_name CpsThirdPartyEnrollment#first_name}
    */
    readonly firstName: string;
    /**
    * Last name of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#last_name CpsThirdPartyEnrollment#last_name}
    */
    readonly lastName: string;
    /**
    * Organization where contact is hired
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#organization CpsThirdPartyEnrollment#organization}
    */
    readonly organization: string;
    /**
    * Phone number of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#phone CpsThirdPartyEnrollment#phone}
    */
    readonly phone: string;
    /**
    * Postal code of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#postal_code CpsThirdPartyEnrollment#postal_code}
    */
    readonly postalCode: string;
    /**
    * The region of the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#region CpsThirdPartyEnrollment#region}
    */
    readonly region: string;
    /**
    * Title of the the contact
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#title CpsThirdPartyEnrollment#title}
    */
    readonly title?: string;
}
export declare function cpsThirdPartyEnrollmentTechContactToTerraform(struct?: CpsThirdPartyEnrollmentTechContactOutputReference | CpsThirdPartyEnrollmentTechContact): any;
export declare function cpsThirdPartyEnrollmentTechContactToHclTerraform(struct?: CpsThirdPartyEnrollmentTechContactOutputReference | CpsThirdPartyEnrollmentTechContact): any;
export declare class CpsThirdPartyEnrollmentTechContactOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentTechContact | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentTechContact | undefined);
    private _addressLineOne?;
    get addressLineOne(): string;
    set addressLineOne(value: string);
    get addressLineOneInput(): string | undefined;
    private _addressLineTwo?;
    get addressLineTwo(): string;
    set addressLineTwo(value: string);
    resetAddressLineTwo(): void;
    get addressLineTwoInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    get cityInput(): string | undefined;
    private _countryCode?;
    get countryCode(): string;
    set countryCode(value: string);
    get countryCodeInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    get phoneInput(): string | undefined;
    private _postalCode?;
    get postalCode(): string;
    set postalCode(value: string);
    get postalCodeInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface CpsThirdPartyEnrollmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#default CpsThirdPartyEnrollment#default}
    */
    readonly default?: string;
}
export declare function cpsThirdPartyEnrollmentTimeoutsToTerraform(struct?: CpsThirdPartyEnrollmentTimeoutsOutputReference | CpsThirdPartyEnrollmentTimeouts): any;
export declare function cpsThirdPartyEnrollmentTimeoutsToHclTerraform(struct?: CpsThirdPartyEnrollmentTimeoutsOutputReference | CpsThirdPartyEnrollmentTimeouts): any;
export declare class CpsThirdPartyEnrollmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsThirdPartyEnrollmentTimeouts | undefined;
    set internalValue(value: CpsThirdPartyEnrollmentTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment akamai_cps_third_party_enrollment}
*/
export declare class CpsThirdPartyEnrollment extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cps_third_party_enrollment";
    /**
    * Generates CDKTF code for importing a CpsThirdPartyEnrollment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CpsThirdPartyEnrollment to import
    * @param importFromId The id of the existing CpsThirdPartyEnrollment that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CpsThirdPartyEnrollment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_third_party_enrollment akamai_cps_third_party_enrollment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CpsThirdPartyEnrollmentConfig
    */
    constructor(scope: Construct, id: string, config: CpsThirdPartyEnrollmentConfig);
    private _acknowledgePreVerificationWarnings?;
    get acknowledgePreVerificationWarnings(): boolean | cdktf.IResolvable;
    set acknowledgePreVerificationWarnings(value: boolean | cdktf.IResolvable);
    resetAcknowledgePreVerificationWarnings(): void;
    get acknowledgePreVerificationWarningsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowDuplicateCommonName?;
    get allowDuplicateCommonName(): boolean | cdktf.IResolvable;
    set allowDuplicateCommonName(value: boolean | cdktf.IResolvable);
    resetAllowDuplicateCommonName(): void;
    get allowDuplicateCommonNameInput(): boolean | cdktf.IResolvable | undefined;
    private _autoApproveWarnings?;
    get autoApproveWarnings(): string[];
    set autoApproveWarnings(value: string[]);
    resetAutoApproveWarnings(): void;
    get autoApproveWarningsInput(): string[] | undefined;
    private _certificateChainType?;
    get certificateChainType(): string;
    set certificateChainType(value: string);
    resetCertificateChainType(): void;
    get certificateChainTypeInput(): string | undefined;
    private _changeManagement?;
    get changeManagement(): boolean | cdktf.IResolvable;
    set changeManagement(value: boolean | cdktf.IResolvable);
    resetChangeManagement(): void;
    get changeManagementInput(): boolean | cdktf.IResolvable | undefined;
    private _commonName?;
    get commonName(): string;
    set commonName(value: string);
    get commonNameInput(): string | undefined;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _excludeSans?;
    get excludeSans(): boolean | cdktf.IResolvable;
    set excludeSans(value: boolean | cdktf.IResolvable);
    resetExcludeSans(): void;
    get excludeSansInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _sans?;
    get sans(): string[];
    set sans(value: string[]);
    resetSans(): void;
    get sansInput(): string[] | undefined;
    private _secureNetwork?;
    get secureNetwork(): string;
    set secureNetwork(value: string);
    get secureNetworkInput(): string | undefined;
    private _signatureAlgorithm?;
    get signatureAlgorithm(): string;
    set signatureAlgorithm(value: string);
    resetSignatureAlgorithm(): void;
    get signatureAlgorithmInput(): string | undefined;
    private _sniOnly?;
    get sniOnly(): boolean | cdktf.IResolvable;
    set sniOnly(value: boolean | cdktf.IResolvable);
    get sniOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _adminContact;
    get adminContact(): CpsThirdPartyEnrollmentAdminContactOutputReference;
    putAdminContact(value: CpsThirdPartyEnrollmentAdminContact): void;
    get adminContactInput(): CpsThirdPartyEnrollmentAdminContact | undefined;
    private _csr;
    get csr(): CpsThirdPartyEnrollmentCsrOutputReference;
    putCsr(value: CpsThirdPartyEnrollmentCsr): void;
    get csrInput(): CpsThirdPartyEnrollmentCsr | undefined;
    private _networkConfiguration;
    get networkConfiguration(): CpsThirdPartyEnrollmentNetworkConfigurationOutputReference;
    putNetworkConfiguration(value: CpsThirdPartyEnrollmentNetworkConfiguration): void;
    get networkConfigurationInput(): CpsThirdPartyEnrollmentNetworkConfiguration | undefined;
    private _organization;
    get organization(): CpsThirdPartyEnrollmentOrganizationOutputReference;
    putOrganization(value: CpsThirdPartyEnrollmentOrganization): void;
    get organizationInput(): CpsThirdPartyEnrollmentOrganization | undefined;
    private _techContact;
    get techContact(): CpsThirdPartyEnrollmentTechContactOutputReference;
    putTechContact(value: CpsThirdPartyEnrollmentTechContact): void;
    get techContactInput(): CpsThirdPartyEnrollmentTechContact | undefined;
    private _timeouts;
    get timeouts(): CpsThirdPartyEnrollmentTimeoutsOutputReference;
    putTimeouts(value: CpsThirdPartyEnrollmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CpsThirdPartyEnrollmentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
