import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CpsUploadCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether to acknowledge change management
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#acknowledge_change_management CpsUploadCertificate#acknowledge_change_management}
    */
    readonly acknowledgeChangeManagement?: boolean | cdktf.IResolvable;
    /**
    * Whether to acknowledge post-verification warnings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#acknowledge_post_verification_warnings CpsUploadCertificate#acknowledge_post_verification_warnings}
    */
    readonly acknowledgePostVerificationWarnings?: boolean | cdktf.IResolvable;
    /**
    * List of post-verification warnings to be automatically acknowledged
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#auto_approve_warnings CpsUploadCertificate#auto_approve_warnings}
    */
    readonly autoApproveWarnings?: string[];
    /**
    * ECDSA certificate in pem format to be uploaded
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#certificate_ecdsa_pem CpsUploadCertificate#certificate_ecdsa_pem}
    */
    readonly certificateEcdsaPem?: string;
    /**
    * RSA certificate in pem format to be uploaded
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#certificate_rsa_pem CpsUploadCertificate#certificate_rsa_pem}
    */
    readonly certificateRsaPem?: string;
    /**
    * The unique identifier of the enrollment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#enrollment_id CpsUploadCertificate#enrollment_id}
    */
    readonly enrollmentId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#id CpsUploadCertificate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Trust chain in pem format for provided ECDSA certificate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#trust_chain_ecdsa_pem CpsUploadCertificate#trust_chain_ecdsa_pem}
    */
    readonly trustChainEcdsaPem?: string;
    /**
    * Trust chain in pem format for provided RSA certificate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#trust_chain_rsa_pem CpsUploadCertificate#trust_chain_rsa_pem}
    */
    readonly trustChainRsaPem?: string;
    /**
    * Whether to wait for certificate to be deployed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#wait_for_deployment CpsUploadCertificate#wait_for_deployment}
    */
    readonly waitForDeployment?: boolean | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#timeouts CpsUploadCertificate#timeouts}
    */
    readonly timeouts?: CpsUploadCertificateTimeouts;
}
export interface CpsUploadCertificateTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#default CpsUploadCertificate#default}
    */
    readonly default?: string;
}
export declare function cpsUploadCertificateTimeoutsToTerraform(struct?: CpsUploadCertificateTimeoutsOutputReference | CpsUploadCertificateTimeouts): any;
export declare function cpsUploadCertificateTimeoutsToHclTerraform(struct?: CpsUploadCertificateTimeoutsOutputReference | CpsUploadCertificateTimeouts): any;
export declare class CpsUploadCertificateTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CpsUploadCertificateTimeouts | undefined;
    set internalValue(value: CpsUploadCertificateTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate akamai_cps_upload_certificate}
*/
export declare class CpsUploadCertificate extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_cps_upload_certificate";
    /**
    * Generates CDKTF code for importing a CpsUploadCertificate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CpsUploadCertificate to import
    * @param importFromId The id of the existing CpsUploadCertificate that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CpsUploadCertificate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/cps_upload_certificate akamai_cps_upload_certificate} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CpsUploadCertificateConfig
    */
    constructor(scope: Construct, id: string, config: CpsUploadCertificateConfig);
    private _acknowledgeChangeManagement?;
    get acknowledgeChangeManagement(): boolean | cdktf.IResolvable;
    set acknowledgeChangeManagement(value: boolean | cdktf.IResolvable);
    resetAcknowledgeChangeManagement(): void;
    get acknowledgeChangeManagementInput(): boolean | cdktf.IResolvable | undefined;
    private _acknowledgePostVerificationWarnings?;
    get acknowledgePostVerificationWarnings(): boolean | cdktf.IResolvable;
    set acknowledgePostVerificationWarnings(value: boolean | cdktf.IResolvable);
    resetAcknowledgePostVerificationWarnings(): void;
    get acknowledgePostVerificationWarningsInput(): boolean | cdktf.IResolvable | undefined;
    private _autoApproveWarnings?;
    get autoApproveWarnings(): string[];
    set autoApproveWarnings(value: string[]);
    resetAutoApproveWarnings(): void;
    get autoApproveWarningsInput(): string[] | undefined;
    private _certificateEcdsaPem?;
    get certificateEcdsaPem(): string;
    set certificateEcdsaPem(value: string);
    resetCertificateEcdsaPem(): void;
    get certificateEcdsaPemInput(): string | undefined;
    private _certificateRsaPem?;
    get certificateRsaPem(): string;
    set certificateRsaPem(value: string);
    resetCertificateRsaPem(): void;
    get certificateRsaPemInput(): string | undefined;
    private _enrollmentId?;
    get enrollmentId(): number;
    set enrollmentId(value: number);
    get enrollmentIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _trustChainEcdsaPem?;
    get trustChainEcdsaPem(): string;
    set trustChainEcdsaPem(value: string);
    resetTrustChainEcdsaPem(): void;
    get trustChainEcdsaPemInput(): string | undefined;
    private _trustChainRsaPem?;
    get trustChainRsaPem(): string;
    set trustChainRsaPem(value: string);
    resetTrustChainRsaPem(): void;
    get trustChainRsaPemInput(): string | undefined;
    get unacknowledgedWarnings(): cdktf.IResolvable;
    private _waitForDeployment?;
    get waitForDeployment(): boolean | cdktf.IResolvable;
    set waitForDeployment(value: boolean | cdktf.IResolvable);
    resetWaitForDeployment(): void;
    get waitForDeploymentInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    get timeouts(): CpsUploadCertificateTimeoutsOutputReference;
    putTimeouts(value: CpsUploadCertificateTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CpsUploadCertificateTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
