import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAkamaiAppsecTuningRecommendationsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Unique name of a specific attack group for which to return tuning recommendations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#attack_group DataAkamaiAppsecTuningRecommendations#attack_group}
    */
    readonly attackGroup?: string;
    /**
    * Unique identifier of the security configuration for which to return tuning recommendations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#config_id DataAkamaiAppsecTuningRecommendations#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#id DataAkamaiAppsecTuningRecommendations#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique name of a specific rule id for which to return tuning recommendations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#rule_id DataAkamaiAppsecTuningRecommendations#rule_id}
    */
    readonly ruleId?: number;
    /**
    * Type of the ruleset of the security configuration for which to return tuning recommendations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#ruleset_type DataAkamaiAppsecTuningRecommendations#ruleset_type}
    */
    readonly rulesetType?: string;
    /**
    * Unique identifier of the security policy for which to return tuning recommendations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#security_policy_id DataAkamaiAppsecTuningRecommendations#security_policy_id}
    */
    readonly securityPolicyId?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations akamai_appsec_tuning_recommendations}
*/
export declare class DataAkamaiAppsecTuningRecommendations extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "akamai_appsec_tuning_recommendations";
    /**
    * Generates CDKTF code for importing a DataAkamaiAppsecTuningRecommendations resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataAkamaiAppsecTuningRecommendations to import
    * @param importFromId The id of the existing DataAkamaiAppsecTuningRecommendations that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataAkamaiAppsecTuningRecommendations to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/appsec_tuning_recommendations akamai_appsec_tuning_recommendations} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAkamaiAppsecTuningRecommendationsConfig
    */
    constructor(scope: Construct, id: string, config: DataAkamaiAppsecTuningRecommendationsConfig);
    private _attackGroup?;
    get attackGroup(): string;
    set attackGroup(value: string);
    resetAttackGroup(): void;
    get attackGroupInput(): string | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get json(): string;
    private _ruleId?;
    get ruleId(): number;
    set ruleId(value: number);
    resetRuleId(): void;
    get ruleIdInput(): number | undefined;
    private _rulesetType?;
    get rulesetType(): string;
    set rulesetType(value: string);
    resetRulesetType(): void;
    get rulesetTypeInput(): string | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    resetSecurityPolicyId(): void;
    get securityPolicyIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
