import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAkamaiGtmDatacenterConfig extends cdktf.TerraformMetaArguments {
    /**
    * A unique identifier for an existing data center in the domain.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/gtm_datacenter#datacenter_id DataAkamaiGtmDatacenter#datacenter_id}
    */
    readonly datacenterId: number;
    /**
    * GTM domain name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/gtm_datacenter#domain DataAkamaiGtmDatacenter#domain}
    */
    readonly domain: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/gtm_datacenter#id DataAkamaiGtmDatacenter#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataAkamaiGtmDatacenterDefaultLoadObject {
}
export declare function dataAkamaiGtmDatacenterDefaultLoadObjectToTerraform(struct?: DataAkamaiGtmDatacenterDefaultLoadObject): any;
export declare function dataAkamaiGtmDatacenterDefaultLoadObjectToHclTerraform(struct?: DataAkamaiGtmDatacenterDefaultLoadObject): any;
export declare class DataAkamaiGtmDatacenterDefaultLoadObjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAkamaiGtmDatacenterDefaultLoadObject | undefined;
    set internalValue(value: DataAkamaiGtmDatacenterDefaultLoadObject | undefined);
    get loadObject(): string;
    get loadObjectPort(): number;
    get loadServers(): string[];
}
export declare class DataAkamaiGtmDatacenterDefaultLoadObjectList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAkamaiGtmDatacenterDefaultLoadObjectOutputReference;
}
export interface DataAkamaiGtmDatacenterLinks {
}
export declare function dataAkamaiGtmDatacenterLinksToTerraform(struct?: DataAkamaiGtmDatacenterLinks): any;
export declare function dataAkamaiGtmDatacenterLinksToHclTerraform(struct?: DataAkamaiGtmDatacenterLinks): any;
export declare class DataAkamaiGtmDatacenterLinksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAkamaiGtmDatacenterLinks | undefined;
    set internalValue(value: DataAkamaiGtmDatacenterLinks | undefined);
    get href(): string;
    get rel(): string;
}
export declare class DataAkamaiGtmDatacenterLinksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAkamaiGtmDatacenterLinksOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/gtm_datacenter akamai_gtm_datacenter}
*/
export declare class DataAkamaiGtmDatacenter extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "akamai_gtm_datacenter";
    /**
    * Generates CDKTF code for importing a DataAkamaiGtmDatacenter resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataAkamaiGtmDatacenter to import
    * @param importFromId The id of the existing DataAkamaiGtmDatacenter that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/gtm_datacenter#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataAkamaiGtmDatacenter to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/gtm_datacenter akamai_gtm_datacenter} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAkamaiGtmDatacenterConfig
    */
    constructor(scope: Construct, id: string, config: DataAkamaiGtmDatacenterConfig);
    get city(): string;
    get cloneOf(): number;
    get cloudServerHostHeaderOverride(): cdktf.IResolvable;
    get cloudServerTargeting(): cdktf.IResolvable;
    get continent(): string;
    get country(): string;
    private _datacenterId?;
    get datacenterId(): number;
    set datacenterId(value: number);
    get datacenterIdInput(): number | undefined;
    private _defaultLoadObject;
    get defaultLoadObject(): DataAkamaiGtmDatacenterDefaultLoadObjectList;
    private _domain?;
    get domain(): string;
    set domain(value: string);
    get domainInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get latitude(): number;
    private _links;
    get links(): DataAkamaiGtmDatacenterLinksList;
    get longitude(): number;
    get nickname(): string;
    get scorePenalty(): number;
    get servermonitorPool(): string;
    get stateOrProvince(): string;
    get virtual(): cdktf.IResolvable;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
