import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAkamaiPropertyActivationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation#id DataAkamaiPropertyActivation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Akamai network to check the activation, either `STAGING` or `PRODUCTION`. `STAGING` is the default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation#network DataAkamaiPropertyActivation#network}
    */
    readonly network?: string;
    /**
    * The property's unique identifier, including optional `prp_` prefix
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation#property_id DataAkamaiPropertyActivation#property_id}
    */
    readonly propertyId: string;
    /**
    * The activated property version. When not provided, defaults to latest.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation#version DataAkamaiPropertyActivation#version}
    */
    readonly version?: number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation akamai_property_activation}
*/
export declare class DataAkamaiPropertyActivation extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "akamai_property_activation";
    /**
    * Generates CDKTF code for importing a DataAkamaiPropertyActivation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataAkamaiPropertyActivation to import
    * @param importFromId The id of the existing DataAkamaiPropertyActivation that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataAkamaiPropertyActivation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_activation akamai_property_activation} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAkamaiPropertyActivationConfig
    */
    constructor(scope: Construct, id: string, config: DataAkamaiPropertyActivationConfig);
    get activationId(): string;
    get contact(): string[];
    get errors(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    get note(): string;
    private _propertyId?;
    get propertyId(): string;
    set propertyId(value: string);
    get propertyIdInput(): string | undefined;
    get status(): string;
    private _version?;
    get version(): number;
    set version(value: number);
    resetVersion(): void;
    get versionInput(): number | undefined;
    get warnings(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
