import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAkamaiPropertyIncludesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifies the contract under which the data were requested
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#contract_id DataAkamaiPropertyIncludes#contract_id}
    */
    readonly contractId: string;
    /**
    * Identifies the group under which the data were requested
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#group_id DataAkamaiPropertyIncludes#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#id DataAkamaiPropertyIncludes#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies the type of the include, either `MICROSERVICES` or `COMMON_SETTINGS`. Use this field for filtering
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#type DataAkamaiPropertyIncludes#type}
    */
    readonly type?: string;
    /**
    * parent_property block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#parent_property DataAkamaiPropertyIncludes#parent_property}
    */
    readonly parentProperty?: DataAkamaiPropertyIncludesParentProperty;
}
export interface DataAkamaiPropertyIncludesIncludes {
}
export declare function dataAkamaiPropertyIncludesIncludesToTerraform(struct?: DataAkamaiPropertyIncludesIncludes): any;
export declare function dataAkamaiPropertyIncludesIncludesToHclTerraform(struct?: DataAkamaiPropertyIncludesIncludes): any;
export declare class DataAkamaiPropertyIncludesIncludesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataAkamaiPropertyIncludesIncludes | undefined;
    set internalValue(value: DataAkamaiPropertyIncludesIncludes | undefined);
    get id(): string;
    get latestVersion(): number;
    get name(): string;
    get productionVersion(): string;
    get stagingVersion(): string;
    get type(): string;
}
export declare class DataAkamaiPropertyIncludesIncludesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataAkamaiPropertyIncludesIncludesOutputReference;
}
export interface DataAkamaiPropertyIncludesParentProperty {
    /**
    * The property's unique identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#id DataAkamaiPropertyIncludes#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The property's version for which the data is requested
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#version DataAkamaiPropertyIncludes#version}
    */
    readonly version: number;
}
export declare function dataAkamaiPropertyIncludesParentPropertyToTerraform(struct?: DataAkamaiPropertyIncludesParentPropertyOutputReference | DataAkamaiPropertyIncludesParentProperty): any;
export declare function dataAkamaiPropertyIncludesParentPropertyToHclTerraform(struct?: DataAkamaiPropertyIncludesParentPropertyOutputReference | DataAkamaiPropertyIncludesParentProperty): any;
export declare class DataAkamaiPropertyIncludesParentPropertyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAkamaiPropertyIncludesParentProperty | undefined;
    set internalValue(value: DataAkamaiPropertyIncludesParentProperty | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _version?;
    get version(): number;
    set version(value: number);
    get versionInput(): number | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes akamai_property_includes}
*/
export declare class DataAkamaiPropertyIncludes extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "akamai_property_includes";
    /**
    * Generates CDKTF code for importing a DataAkamaiPropertyIncludes resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataAkamaiPropertyIncludes to import
    * @param importFromId The id of the existing DataAkamaiPropertyIncludes that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataAkamaiPropertyIncludes to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/data-sources/property_includes akamai_property_includes} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAkamaiPropertyIncludesConfig
    */
    constructor(scope: Construct, id: string, config: DataAkamaiPropertyIncludesConfig);
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _includes;
    get includes(): DataAkamaiPropertyIncludesIncludesList;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _parentProperty;
    get parentProperty(): DataAkamaiPropertyIncludesParentPropertyOutputReference;
    putParentProperty(value: DataAkamaiPropertyIncludesParentProperty): void;
    resetParentProperty(): void;
    get parentPropertyInput(): DataAkamaiPropertyIncludesParentProperty | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
