import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DatastreamConfig extends cdktf.TerraformMetaArguments {
    /**
    * Defining if stream should be active or not
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#active Datastream#active}
    */
    readonly active: boolean | cdktf.IResolvable;
    /**
    * Identifies if stream needs to collect midgress data
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#collect_midgress Datastream#collect_midgress}
    */
    readonly collectMidgress?: boolean | cdktf.IResolvable;
    /**
    * Identifies the contract that has access to the product
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#contract_id Datastream#contract_id}
    */
    readonly contractId: string;
    /**
    * A list of data set fields selected from the associated template that the stream monitors in logs. The order of the identifiers define how the value for these fields appear in the log lines
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#dataset_fields Datastream#dataset_fields}
    */
    readonly datasetFields: number[];
    /**
    * Identifies the group that has access to the product and for which the stream configuration was created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#group_id Datastream#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#id Datastream#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of email addresses where the system sends notifications about activations and deactivations of the stream
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#notification_emails Datastream#notification_emails}
    */
    readonly notificationEmails?: string[];
    /**
    * Identifies the properties monitored in the stream
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#properties Datastream#properties}
    */
    readonly properties: string[];
    /**
    * The name of the stream
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#stream_name Datastream#stream_name}
    */
    readonly streamName: string;
    /**
    * azure_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#azure_connector Datastream#azure_connector}
    */
    readonly azureConnector?: DatastreamAzureConnector;
    /**
    * datadog_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#datadog_connector Datastream#datadog_connector}
    */
    readonly datadogConnector?: DatastreamDatadogConnector;
    /**
    * delivery_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#delivery_configuration Datastream#delivery_configuration}
    */
    readonly deliveryConfiguration: DatastreamDeliveryConfiguration;
    /**
    * elasticsearch_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#elasticsearch_connector Datastream#elasticsearch_connector}
    */
    readonly elasticsearchConnector?: DatastreamElasticsearchConnector;
    /**
    * gcs_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#gcs_connector Datastream#gcs_connector}
    */
    readonly gcsConnector?: DatastreamGcsConnector;
    /**
    * https_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#https_connector Datastream#https_connector}
    */
    readonly httpsConnector?: DatastreamHttpsConnector;
    /**
    * loggly_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#loggly_connector Datastream#loggly_connector}
    */
    readonly logglyConnector?: DatastreamLogglyConnector;
    /**
    * new_relic_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#new_relic_connector Datastream#new_relic_connector}
    */
    readonly newRelicConnector?: DatastreamNewRelicConnector;
    /**
    * oracle_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#oracle_connector Datastream#oracle_connector}
    */
    readonly oracleConnector?: DatastreamOracleConnector;
    /**
    * s3_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#s3_connector Datastream#s3_connector}
    */
    readonly s3Connector?: DatastreamS3Connector;
    /**
    * splunk_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#splunk_connector Datastream#splunk_connector}
    */
    readonly splunkConnector?: DatastreamSplunkConnector;
    /**
    * sumologic_connector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#sumologic_connector Datastream#sumologic_connector}
    */
    readonly sumologicConnector?: DatastreamSumologicConnector;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#timeouts Datastream#timeouts}
    */
    readonly timeouts?: DatastreamTimeouts;
}
export interface DatastreamAzureConnector {
    /**
    * Access keys associated with Azure Storage account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#access_key Datastream#access_key}
    */
    readonly accessKey: string;
    /**
    * Specifies the Azure Storage account name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#account_name Datastream#account_name}
    */
    readonly accountName: string;
    /**
    * Specifies the Azure Storage container name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#container_name Datastream#container_name}
    */
    readonly containerName: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The path to the folder within Azure Storage container where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#path Datastream#path}
    */
    readonly path: string;
}
export declare function datastreamAzureConnectorToTerraform(struct?: DatastreamAzureConnectorOutputReference | DatastreamAzureConnector): any;
export declare function datastreamAzureConnectorToHclTerraform(struct?: DatastreamAzureConnectorOutputReference | DatastreamAzureConnector): any;
export declare class DatastreamAzureConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamAzureConnector | undefined;
    set internalValue(value: DatastreamAzureConnector | undefined);
    private _accessKey?;
    get accessKey(): string;
    set accessKey(value: string);
    get accessKeyInput(): string | undefined;
    private _accountName?;
    get accountName(): string;
    set accountName(value: string);
    get accountNameInput(): string | undefined;
    get compressLogs(): cdktf.IResolvable;
    private _containerName?;
    get containerName(): string;
    set containerName(value: string);
    get containerNameInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
}
export interface DatastreamDatadogConnector {
    /**
    * The API key associated with Datadog account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#auth_token Datastream#auth_token}
    */
    readonly authToken: string;
    /**
    * Indicates whether the logs should be compressed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#compress_logs Datastream#compress_logs}
    */
    readonly compressLogs?: boolean | cdktf.IResolvable;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The Datadog endpoint where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
    /**
    * The service of the Datadog connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#service Datastream#service}
    */
    readonly service?: string;
    /**
    * The source of the Datadog connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#source Datastream#source}
    */
    readonly source?: string;
    /**
    * The tags of the Datadog connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#tags Datastream#tags}
    */
    readonly tags?: string;
}
export declare function datastreamDatadogConnectorToTerraform(struct?: DatastreamDatadogConnectorOutputReference | DatastreamDatadogConnector): any;
export declare function datastreamDatadogConnectorToHclTerraform(struct?: DatastreamDatadogConnectorOutputReference | DatastreamDatadogConnector): any;
export declare class DatastreamDatadogConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamDatadogConnector | undefined;
    set internalValue(value: DatastreamDatadogConnector | undefined);
    private _authToken?;
    get authToken(): string;
    set authToken(value: string);
    get authTokenInput(): string | undefined;
    private _compressLogs?;
    get compressLogs(): boolean | cdktf.IResolvable;
    set compressLogs(value: boolean | cdktf.IResolvable);
    resetCompressLogs(): void;
    get compressLogsInput(): boolean | cdktf.IResolvable | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    resetSource(): void;
    get sourceInput(): string | undefined;
    private _tags?;
    get tags(): string;
    set tags(value: string);
    resetTags(): void;
    get tagsInput(): string | undefined;
}
export interface DatastreamDeliveryConfigurationFrequency {
    /**
    * The time in seconds after which the system bundles log lines into a file and sends it to a destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#interval_in_secs Datastream#interval_in_secs}
    */
    readonly intervalInSecs: number;
}
export declare function datastreamDeliveryConfigurationFrequencyToTerraform(struct?: DatastreamDeliveryConfigurationFrequencyOutputReference | DatastreamDeliveryConfigurationFrequency): any;
export declare function datastreamDeliveryConfigurationFrequencyToHclTerraform(struct?: DatastreamDeliveryConfigurationFrequencyOutputReference | DatastreamDeliveryConfigurationFrequency): any;
export declare class DatastreamDeliveryConfigurationFrequencyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamDeliveryConfigurationFrequency | undefined;
    set internalValue(value: DatastreamDeliveryConfigurationFrequency | undefined);
    private _intervalInSecs?;
    get intervalInSecs(): number;
    set intervalInSecs(value: number);
    get intervalInSecsInput(): number | undefined;
}
export interface DatastreamDeliveryConfiguration {
    /**
    * A delimiter that you use to separate data set fields in log lines
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#field_delimiter Datastream#field_delimiter}
    */
    readonly fieldDelimiter?: string;
    /**
    * The format in which logs will be received
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#format Datastream#format}
    */
    readonly format: string;
    /**
    * The prefix of the log file that will be send to a destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#upload_file_prefix Datastream#upload_file_prefix}
    */
    readonly uploadFilePrefix?: string;
    /**
    * The suffix of the log file that will be send to a destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#upload_file_suffix Datastream#upload_file_suffix}
    */
    readonly uploadFileSuffix?: string;
    /**
    * frequency block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#frequency Datastream#frequency}
    */
    readonly frequency: DatastreamDeliveryConfigurationFrequency;
}
export declare function datastreamDeliveryConfigurationToTerraform(struct?: DatastreamDeliveryConfigurationOutputReference | DatastreamDeliveryConfiguration): any;
export declare function datastreamDeliveryConfigurationToHclTerraform(struct?: DatastreamDeliveryConfigurationOutputReference | DatastreamDeliveryConfiguration): any;
export declare class DatastreamDeliveryConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamDeliveryConfiguration | undefined;
    set internalValue(value: DatastreamDeliveryConfiguration | undefined);
    private _fieldDelimiter?;
    get fieldDelimiter(): string;
    set fieldDelimiter(value: string);
    resetFieldDelimiter(): void;
    get fieldDelimiterInput(): string | undefined;
    private _format?;
    get format(): string;
    set format(value: string);
    get formatInput(): string | undefined;
    private _uploadFilePrefix?;
    get uploadFilePrefix(): string;
    set uploadFilePrefix(value: string);
    resetUploadFilePrefix(): void;
    get uploadFilePrefixInput(): string | undefined;
    private _uploadFileSuffix?;
    get uploadFileSuffix(): string;
    set uploadFileSuffix(value: string);
    resetUploadFileSuffix(): void;
    get uploadFileSuffixInput(): string | undefined;
    private _frequency;
    get frequency(): DatastreamDeliveryConfigurationFrequencyOutputReference;
    putFrequency(value: DatastreamDeliveryConfigurationFrequency): void;
    get frequencyInput(): DatastreamDeliveryConfigurationFrequency | undefined;
}
export interface DatastreamElasticsearchConnector {
    /**
    * The certification authority (CA) certificate used to verify the origin server's certificate. If the certificate is not signed by a well-known certification authority, enter the CA certificate in the PEM format for verification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#ca_cert Datastream#ca_cert}
    */
    readonly caCert?: string;
    /**
    * The PEM-formatted digital certificate you want to authenticate requests to your destination with. If you want to use mutual authentication, you need to provide both the client certificate and the client key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#client_cert Datastream#client_cert}
    */
    readonly clientCert?: string;
    /**
    * The private key in the non-encrypted PKCS8 format you want to use to authenticate with the backend server. If you want to use mutual authentication, you need to provide both the client certificate and the client key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#client_key Datastream#client_key}
    */
    readonly clientKey?: string;
    /**
    * The type of the resource passed in the request's custom header. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#content_type Datastream#content_type}
    */
    readonly contentType?: string;
    /**
    * A human-readable name for the request's custom header, containing only alphanumeric, dash, and underscore characters. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_name Datastream#custom_header_name}
    */
    readonly customHeaderName?: string;
    /**
    * The custom header's contents passed with the request that contains information about the client connection. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_value Datastream#custom_header_value}
    */
    readonly customHeaderValue?: string;
    /**
    * The name of the connector.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The Elasticsearch bulk endpoint URL in the https://hostname.elastic-cloud.com:9243/_bulk/ format. Set indexName in the appropriate field instead of providing it in the URL. You can use Akamaized property hostnames as endpoint URLs. See Stream logs to Elasticsearch.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
    /**
    * The index name of the Elastic cloud where you want to store log files.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#index_name Datastream#index_name}
    */
    readonly indexName: string;
    /**
    * The Elasticsearch basic access authentication password.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#password Datastream#password}
    */
    readonly password: string;
    /**
    * The hostname that verifies the server's certificate and matches the Subject Alternative Names (SANs) in the certificate. If not provided, DataStream fetches the hostname from the endpoint URL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#tls_hostname Datastream#tls_hostname}
    */
    readonly tlsHostname?: string;
    /**
    * The Elasticsearch basic access authentication username.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#user_name Datastream#user_name}
    */
    readonly userName: string;
}
export declare function datastreamElasticsearchConnectorToTerraform(struct?: DatastreamElasticsearchConnectorOutputReference | DatastreamElasticsearchConnector): any;
export declare function datastreamElasticsearchConnectorToHclTerraform(struct?: DatastreamElasticsearchConnectorOutputReference | DatastreamElasticsearchConnector): any;
export declare class DatastreamElasticsearchConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamElasticsearchConnector | undefined;
    set internalValue(value: DatastreamElasticsearchConnector | undefined);
    private _caCert?;
    get caCert(): string;
    set caCert(value: string);
    resetCaCert(): void;
    get caCertInput(): string | undefined;
    private _clientCert?;
    get clientCert(): string;
    set clientCert(value: string);
    resetClientCert(): void;
    get clientCertInput(): string | undefined;
    private _clientKey?;
    get clientKey(): string;
    set clientKey(value: string);
    resetClientKey(): void;
    get clientKeyInput(): string | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _customHeaderName?;
    get customHeaderName(): string;
    set customHeaderName(value: string);
    resetCustomHeaderName(): void;
    get customHeaderNameInput(): string | undefined;
    private _customHeaderValue?;
    get customHeaderValue(): string;
    set customHeaderValue(value: string);
    resetCustomHeaderValue(): void;
    get customHeaderValueInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
    private _indexName?;
    get indexName(): string;
    set indexName(value: string);
    get indexNameInput(): string | undefined;
    get mTls(): cdktf.IResolvable;
    private _password?;
    get password(): string;
    set password(value: string);
    get passwordInput(): string | undefined;
    private _tlsHostname?;
    get tlsHostname(): string;
    set tlsHostname(value: string);
    resetTlsHostname(): void;
    get tlsHostnameInput(): string | undefined;
    private _userName?;
    get userName(): string;
    set userName(value: string);
    get userNameInput(): string | undefined;
}
export interface DatastreamGcsConnector {
    /**
    * The name of the storage bucket created in Google Cloud account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#bucket Datastream#bucket}
    */
    readonly bucket: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The path to the folder within Google Cloud bucket where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#path Datastream#path}
    */
    readonly path?: string;
    /**
    * The contents of the JSON private key generated and downloaded in Google Cloud Storage account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#private_key Datastream#private_key}
    */
    readonly privateKey: string;
    /**
    * The unique ID of Google Cloud project
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#project_id Datastream#project_id}
    */
    readonly projectId: string;
    /**
    * The name of the service account with the storage.object.create permission or Storage Object Creator role
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#service_account_name Datastream#service_account_name}
    */
    readonly serviceAccountName: string;
}
export declare function datastreamGcsConnectorToTerraform(struct?: DatastreamGcsConnectorOutputReference | DatastreamGcsConnector): any;
export declare function datastreamGcsConnectorToHclTerraform(struct?: DatastreamGcsConnectorOutputReference | DatastreamGcsConnector): any;
export declare class DatastreamGcsConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamGcsConnector | undefined;
    set internalValue(value: DatastreamGcsConnector | undefined);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    get compressLogs(): cdktf.IResolvable;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _privateKey?;
    get privateKey(): string;
    set privateKey(value: string);
    get privateKeyInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _serviceAccountName?;
    get serviceAccountName(): string;
    set serviceAccountName(value: string);
    get serviceAccountNameInput(): string | undefined;
}
export interface DatastreamHttpsConnector {
    /**
    * Either NONE for no authentication, or BASIC for username and password authentication
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#authentication_type Datastream#authentication_type}
    */
    readonly authenticationType: string;
    /**
    * The certification authority (CA) certificate used to verify the origin server's certificate. If the certificate is not signed by a well-known certification authority, enter the CA certificate in the PEM format for verification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#ca_cert Datastream#ca_cert}
    */
    readonly caCert?: string;
    /**
    * The digital certificate in the PEM format you want to use to authenticate requests to your destination. If you want to use mutual authentication, you need to provide both the client certificate and the client key (in the PEM format).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#client_cert Datastream#client_cert}
    */
    readonly clientCert?: string;
    /**
    * The private key in the non-encrypted PKCS8 format you want to use to authenticate with the back-end server. If you want to use mutual authentication, you need to provide both the client certificate and the client key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#client_key Datastream#client_key}
    */
    readonly clientKey?: string;
    /**
    * Indicates whether the logs should be compressed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#compress_logs Datastream#compress_logs}
    */
    readonly compressLogs?: boolean | cdktf.IResolvable;
    /**
    * Content type to pass in the log file header
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#content_type Datastream#content_type}
    */
    readonly contentType?: string;
    /**
    * The name of custom header passed with the request to the destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_name Datastream#custom_header_name}
    */
    readonly customHeaderName?: string;
    /**
    * The custom header's contents passed with the request to the destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_value Datastream#custom_header_value}
    */
    readonly customHeaderValue?: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * URL where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
    /**
    * Password set for custom HTTPS endpoint for authentication
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#password Datastream#password}
    */
    readonly password?: string;
    /**
    * The hostname that verifies the server's certificate and matches the Subject Alternative Names (SANs) in the certificate. If not provided, DataStream fetches the hostname from the endpoint URL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#tls_hostname Datastream#tls_hostname}
    */
    readonly tlsHostname?: string;
    /**
    * Username used for authentication
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#user_name Datastream#user_name}
    */
    readonly userName?: string;
}
export declare function datastreamHttpsConnectorToTerraform(struct?: DatastreamHttpsConnectorOutputReference | DatastreamHttpsConnector): any;
export declare function datastreamHttpsConnectorToHclTerraform(struct?: DatastreamHttpsConnectorOutputReference | DatastreamHttpsConnector): any;
export declare class DatastreamHttpsConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamHttpsConnector | undefined;
    set internalValue(value: DatastreamHttpsConnector | undefined);
    private _authenticationType?;
    get authenticationType(): string;
    set authenticationType(value: string);
    get authenticationTypeInput(): string | undefined;
    private _caCert?;
    get caCert(): string;
    set caCert(value: string);
    resetCaCert(): void;
    get caCertInput(): string | undefined;
    private _clientCert?;
    get clientCert(): string;
    set clientCert(value: string);
    resetClientCert(): void;
    get clientCertInput(): string | undefined;
    private _clientKey?;
    get clientKey(): string;
    set clientKey(value: string);
    resetClientKey(): void;
    get clientKeyInput(): string | undefined;
    private _compressLogs?;
    get compressLogs(): boolean | cdktf.IResolvable;
    set compressLogs(value: boolean | cdktf.IResolvable);
    resetCompressLogs(): void;
    get compressLogsInput(): boolean | cdktf.IResolvable | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _customHeaderName?;
    get customHeaderName(): string;
    set customHeaderName(value: string);
    resetCustomHeaderName(): void;
    get customHeaderNameInput(): string | undefined;
    private _customHeaderValue?;
    get customHeaderValue(): string;
    set customHeaderValue(value: string);
    resetCustomHeaderValue(): void;
    get customHeaderValueInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
    get mTls(): cdktf.IResolvable;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _tlsHostname?;
    get tlsHostname(): string;
    set tlsHostname(value: string);
    resetTlsHostname(): void;
    get tlsHostnameInput(): string | undefined;
    private _userName?;
    get userName(): string;
    set userName(value: string);
    resetUserName(): void;
    get userNameInput(): string | undefined;
}
export interface DatastreamLogglyConnector {
    /**
    * The unique HTTP code for your Loggly bulk endpoint.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#auth_token Datastream#auth_token}
    */
    readonly authToken: string;
    /**
    * The type of the resource passed in the request's custom header. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#content_type Datastream#content_type}
    */
    readonly contentType?: string;
    /**
    * A human-readable name for the request's custom header, containing only alphanumeric, dash, and underscore characters. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_name Datastream#custom_header_name}
    */
    readonly customHeaderName?: string;
    /**
    * The custom header's contents passed with the request that contains information about the client connection. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_value Datastream#custom_header_value}
    */
    readonly customHeaderValue?: string;
    /**
    * The name of the connector.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The Loggly bulk endpoint URL in the https://hostname.loggly.com/bulk/ format. Set the endpoint code in the authToken field instead of providing it in the URL. You can use Akamaized property hostnames as endpoint URLs. See Stream logs to Loggly.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
    /**
    * The tags you can use to segment and filter log events in Loggly. See Tags in the Loggly documentation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#tags Datastream#tags}
    */
    readonly tags?: string;
}
export declare function datastreamLogglyConnectorToTerraform(struct?: DatastreamLogglyConnectorOutputReference | DatastreamLogglyConnector): any;
export declare function datastreamLogglyConnectorToHclTerraform(struct?: DatastreamLogglyConnectorOutputReference | DatastreamLogglyConnector): any;
export declare class DatastreamLogglyConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamLogglyConnector | undefined;
    set internalValue(value: DatastreamLogglyConnector | undefined);
    private _authToken?;
    get authToken(): string;
    set authToken(value: string);
    get authTokenInput(): string | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _customHeaderName?;
    get customHeaderName(): string;
    set customHeaderName(value: string);
    resetCustomHeaderName(): void;
    get customHeaderNameInput(): string | undefined;
    private _customHeaderValue?;
    get customHeaderValue(): string;
    set customHeaderValue(value: string);
    resetCustomHeaderValue(): void;
    get customHeaderValueInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
    private _tags?;
    get tags(): string;
    set tags(value: string);
    resetTags(): void;
    get tagsInput(): string | undefined;
}
export interface DatastreamNewRelicConnector {
    /**
    * Your Log API token for your account in New Relic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#auth_token Datastream#auth_token}
    */
    readonly authToken: string;
    /**
    * The type of the resource passed in the request's custom header. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#content_type Datastream#content_type}
    */
    readonly contentType?: string;
    /**
    * A human-readable name for the request's custom header, containing only alphanumeric, dash, and underscore characters. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_name Datastream#custom_header_name}
    */
    readonly customHeaderName?: string;
    /**
    * The custom header's contents passed with the request that contains information about the client connection. For details, see Additional options in the DataStream user guide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_value Datastream#custom_header_value}
    */
    readonly customHeaderValue?: string;
    /**
    * The name of the connector.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * A New Relic endpoint URL you want to send your logs to. The endpoint URL should follow the https://<newrelic.com>/log/v1/ format format. See Introduction to the Log API https://docs.newrelic.com/docs/logs/log-api/introduction-log-api/ if you want to retrieve your New Relic endpoint URL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
}
export declare function datastreamNewRelicConnectorToTerraform(struct?: DatastreamNewRelicConnectorOutputReference | DatastreamNewRelicConnector): any;
export declare function datastreamNewRelicConnectorToHclTerraform(struct?: DatastreamNewRelicConnectorOutputReference | DatastreamNewRelicConnector): any;
export declare class DatastreamNewRelicConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamNewRelicConnector | undefined;
    set internalValue(value: DatastreamNewRelicConnector | undefined);
    private _authToken?;
    get authToken(): string;
    set authToken(value: string);
    get authTokenInput(): string | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _customHeaderName?;
    get customHeaderName(): string;
    set customHeaderName(value: string);
    resetCustomHeaderName(): void;
    get customHeaderNameInput(): string | undefined;
    private _customHeaderValue?;
    get customHeaderValue(): string;
    set customHeaderValue(value: string);
    resetCustomHeaderValue(): void;
    get customHeaderValueInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
}
export interface DatastreamOracleConnector {
    /**
    * The access key identifier used to authenticate requests to the Oracle Cloud account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#access_key Datastream#access_key}
    */
    readonly accessKey: string;
    /**
    * The name of the Oracle Cloud Storage bucket
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#bucket Datastream#bucket}
    */
    readonly bucket: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The namespace of Oracle Cloud Storage account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#namespace Datastream#namespace}
    */
    readonly namespace: string;
    /**
    * The path to the folder within your Oracle Cloud Storage bucket where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#path Datastream#path}
    */
    readonly path: string;
    /**
    * The Oracle Cloud Storage region where bucket resides
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#region Datastream#region}
    */
    readonly region: string;
    /**
    * The secret access key identifier used to authenticate requests to the Oracle Cloud account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#secret_access_key Datastream#secret_access_key}
    */
    readonly secretAccessKey: string;
}
export declare function datastreamOracleConnectorToTerraform(struct?: DatastreamOracleConnectorOutputReference | DatastreamOracleConnector): any;
export declare function datastreamOracleConnectorToHclTerraform(struct?: DatastreamOracleConnectorOutputReference | DatastreamOracleConnector): any;
export declare class DatastreamOracleConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamOracleConnector | undefined;
    set internalValue(value: DatastreamOracleConnector | undefined);
    private _accessKey?;
    get accessKey(): string;
    set accessKey(value: string);
    get accessKeyInput(): string | undefined;
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    get compressLogs(): cdktf.IResolvable;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    get namespaceInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _secretAccessKey?;
    get secretAccessKey(): string;
    set secretAccessKey(value: string);
    get secretAccessKeyInput(): string | undefined;
}
export interface DatastreamS3Connector {
    /**
    * The access key identifier used to authenticate requests to the Amazon S3 account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#access_key Datastream#access_key}
    */
    readonly accessKey: string;
    /**
    * The name of the Amazon S3 bucket
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#bucket Datastream#bucket}
    */
    readonly bucket: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The path to the folder within Amazon S3 bucket where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#path Datastream#path}
    */
    readonly path: string;
    /**
    * The AWS region where Amazon S3 bucket resides
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#region Datastream#region}
    */
    readonly region: string;
    /**
    * The secret access key identifier used to authenticate requests to the Amazon S3 account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#secret_access_key Datastream#secret_access_key}
    */
    readonly secretAccessKey: string;
}
export declare function datastreamS3ConnectorToTerraform(struct?: DatastreamS3ConnectorOutputReference | DatastreamS3Connector): any;
export declare function datastreamS3ConnectorToHclTerraform(struct?: DatastreamS3ConnectorOutputReference | DatastreamS3Connector): any;
export declare class DatastreamS3ConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamS3Connector | undefined;
    set internalValue(value: DatastreamS3Connector | undefined);
    private _accessKey?;
    get accessKey(): string;
    set accessKey(value: string);
    get accessKeyInput(): string | undefined;
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    get compressLogs(): cdktf.IResolvable;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _secretAccessKey?;
    get secretAccessKey(): string;
    set secretAccessKey(value: string);
    get secretAccessKeyInput(): string | undefined;
}
export interface DatastreamSplunkConnector {
    /**
    * The certification authority (CA) certificate used to verify the origin server's certificate. If the certificate is not signed by a well-known certification authority, enter the CA certificate in the PEM format for verification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#ca_cert Datastream#ca_cert}
    */
    readonly caCert?: string;
    /**
    * The digital certificate in the PEM format you want to use to authenticate requests to your destination. If you want to use mutual authentication, you need to provide both the client certificate and the client key (in the PEM format).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#client_cert Datastream#client_cert}
    */
    readonly clientCert?: string;
    /**
    * The private key in the non-encrypted PKCS8 format you want to use to authenticate with the back-end server. If you want to use mutual authentication, you need to provide both the client certificate and the client key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#client_key Datastream#client_key}
    */
    readonly clientKey?: string;
    /**
    * Indicates whether the logs should be compressed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#compress_logs Datastream#compress_logs}
    */
    readonly compressLogs?: boolean | cdktf.IResolvable;
    /**
    * The name of custom header passed with the request to the destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_name Datastream#custom_header_name}
    */
    readonly customHeaderName?: string;
    /**
    * The custom header's contents passed with the request to the destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_value Datastream#custom_header_value}
    */
    readonly customHeaderValue?: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The raw event Splunk URL where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
    /**
    * The Event Collector token associated with Splunk account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#event_collector_token Datastream#event_collector_token}
    */
    readonly eventCollectorToken: string;
    /**
    * The hostname that verifies the server's certificate and matches the Subject Alternative Names (SANs) in the certificate. If not provided, DataStream fetches the hostname from the endpoint URL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#tls_hostname Datastream#tls_hostname}
    */
    readonly tlsHostname?: string;
}
export declare function datastreamSplunkConnectorToTerraform(struct?: DatastreamSplunkConnectorOutputReference | DatastreamSplunkConnector): any;
export declare function datastreamSplunkConnectorToHclTerraform(struct?: DatastreamSplunkConnectorOutputReference | DatastreamSplunkConnector): any;
export declare class DatastreamSplunkConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamSplunkConnector | undefined;
    set internalValue(value: DatastreamSplunkConnector | undefined);
    private _caCert?;
    get caCert(): string;
    set caCert(value: string);
    resetCaCert(): void;
    get caCertInput(): string | undefined;
    private _clientCert?;
    get clientCert(): string;
    set clientCert(value: string);
    resetClientCert(): void;
    get clientCertInput(): string | undefined;
    private _clientKey?;
    get clientKey(): string;
    set clientKey(value: string);
    resetClientKey(): void;
    get clientKeyInput(): string | undefined;
    private _compressLogs?;
    get compressLogs(): boolean | cdktf.IResolvable;
    set compressLogs(value: boolean | cdktf.IResolvable);
    resetCompressLogs(): void;
    get compressLogsInput(): boolean | cdktf.IResolvable | undefined;
    private _customHeaderName?;
    get customHeaderName(): string;
    set customHeaderName(value: string);
    resetCustomHeaderName(): void;
    get customHeaderNameInput(): string | undefined;
    private _customHeaderValue?;
    get customHeaderValue(): string;
    set customHeaderValue(value: string);
    resetCustomHeaderValue(): void;
    get customHeaderValueInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
    private _eventCollectorToken?;
    get eventCollectorToken(): string;
    set eventCollectorToken(value: string);
    get eventCollectorTokenInput(): string | undefined;
    get mTls(): cdktf.IResolvable;
    private _tlsHostname?;
    get tlsHostname(): string;
    set tlsHostname(value: string);
    resetTlsHostname(): void;
    get tlsHostnameInput(): string | undefined;
}
export interface DatastreamSumologicConnector {
    /**
    * The unique HTTP collector code of Sumo Logic endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#collector_code Datastream#collector_code}
    */
    readonly collectorCode: string;
    /**
    * Indicates whether the logs should be compressed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#compress_logs Datastream#compress_logs}
    */
    readonly compressLogs?: boolean | cdktf.IResolvable;
    /**
    * Content type to pass in the log file header
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#content_type Datastream#content_type}
    */
    readonly contentType?: string;
    /**
    * The name of custom header passed with the request to the destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_name Datastream#custom_header_name}
    */
    readonly customHeaderName?: string;
    /**
    * The custom header's contents passed with the request to the destination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#custom_header_value Datastream#custom_header_value}
    */
    readonly customHeaderValue?: string;
    /**
    * The name of the connector
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#display_name Datastream#display_name}
    */
    readonly displayName: string;
    /**
    * The Sumo Logic collection endpoint where logs will be stored
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#endpoint Datastream#endpoint}
    */
    readonly endpoint: string;
}
export declare function datastreamSumologicConnectorToTerraform(struct?: DatastreamSumologicConnectorOutputReference | DatastreamSumologicConnector): any;
export declare function datastreamSumologicConnectorToHclTerraform(struct?: DatastreamSumologicConnectorOutputReference | DatastreamSumologicConnector): any;
export declare class DatastreamSumologicConnectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamSumologicConnector | undefined;
    set internalValue(value: DatastreamSumologicConnector | undefined);
    private _collectorCode?;
    get collectorCode(): string;
    set collectorCode(value: string);
    get collectorCodeInput(): string | undefined;
    private _compressLogs?;
    get compressLogs(): boolean | cdktf.IResolvable;
    set compressLogs(value: boolean | cdktf.IResolvable);
    resetCompressLogs(): void;
    get compressLogsInput(): boolean | cdktf.IResolvable | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _customHeaderName?;
    get customHeaderName(): string;
    set customHeaderName(value: string);
    resetCustomHeaderName(): void;
    get customHeaderNameInput(): string | undefined;
    private _customHeaderValue?;
    get customHeaderValue(): string;
    set customHeaderValue(value: string);
    resetCustomHeaderValue(): void;
    get customHeaderValueInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    get endpointInput(): string | undefined;
}
export interface DatastreamTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#default Datastream#default}
    */
    readonly default?: string;
}
export declare function datastreamTimeoutsToTerraform(struct?: DatastreamTimeouts | cdktf.IResolvable): any;
export declare function datastreamTimeoutsToHclTerraform(struct?: DatastreamTimeouts | cdktf.IResolvable): any;
export declare class DatastreamTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DatastreamTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DatastreamTimeouts | cdktf.IResolvable | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream akamai_datastream}
*/
export declare class Datastream extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_datastream";
    /**
    * Generates CDKTF code for importing a Datastream resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Datastream to import
    * @param importFromId The id of the existing Datastream that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Datastream to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/datastream akamai_datastream} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DatastreamConfig
    */
    constructor(scope: Construct, id: string, config: DatastreamConfig);
    private _active?;
    get active(): boolean | cdktf.IResolvable;
    set active(value: boolean | cdktf.IResolvable);
    get activeInput(): boolean | cdktf.IResolvable | undefined;
    private _collectMidgress?;
    get collectMidgress(): boolean | cdktf.IResolvable;
    set collectMidgress(value: boolean | cdktf.IResolvable);
    resetCollectMidgress(): void;
    get collectMidgressInput(): boolean | cdktf.IResolvable | undefined;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    get createdBy(): string;
    get createdDate(): string;
    private _datasetFields?;
    get datasetFields(): number[];
    set datasetFields(value: number[]);
    get datasetFieldsInput(): number[] | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get latestVersion(): number;
    get modifiedBy(): string;
    get modifiedDate(): string;
    private _notificationEmails?;
    get notificationEmails(): string[];
    set notificationEmails(value: string[]);
    resetNotificationEmails(): void;
    get notificationEmailsInput(): string[] | undefined;
    get papiJson(): string;
    get productId(): string;
    private _properties?;
    get properties(): string[];
    set properties(value: string[]);
    get propertiesInput(): string[] | undefined;
    private _streamName?;
    get streamName(): string;
    set streamName(value: string);
    get streamNameInput(): string | undefined;
    get streamVersion(): number;
    private _azureConnector;
    get azureConnector(): DatastreamAzureConnectorOutputReference;
    putAzureConnector(value: DatastreamAzureConnector): void;
    resetAzureConnector(): void;
    get azureConnectorInput(): DatastreamAzureConnector | undefined;
    private _datadogConnector;
    get datadogConnector(): DatastreamDatadogConnectorOutputReference;
    putDatadogConnector(value: DatastreamDatadogConnector): void;
    resetDatadogConnector(): void;
    get datadogConnectorInput(): DatastreamDatadogConnector | undefined;
    private _deliveryConfiguration;
    get deliveryConfiguration(): DatastreamDeliveryConfigurationOutputReference;
    putDeliveryConfiguration(value: DatastreamDeliveryConfiguration): void;
    get deliveryConfigurationInput(): DatastreamDeliveryConfiguration | undefined;
    private _elasticsearchConnector;
    get elasticsearchConnector(): DatastreamElasticsearchConnectorOutputReference;
    putElasticsearchConnector(value: DatastreamElasticsearchConnector): void;
    resetElasticsearchConnector(): void;
    get elasticsearchConnectorInput(): DatastreamElasticsearchConnector | undefined;
    private _gcsConnector;
    get gcsConnector(): DatastreamGcsConnectorOutputReference;
    putGcsConnector(value: DatastreamGcsConnector): void;
    resetGcsConnector(): void;
    get gcsConnectorInput(): DatastreamGcsConnector | undefined;
    private _httpsConnector;
    get httpsConnector(): DatastreamHttpsConnectorOutputReference;
    putHttpsConnector(value: DatastreamHttpsConnector): void;
    resetHttpsConnector(): void;
    get httpsConnectorInput(): DatastreamHttpsConnector | undefined;
    private _logglyConnector;
    get logglyConnector(): DatastreamLogglyConnectorOutputReference;
    putLogglyConnector(value: DatastreamLogglyConnector): void;
    resetLogglyConnector(): void;
    get logglyConnectorInput(): DatastreamLogglyConnector | undefined;
    private _newRelicConnector;
    get newRelicConnector(): DatastreamNewRelicConnectorOutputReference;
    putNewRelicConnector(value: DatastreamNewRelicConnector): void;
    resetNewRelicConnector(): void;
    get newRelicConnectorInput(): DatastreamNewRelicConnector | undefined;
    private _oracleConnector;
    get oracleConnector(): DatastreamOracleConnectorOutputReference;
    putOracleConnector(value: DatastreamOracleConnector): void;
    resetOracleConnector(): void;
    get oracleConnectorInput(): DatastreamOracleConnector | undefined;
    private _s3Connector;
    get s3Connector(): DatastreamS3ConnectorOutputReference;
    putS3Connector(value: DatastreamS3Connector): void;
    resetS3Connector(): void;
    get s3ConnectorInput(): DatastreamS3Connector | undefined;
    private _splunkConnector;
    get splunkConnector(): DatastreamSplunkConnectorOutputReference;
    putSplunkConnector(value: DatastreamSplunkConnector): void;
    resetSplunkConnector(): void;
    get splunkConnectorInput(): DatastreamSplunkConnector | undefined;
    private _sumologicConnector;
    get sumologicConnector(): DatastreamSumologicConnectorOutputReference;
    putSumologicConnector(value: DatastreamSumologicConnector): void;
    resetSumologicConnector(): void;
    get sumologicConnectorInput(): DatastreamSumologicConnector | undefined;
    private _timeouts;
    get timeouts(): DatastreamTimeoutsOutputReference;
    putTimeouts(value: DatastreamTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DatastreamTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
