import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgekvGroupItemsConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the EdgeKV group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#group_name EdgekvGroupItems#group_name}
    */
    readonly groupName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#id EdgekvGroupItems#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A map of items within the specified group. Each item consists of an item key and a value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#items EdgekvGroupItems#items}
    */
    readonly items: {
        [key: string]: string;
    };
    /**
    * The name for the EdgeKV namespace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#namespace_name EdgekvGroupItems#namespace_name}
    */
    readonly namespaceName: string;
    /**
    * The network against which to execute the API request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#network EdgekvGroupItems#network}
    */
    readonly network: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#timeouts EdgekvGroupItems#timeouts}
    */
    readonly timeouts?: EdgekvGroupItemsTimeouts;
}
export interface EdgekvGroupItemsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#default EdgekvGroupItems#default}
    */
    readonly default?: string;
}
export declare function edgekvGroupItemsTimeoutsToTerraform(struct?: EdgekvGroupItemsTimeoutsOutputReference | EdgekvGroupItemsTimeouts): any;
export declare function edgekvGroupItemsTimeoutsToHclTerraform(struct?: EdgekvGroupItemsTimeoutsOutputReference | EdgekvGroupItemsTimeouts): any;
export declare class EdgekvGroupItemsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EdgekvGroupItemsTimeouts | undefined;
    set internalValue(value: EdgekvGroupItemsTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items akamai_edgekv_group_items}
*/
export declare class EdgekvGroupItems extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_edgekv_group_items";
    /**
    * Generates CDKTF code for importing a EdgekvGroupItems resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EdgekvGroupItems to import
    * @param importFromId The id of the existing EdgekvGroupItems that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EdgekvGroupItems to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv_group_items akamai_edgekv_group_items} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgekvGroupItemsConfig
    */
    constructor(scope: Construct, id: string, config: EdgekvGroupItemsConfig);
    private _groupName?;
    get groupName(): string;
    set groupName(value: string);
    get groupNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _items?;
    get items(): {
        [key: string]: string;
    };
    set items(value: {
        [key: string]: string;
    });
    get itemsInput(): {
        [key: string]: string;
    } | undefined;
    private _namespaceName?;
    get namespaceName(): string;
    set namespaceName(value: string);
    get namespaceNameInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _timeouts;
    get timeouts(): EdgekvGroupItemsTimeoutsOutputReference;
    putTimeouts(value: EdgekvGroupItemsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): EdgekvGroupItemsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
