import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgekvConfig extends cdktf.TerraformMetaArguments {
    /**
    * Storage location for data
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#geo_location Edgekv#geo_location}
    */
    readonly geoLocation?: string;
    /**
    * Namespace ACC group ID. It will be used in EdgeKV API v2. Not updatable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#group_id Edgekv#group_id}
    */
    readonly groupId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#id Edgekv#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name for the EKV namespace
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#namespace_name Edgekv#namespace_name}
    */
    readonly namespaceName: string;
    /**
    * The network on which the namespace will be activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#network Edgekv#network}
    */
    readonly network: string;
    /**
    * Retention period for data in this namespace. An update of this value will just affect new EKV items.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#retention_in_seconds Edgekv#retention_in_seconds}
    */
    readonly retentionInSeconds: number;
    /**
    * initial_data block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#initial_data Edgekv#initial_data}
    */
    readonly initialData?: EdgekvInitialData[] | cdktf.IResolvable;
}
export interface EdgekvInitialData {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#group Edgekv#group}
    */
    readonly group?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#key Edgekv#key}
    */
    readonly key: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#value Edgekv#value}
    */
    readonly value: string;
}
export declare function edgekvInitialDataToTerraform(struct?: EdgekvInitialData | cdktf.IResolvable): any;
export declare function edgekvInitialDataToHclTerraform(struct?: EdgekvInitialData | cdktf.IResolvable): any;
export declare class EdgekvInitialDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgekvInitialData | cdktf.IResolvable | undefined;
    set internalValue(value: EdgekvInitialData | cdktf.IResolvable | undefined);
    private _group?;
    get group(): string;
    set group(value: string);
    resetGroup(): void;
    get groupInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class EdgekvInitialDataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EdgekvInitialData[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgekvInitialDataOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv akamai_edgekv}
*/
export declare class Edgekv extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_edgekv";
    /**
    * Generates CDKTF code for importing a Edgekv resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Edgekv to import
    * @param importFromId The id of the existing Edgekv that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Edgekv to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgekv akamai_edgekv} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgekvConfig
    */
    constructor(scope: Construct, id: string, config: EdgekvConfig);
    private _geoLocation?;
    get geoLocation(): string;
    set geoLocation(value: string);
    resetGeoLocation(): void;
    get geoLocationInput(): string | undefined;
    private _groupId?;
    get groupId(): number;
    set groupId(value: number);
    get groupIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _namespaceName?;
    get namespaceName(): string;
    set namespaceName(value: string);
    get namespaceNameInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _retentionInSeconds?;
    get retentionInSeconds(): number;
    set retentionInSeconds(value: number);
    get retentionInSecondsInput(): number | undefined;
    private _initialData;
    get initialData(): EdgekvInitialDataList;
    putInitialData(value: EdgekvInitialData[] | cdktf.IResolvable): void;
    resetInitialData(): void;
    get initialDataInput(): cdktf.IResolvable | EdgekvInitialData[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
