import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgeworkerConfig extends cdktf.TerraformMetaArguments {
    /**
    * Defines the group association for the EdgeWorker
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#group_id Edgeworker#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#id Edgeworker#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The path to the EdgeWorkers tgz code bundle
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#local_bundle Edgeworker#local_bundle}
    */
    readonly localBundle?: string;
    /**
    * The EdgeWorker name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#name Edgeworker#name}
    */
    readonly name: string;
    /**
    * The unique identifier of a resource tier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#resource_tier_id Edgeworker#resource_tier_id}
    */
    readonly resourceTierId: number;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#timeouts Edgeworker#timeouts}
    */
    readonly timeouts?: EdgeworkerTimeouts;
}
export interface EdgeworkerTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#default Edgeworker#default}
    */
    readonly default?: string;
}
export declare function edgeworkerTimeoutsToTerraform(struct?: EdgeworkerTimeoutsOutputReference | EdgeworkerTimeouts): any;
export declare function edgeworkerTimeoutsToHclTerraform(struct?: EdgeworkerTimeoutsOutputReference | EdgeworkerTimeouts): any;
export declare class EdgeworkerTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EdgeworkerTimeouts | undefined;
    set internalValue(value: EdgeworkerTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker akamai_edgeworker}
*/
export declare class Edgeworker extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_edgeworker";
    /**
    * Generates CDKTF code for importing a Edgeworker resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Edgeworker to import
    * @param importFromId The id of the existing Edgeworker that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Edgeworker to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworker akamai_edgeworker} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgeworkerConfig
    */
    constructor(scope: Construct, id: string, config: EdgeworkerConfig);
    get edgeworkerId(): number;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _localBundle?;
    get localBundle(): string;
    set localBundle(value: string);
    resetLocalBundle(): void;
    get localBundleInput(): string | undefined;
    get localBundleHash(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceTierId?;
    get resourceTierId(): number;
    set resourceTierId(value: number);
    get resourceTierIdInput(): number | undefined;
    get version(): string;
    get warnings(): string[];
    private _timeouts;
    get timeouts(): EdgeworkerTimeoutsOutputReference;
    putTimeouts(value: EdgeworkerTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): EdgeworkerTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
