import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgeworkersActivationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Id of the EdgeWorker to activate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#edgeworker_id EdgeworkersActivation#edgeworker_id}
    */
    readonly edgeworkerId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#id EdgeworkersActivation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The network on which the version will be activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#network EdgeworkersActivation#network}
    */
    readonly network: string;
    /**
    * Assigns a log message to the activation request
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#note EdgeworkersActivation#note}
    */
    readonly note?: string;
    /**
    * The version of EdgeWorker to activate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#version EdgeworkersActivation#version}
    */
    readonly version: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#timeouts EdgeworkersActivation#timeouts}
    */
    readonly timeouts?: EdgeworkersActivationTimeouts;
}
export interface EdgeworkersActivationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#default EdgeworkersActivation#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#delete EdgeworkersActivation#delete}
    */
    readonly delete?: string;
}
export declare function edgeworkersActivationTimeoutsToTerraform(struct?: EdgeworkersActivationTimeoutsOutputReference | EdgeworkersActivationTimeouts): any;
export declare function edgeworkersActivationTimeoutsToHclTerraform(struct?: EdgeworkersActivationTimeoutsOutputReference | EdgeworkersActivationTimeouts): any;
export declare class EdgeworkersActivationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EdgeworkersActivationTimeouts | undefined;
    set internalValue(value: EdgeworkersActivationTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation akamai_edgeworkers_activation}
*/
export declare class EdgeworkersActivation extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_edgeworkers_activation";
    /**
    * Generates CDKTF code for importing a EdgeworkersActivation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EdgeworkersActivation to import
    * @param importFromId The id of the existing EdgeworkersActivation that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EdgeworkersActivation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/edgeworkers_activation akamai_edgeworkers_activation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgeworkersActivationConfig
    */
    constructor(scope: Construct, id: string, config: EdgeworkersActivationConfig);
    get activationId(): number;
    private _edgeworkerId?;
    get edgeworkerId(): number;
    set edgeworkerId(value: number);
    get edgeworkerIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _note?;
    get note(): string;
    set note(value: string);
    resetNote(): void;
    get noteInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    private _timeouts;
    get timeouts(): EdgeworkersActivationTimeoutsOutputReference;
    putTimeouts(value: EdgeworkersActivationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): EdgeworkersActivationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
