import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IamRoleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description for a role
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role#description IamRole#description}
    */
    readonly description: string;
    /**
    * The list of existing unique identifiers for the granted roles
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role#granted_roles IamRole#granted_roles}
    */
    readonly grantedRoles: number[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role#id IamRole#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name you supply for a role
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role#name IamRole#name}
    */
    readonly name: string;
    /**
    * The role type which indicates whether it's a standard role provided by Akamai or a custom role for the account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role#type IamRole#type}
    */
    readonly type?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role akamai_iam_role}
*/
export declare class IamRole extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_iam_role";
    /**
    * Generates CDKTF code for importing a IamRole resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IamRole to import
    * @param importFromId The id of the existing IamRole that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IamRole to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_role akamai_iam_role} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IamRoleConfig
    */
    constructor(scope: Construct, id: string, config: IamRoleConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _grantedRoles?;
    get grantedRoles(): number[];
    set grantedRoles(value: number[]);
    get grantedRolesInput(): number[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
