import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IamUserConfig extends cdktf.TerraformMetaArguments {
    /**
    * The user's street address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#address IamUser#address}
    */
    readonly address?: string;
    /**
    * A user's per-group role assignments, in JSON form
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#auth_grants_json IamUser#auth_grants_json}
    */
    readonly authGrantsJson: string;
    /**
    * The user's city
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#city IamUser#city}
    */
    readonly city?: string;
    /**
    * To help characterize the user, the value can be any that are available from the view-contact-types operation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#contact_type IamUser#contact_type}
    */
    readonly contactType?: string;
    /**
    * As part of the user's location, the value can be any that are available from the view-supported-countries operation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#country IamUser#country}
    */
    readonly country: string;
    /**
    * The user's email address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#email IamUser#email}
    */
    readonly email: string;
    /**
    * Indicates whether two-factor authentication is allowed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#enable_tfa IamUser#enable_tfa}
    */
    readonly enableTfa: boolean | cdktf.IResolvable;
    /**
    * The user's first name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#first_name IamUser#first_name}
    */
    readonly firstName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#id IamUser#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The user's position at your company
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#job_title IamUser#job_title}
    */
    readonly jobTitle?: string;
    /**
    * The user's surname
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#last_name IamUser#last_name}
    */
    readonly lastName: string;
    /**
    * Flag to block a user account
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#lock IamUser#lock}
    */
    readonly lock?: boolean | cdktf.IResolvable;
    /**
    * The user's mobile phone number
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#mobile_phone IamUser#mobile_phone}
    */
    readonly mobilePhone?: string;
    /**
    * The user's main phone number
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#phone IamUser#phone}
    */
    readonly phone?: string;
    /**
    * The value can be any that are available from the view-languages operation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#preferred_language IamUser#preferred_language}
    */
    readonly preferredLanguage?: string;
    /**
    * The user's secondary email address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#secondary_email IamUser#secondary_email}
    */
    readonly secondaryEmail?: string;
    /**
    * The number of seconds it takes for the user's Control Center session to time out if there hasn't been any activity
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#session_timeout IamUser#session_timeout}
    */
    readonly sessionTimeout?: number;
    /**
    * The user's state
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#state IamUser#state}
    */
    readonly state?: string;
    /**
    * The user's time zone. The value can be any that are available from the view-time-zones operation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#time_zone IamUser#time_zone}
    */
    readonly timeZone?: string;
    /**
    * The user's five-digit ZIP code
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#zip_code IamUser#zip_code}
    */
    readonly zipCode?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user akamai_iam_user}
*/
export declare class IamUser extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_iam_user";
    /**
    * Generates CDKTF code for importing a IamUser resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IamUser to import
    * @param importFromId The id of the existing IamUser that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IamUser to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/iam_user akamai_iam_user} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IamUserConfig
    */
    constructor(scope: Construct, id: string, config: IamUserConfig);
    private _address?;
    get address(): string;
    set address(value: string);
    resetAddress(): void;
    get addressInput(): string | undefined;
    private _authGrantsJson?;
    get authGrantsJson(): string;
    set authGrantsJson(value: string);
    get authGrantsJsonInput(): string | undefined;
    private _city?;
    get city(): string;
    set city(value: string);
    resetCity(): void;
    get cityInput(): string | undefined;
    private _contactType?;
    get contactType(): string;
    set contactType(value: string);
    resetContactType(): void;
    get contactTypeInput(): string | undefined;
    private _country?;
    get country(): string;
    set country(value: string);
    get countryInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    get emailUpdatePending(): cdktf.IResolvable;
    private _enableTfa?;
    get enableTfa(): boolean | cdktf.IResolvable;
    set enableTfa(value: boolean | cdktf.IResolvable);
    get enableTfaInput(): boolean | cdktf.IResolvable | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _jobTitle?;
    get jobTitle(): string;
    set jobTitle(value: string);
    resetJobTitle(): void;
    get jobTitleInput(): string | undefined;
    get lastLogin(): string;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _lock?;
    get lock(): boolean | cdktf.IResolvable;
    set lock(value: boolean | cdktf.IResolvable);
    resetLock(): void;
    get lockInput(): boolean | cdktf.IResolvable | undefined;
    private _mobilePhone?;
    get mobilePhone(): string;
    set mobilePhone(value: string);
    resetMobilePhone(): void;
    get mobilePhoneInput(): string | undefined;
    get passwordExpiredAfter(): string;
    private _phone?;
    get phone(): string;
    set phone(value: string);
    resetPhone(): void;
    get phoneInput(): string | undefined;
    private _preferredLanguage?;
    get preferredLanguage(): string;
    set preferredLanguage(value: string);
    resetPreferredLanguage(): void;
    get preferredLanguageInput(): string | undefined;
    private _secondaryEmail?;
    get secondaryEmail(): string;
    set secondaryEmail(value: string);
    resetSecondaryEmail(): void;
    get secondaryEmailInput(): string | undefined;
    private _sessionTimeout?;
    get sessionTimeout(): number;
    set sessionTimeout(value: number);
    resetSessionTimeout(): void;
    get sessionTimeoutInput(): number | undefined;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
    get tfaConfigured(): cdktf.IResolvable;
    private _timeZone?;
    get timeZone(): string;
    set timeZone(value: string);
    resetTimeZone(): void;
    get timeZoneInput(): string | undefined;
    get userName(): string;
    private _zipCode?;
    get zipCode(): string;
    set zipCode(value: string);
    resetZipCode(): void;
    get zipCodeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
