import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ImagingPolicySetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique identifier for the Akamai Contract containing the Policy Set(s)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set#contract_id ImagingPolicySet#contract_id}
    */
    readonly contractId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set#id ImagingPolicySet#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A friendly name for the Policy Set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set#name ImagingPolicySet#name}
    */
    readonly name: string;
    /**
    * The geographic region which media using this Policy Set is optimized for
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set#region ImagingPolicySet#region}
    */
    readonly region: string;
    /**
    * The type of media this Policy Set manages
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set#type ImagingPolicySet#type}
    */
    readonly type: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set akamai_imaging_policy_set}
*/
export declare class ImagingPolicySet extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_imaging_policy_set";
    /**
    * Generates CDKTF code for importing a ImagingPolicySet resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ImagingPolicySet to import
    * @param importFromId The id of the existing ImagingPolicySet that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ImagingPolicySet to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_set akamai_imaging_policy_set} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ImagingPolicySetConfig
    */
    constructor(scope: Construct, id: string, config: ImagingPolicySetConfig);
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
