import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ImagingPolicyVideoConfig extends cdktf.TerraformMetaArguments {
    /**
    * With this flag set to false, the user can perform modifications on staging without affecting the version already saved to production. With this flag set to true, the policy will be saved on the production network. It is possible to change it back to false only when there are any changes to the policy qualifying it for the new version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#activate_on_production ImagingPolicyVideo#activate_on_production}
    */
    readonly activateOnProduction?: boolean | cdktf.IResolvable;
    /**
    * Unique identifier for the Akamai Contract containing the Policy Set(s)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#contract_id ImagingPolicyVideo#contract_id}
    */
    readonly contractId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#id ImagingPolicyVideo#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A JSON encoded policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#json ImagingPolicyVideo#json}
    */
    readonly json: string;
    /**
    * Unique identifier for a Policy. It is not possible to modify the id of the policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#policy_id ImagingPolicyVideo#policy_id}
    */
    readonly policyId: string;
    /**
    * Unique identifier for the Image & Video Manager Policy Set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#policyset_id ImagingPolicyVideo#policyset_id}
    */
    readonly policysetId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video akamai_imaging_policy_video}
*/
export declare class ImagingPolicyVideo extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_imaging_policy_video";
    /**
    * Generates CDKTF code for importing a ImagingPolicyVideo resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ImagingPolicyVideo to import
    * @param importFromId The id of the existing ImagingPolicyVideo that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ImagingPolicyVideo to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/imaging_policy_video akamai_imaging_policy_video} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ImagingPolicyVideoConfig
    */
    constructor(scope: Construct, id: string, config: ImagingPolicyVideoConfig);
    private _activateOnProduction?;
    get activateOnProduction(): boolean | cdktf.IResolvable;
    set activateOnProduction(value: boolean | cdktf.IResolvable);
    resetActivateOnProduction(): void;
    get activateOnProductionInput(): boolean | cdktf.IResolvable | undefined;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _json?;
    get json(): string;
    set json(value: string);
    get jsonInput(): string | undefined;
    private _policyId?;
    get policyId(): string;
    set policyId(value: string);
    get policyIdInput(): string | undefined;
    private _policysetId?;
    get policysetId(): string;
    set policysetId(value: string);
    get policysetIdInput(): string | undefined;
    get version(): number;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
