import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworklistActivationsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#id NetworklistActivations#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The Akamai network on which the list is activated: STAGING or PRODUCTION
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#network NetworklistActivations#network}
    */
    readonly network?: string;
    /**
    * Unique identifier of the network list
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#network_list_id NetworklistActivations#network_list_id}
    */
    readonly networkListId: string;
    /**
    * Descriptive text to accompany the activation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#notes NetworklistActivations#notes}
    */
    readonly notes?: string;
    /**
    * List of email addresses of Control Center users who receive an email when activation of this list is complete
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#notification_emails NetworklistActivations#notification_emails}
    */
    readonly notificationEmails: string[];
    /**
    * Identifies the sync point of the network list to be activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#sync_point NetworklistActivations#sync_point}
    */
    readonly syncPoint: number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations akamai_networklist_activations}
*/
export declare class NetworklistActivations extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_networklist_activations";
    /**
    * Generates CDKTF code for importing a NetworklistActivations resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworklistActivations to import
    * @param importFromId The id of the existing NetworklistActivations that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworklistActivations to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/networklist_activations akamai_networklist_activations} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworklistActivationsConfig
    */
    constructor(scope: Construct, id: string, config: NetworklistActivationsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _networkListId?;
    get networkListId(): string;
    set networkListId(value: string);
    get networkListIdInput(): string | undefined;
    private _notes?;
    get notes(): string;
    set notes(value: string);
    resetNotes(): void;
    get notesInput(): string | undefined;
    private _notificationEmails?;
    get notificationEmails(): string[];
    set notificationEmails(value: string[]);
    get notificationEmailsInput(): string[] | undefined;
    get status(): string;
    private _syncPoint?;
    get syncPoint(): number;
    set syncPoint(value: number);
    get syncPointInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
