import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PropertyIncludeActivationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Automatically acknowledge all rule warnings for activation and continue
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#auto_acknowledge_rule_warnings PropertyIncludeActivation#auto_acknowledge_rule_warnings}
    */
    readonly autoAcknowledgeRuleWarnings?: boolean | cdktf.IResolvable;
    /**
    * The contract under which the include is activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#contract_id PropertyIncludeActivation#contract_id}
    */
    readonly contractId: string;
    /**
    * The group under which the include is activated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#group_id PropertyIncludeActivation#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#id PropertyIncludeActivation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier of the include
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#include_id PropertyIncludeActivation#include_id}
    */
    readonly includeId: string;
    /**
    * The network for which the activation will be performed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#network PropertyIncludeActivation#network}
    */
    readonly network: string;
    /**
    * The note to assign to a log message of the activation request
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#note PropertyIncludeActivation#note}
    */
    readonly note?: string;
    /**
    * The list of email addresses to notify about an activation status
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#notify_emails PropertyIncludeActivation#notify_emails}
    */
    readonly notifyEmails: string[];
    /**
    * The unique identifier of the include
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#version PropertyIncludeActivation#version}
    */
    readonly version: number;
    /**
    * compliance_record block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#compliance_record PropertyIncludeActivation#compliance_record}
    */
    readonly complianceRecord?: PropertyIncludeActivationComplianceRecord;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#timeouts PropertyIncludeActivation#timeouts}
    */
    readonly timeouts?: PropertyIncludeActivationTimeouts;
}
export interface PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency {
    /**
    * Identifies the ticket that describes the need for the activation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#ticket_id PropertyIncludeActivation#ticket_id}
    */
    readonly ticketId?: string;
}
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonEmergencyToTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergencyOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency): any;
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonEmergencyToHclTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergencyOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency): any;
export declare class PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergencyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency | undefined;
    set internalValue(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency | undefined);
    private _ticketId?;
    get ticketId(): string;
    set ticketId(value: string);
    resetTicketId(): void;
    get ticketIdInput(): string | undefined;
}
export interface PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic {
    /**
    * Identifies the ticket that describes the need for the activation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#ticket_id PropertyIncludeActivation#ticket_id}
    */
    readonly ticketId?: string;
}
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTrafficToTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTrafficOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic): any;
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTrafficToHclTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTrafficOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic): any;
export declare class PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTrafficOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic | undefined;
    set internalValue(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic | undefined);
    private _ticketId?;
    get ticketId(): string;
    set ticketId(value: string);
    resetTicketId(): void;
    get ticketIdInput(): string | undefined;
}
export interface PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone {
    /**
    * Identifies the customer
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#customer_email PropertyIncludeActivation#customer_email}
    */
    readonly customerEmail?: string;
    /**
    * Identifies person who has independently approved the activation request
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#peer_reviewed_by PropertyIncludeActivation#peer_reviewed_by}
    */
    readonly peerReviewedBy?: string;
    /**
    * Identifies the ticket that describes the need for the activation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#ticket_id PropertyIncludeActivation#ticket_id}
    */
    readonly ticketId?: string;
    /**
    * Whether the metadata to activate has been fully tested
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#unit_tested PropertyIncludeActivation#unit_tested}
    */
    readonly unitTested?: boolean | cdktf.IResolvable;
}
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonNoneToTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoneOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone): any;
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonNoneToHclTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoneOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone): any;
export declare class PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone | undefined;
    set internalValue(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone | undefined);
    private _customerEmail?;
    get customerEmail(): string;
    set customerEmail(value: string);
    resetCustomerEmail(): void;
    get customerEmailInput(): string | undefined;
    private _peerReviewedBy?;
    get peerReviewedBy(): string;
    set peerReviewedBy(value: string);
    resetPeerReviewedBy(): void;
    get peerReviewedByInput(): string | undefined;
    private _ticketId?;
    get ticketId(): string;
    set ticketId(value: string);
    resetTicketId(): void;
    get ticketIdInput(): string | undefined;
    private _unitTested?;
    get unitTested(): boolean | cdktf.IResolvable;
    set unitTested(value: boolean | cdktf.IResolvable);
    resetUnitTested(): void;
    get unitTestedInput(): boolean | cdktf.IResolvable | undefined;
}
export interface PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther {
    /**
    * Describes the reason why the activation must occur immediately, out of compliance with the standard procedure
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#other_noncompliance_reason PropertyIncludeActivation#other_noncompliance_reason}
    */
    readonly otherNoncomplianceReason?: string;
    /**
    * Identifies the ticket that describes the need for the activation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#ticket_id PropertyIncludeActivation#ticket_id}
    */
    readonly ticketId?: string;
}
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonOtherToTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonOtherOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther): any;
export declare function propertyIncludeActivationComplianceRecordNoncomplianceReasonOtherToHclTerraform(struct?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonOtherOutputReference | PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther): any;
export declare class PropertyIncludeActivationComplianceRecordNoncomplianceReasonOtherOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther | undefined;
    set internalValue(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther | undefined);
    private _otherNoncomplianceReason?;
    get otherNoncomplianceReason(): string;
    set otherNoncomplianceReason(value: string);
    resetOtherNoncomplianceReason(): void;
    get otherNoncomplianceReasonInput(): string | undefined;
    private _ticketId?;
    get ticketId(): string;
    set ticketId(value: string);
    resetTicketId(): void;
    get ticketIdInput(): string | undefined;
}
export interface PropertyIncludeActivationComplianceRecord {
    /**
    * noncompliance_reason_emergency block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#noncompliance_reason_emergency PropertyIncludeActivation#noncompliance_reason_emergency}
    */
    readonly noncomplianceReasonEmergency?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency;
    /**
    * noncompliance_reason_no_production_traffic block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#noncompliance_reason_no_production_traffic PropertyIncludeActivation#noncompliance_reason_no_production_traffic}
    */
    readonly noncomplianceReasonNoProductionTraffic?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic;
    /**
    * noncompliance_reason_none block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#noncompliance_reason_none PropertyIncludeActivation#noncompliance_reason_none}
    */
    readonly noncomplianceReasonNone?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone;
    /**
    * noncompliance_reason_other block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#noncompliance_reason_other PropertyIncludeActivation#noncompliance_reason_other}
    */
    readonly noncomplianceReasonOther?: PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther;
}
export declare function propertyIncludeActivationComplianceRecordToTerraform(struct?: PropertyIncludeActivationComplianceRecordOutputReference | PropertyIncludeActivationComplianceRecord): any;
export declare function propertyIncludeActivationComplianceRecordToHclTerraform(struct?: PropertyIncludeActivationComplianceRecordOutputReference | PropertyIncludeActivationComplianceRecord): any;
export declare class PropertyIncludeActivationComplianceRecordOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PropertyIncludeActivationComplianceRecord | undefined;
    set internalValue(value: PropertyIncludeActivationComplianceRecord | undefined);
    private _noncomplianceReasonEmergency;
    get noncomplianceReasonEmergency(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergencyOutputReference;
    putNoncomplianceReasonEmergency(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency): void;
    resetNoncomplianceReasonEmergency(): void;
    get noncomplianceReasonEmergencyInput(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonEmergency | undefined;
    private _noncomplianceReasonNoProductionTraffic;
    get noncomplianceReasonNoProductionTraffic(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTrafficOutputReference;
    putNoncomplianceReasonNoProductionTraffic(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic): void;
    resetNoncomplianceReasonNoProductionTraffic(): void;
    get noncomplianceReasonNoProductionTrafficInput(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoProductionTraffic | undefined;
    private _noncomplianceReasonNone;
    get noncomplianceReasonNone(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonNoneOutputReference;
    putNoncomplianceReasonNone(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone): void;
    resetNoncomplianceReasonNone(): void;
    get noncomplianceReasonNoneInput(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonNone | undefined;
    private _noncomplianceReasonOther;
    get noncomplianceReasonOther(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonOtherOutputReference;
    putNoncomplianceReasonOther(value: PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther): void;
    resetNoncomplianceReasonOther(): void;
    get noncomplianceReasonOtherInput(): PropertyIncludeActivationComplianceRecordNoncomplianceReasonOther | undefined;
}
export interface PropertyIncludeActivationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#default PropertyIncludeActivation#default}
    */
    readonly default?: string;
}
export declare function propertyIncludeActivationTimeoutsToTerraform(struct?: PropertyIncludeActivationTimeoutsOutputReference | PropertyIncludeActivationTimeouts): any;
export declare function propertyIncludeActivationTimeoutsToHclTerraform(struct?: PropertyIncludeActivationTimeoutsOutputReference | PropertyIncludeActivationTimeouts): any;
export declare class PropertyIncludeActivationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PropertyIncludeActivationTimeouts | undefined;
    set internalValue(value: PropertyIncludeActivationTimeouts | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation akamai_property_include_activation}
*/
export declare class PropertyIncludeActivation extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_property_include_activation";
    /**
    * Generates CDKTF code for importing a PropertyIncludeActivation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PropertyIncludeActivation to import
    * @param importFromId The id of the existing PropertyIncludeActivation that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PropertyIncludeActivation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include_activation akamai_property_include_activation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PropertyIncludeActivationConfig
    */
    constructor(scope: Construct, id: string, config: PropertyIncludeActivationConfig);
    private _autoAcknowledgeRuleWarnings?;
    get autoAcknowledgeRuleWarnings(): boolean | cdktf.IResolvable;
    set autoAcknowledgeRuleWarnings(value: boolean | cdktf.IResolvable);
    resetAutoAcknowledgeRuleWarnings(): void;
    get autoAcknowledgeRuleWarningsInput(): boolean | cdktf.IResolvable | undefined;
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _includeId?;
    get includeId(): string;
    set includeId(value: string);
    get includeIdInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _note?;
    get note(): string;
    set note(value: string);
    resetNote(): void;
    get noteInput(): string | undefined;
    private _notifyEmails?;
    get notifyEmails(): string[];
    set notifyEmails(value: string[]);
    get notifyEmailsInput(): string[] | undefined;
    get validations(): string;
    private _version?;
    get version(): number;
    set version(value: number);
    get versionInput(): number | undefined;
    private _complianceRecord;
    get complianceRecord(): PropertyIncludeActivationComplianceRecordOutputReference;
    putComplianceRecord(value: PropertyIncludeActivationComplianceRecord): void;
    resetComplianceRecord(): void;
    get complianceRecordInput(): PropertyIncludeActivationComplianceRecord | undefined;
    private _timeouts;
    get timeouts(): PropertyIncludeActivationTimeoutsOutputReference;
    putTimeouts(value: PropertyIncludeActivationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): PropertyIncludeActivationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
