import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PropertyIncludeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifies the contract to which the include is assigned
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#contract_id PropertyInclude#contract_id}
    */
    readonly contractId: string;
    /**
    * Identifies the group to which the include is assigned
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#group_id PropertyInclude#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#id PropertyInclude#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A descriptive name for the include
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#name PropertyInclude#name}
    */
    readonly name: string;
    /**
    * The product assigned to the include
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#product_id PropertyInclude#product_id}
    */
    readonly productId?: string;
    /**
    * Indicates the versioned set of features and criteria
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#rule_format PropertyInclude#rule_format}
    */
    readonly ruleFormat: string;
    /**
    * Property Rules as JSON
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#rules PropertyInclude#rules}
    */
    readonly rules?: string;
    /**
    * Specifies the type of the include, either 'MICROSERVICES' or 'COMMON_SETTINGS'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#type PropertyInclude#type}
    */
    readonly type: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include akamai_property_include}
*/
export declare class PropertyInclude extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_property_include";
    /**
    * Generates CDKTF code for importing a PropertyInclude resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PropertyInclude to import
    * @param importFromId The id of the existing PropertyInclude that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PropertyInclude to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property_include akamai_property_include} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PropertyIncludeConfig
    */
    constructor(scope: Construct, id: string, config: PropertyIncludeConfig);
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get latestVersion(): number;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _productId?;
    get productId(): string;
    set productId(value: string);
    resetProductId(): void;
    get productIdInput(): string | undefined;
    get productionVersion(): string;
    get ruleErrors(): string;
    private _ruleFormat?;
    get ruleFormat(): string;
    set ruleFormat(value: string);
    get ruleFormatInput(): string | undefined;
    get ruleWarnings(): string;
    private _rules?;
    get rules(): string;
    set rules(value: string);
    resetRules(): void;
    get rulesInput(): string | undefined;
    get stagingVersion(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
