import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PropertyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Contract ID to be assigned to the Property
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#contract_id Property#contract_id}
    */
    readonly contractId: string;
    /**
    * Group ID to be assigned to the Property
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#group_id Property#group_id}
    */
    readonly groupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#id Property#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name to give to the Property (must be unique)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#name Property#name}
    */
    readonly name: string;
    /**
    * Product ID to be assigned to the Property
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#product_id Property#product_id}
    */
    readonly productId: string;
    /**
    * Property ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#property_id Property#property_id}
    */
    readonly propertyId?: string;
    /**
    * Specify the rule format version (defaults to latest version available when created)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#rule_format Property#rule_format}
    */
    readonly ruleFormat?: string;
    /**
    * Property Rules as JSON
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#rules Property#rules}
    */
    readonly rules?: string;
    /**
    * Property version notes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#version_notes Property#version_notes}
    */
    readonly versionNotes?: string;
    /**
    * hostnames block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#hostnames Property#hostnames}
    */
    readonly hostnames?: PropertyHostnames[] | cdktf.IResolvable;
}
export interface PropertyRuleErrors {
}
export declare function propertyRuleErrorsToTerraform(struct?: PropertyRuleErrors): any;
export declare function propertyRuleErrorsToHclTerraform(struct?: PropertyRuleErrors): any;
export declare class PropertyRuleErrorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PropertyRuleErrors | undefined;
    set internalValue(value: PropertyRuleErrors | undefined);
    get behaviorName(): string;
    get detail(): string;
    get errorLocation(): string;
    get instance(): string;
    get statusCode(): number;
    get title(): string;
    get type(): string;
}
export declare class PropertyRuleErrorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PropertyRuleErrorsOutputReference;
}
export interface PropertyRuleWarnings {
}
export declare function propertyRuleWarningsToTerraform(struct?: PropertyRuleWarnings): any;
export declare function propertyRuleWarningsToHclTerraform(struct?: PropertyRuleWarnings): any;
export declare class PropertyRuleWarningsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PropertyRuleWarnings | undefined;
    set internalValue(value: PropertyRuleWarnings | undefined);
    get behaviorName(): string;
    get detail(): string;
    get errorLocation(): string;
    get instance(): string;
    get statusCode(): number;
    get title(): string;
    get type(): string;
}
export declare class PropertyRuleWarningsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PropertyRuleWarningsOutputReference;
}
export interface PropertyHostnamesCertStatus {
}
export declare function propertyHostnamesCertStatusToTerraform(struct?: PropertyHostnamesCertStatus | cdktf.IResolvable): any;
export declare function propertyHostnamesCertStatusToHclTerraform(struct?: PropertyHostnamesCertStatus | cdktf.IResolvable): any;
export declare class PropertyHostnamesCertStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PropertyHostnamesCertStatus | cdktf.IResolvable | undefined;
    set internalValue(value: PropertyHostnamesCertStatus | cdktf.IResolvable | undefined);
    get hostname(): string;
    get productionStatus(): string;
    get stagingStatus(): string;
    get target(): string;
}
export declare class PropertyHostnamesCertStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: PropertyHostnamesCertStatus[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PropertyHostnamesCertStatusOutputReference;
}
export interface PropertyHostnames {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#cert_provisioning_type Property#cert_provisioning_type}
    */
    readonly certProvisioningType: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#cname_from Property#cname_from}
    */
    readonly cnameFrom: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#cname_to Property#cname_to}
    */
    readonly cnameTo: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#cname_type Property#cname_type}
    */
    readonly cnameType?: string;
    /**
    * cert_status block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#cert_status Property#cert_status}
    */
    readonly certStatus?: PropertyHostnamesCertStatus[] | cdktf.IResolvable;
}
export declare function propertyHostnamesToTerraform(struct?: PropertyHostnames | cdktf.IResolvable): any;
export declare function propertyHostnamesToHclTerraform(struct?: PropertyHostnames | cdktf.IResolvable): any;
export declare class PropertyHostnamesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PropertyHostnames | cdktf.IResolvable | undefined;
    set internalValue(value: PropertyHostnames | cdktf.IResolvable | undefined);
    private _certProvisioningType?;
    get certProvisioningType(): string;
    set certProvisioningType(value: string);
    get certProvisioningTypeInput(): string | undefined;
    private _cnameFrom?;
    get cnameFrom(): string;
    set cnameFrom(value: string);
    get cnameFromInput(): string | undefined;
    private _cnameTo?;
    get cnameTo(): string;
    set cnameTo(value: string);
    get cnameToInput(): string | undefined;
    private _cnameType?;
    get cnameType(): string;
    set cnameType(value: string);
    resetCnameType(): void;
    get cnameTypeInput(): string | undefined;
    get edgeHostnameId(): string;
    private _certStatus;
    get certStatus(): PropertyHostnamesCertStatusList;
    putCertStatus(value: PropertyHostnamesCertStatus[] | cdktf.IResolvable): void;
    resetCertStatus(): void;
    get certStatusInput(): cdktf.IResolvable | PropertyHostnamesCertStatus[] | undefined;
}
export declare class PropertyHostnamesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: PropertyHostnames[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PropertyHostnamesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property akamai_property}
*/
export declare class Property extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_property";
    /**
    * Generates CDKTF code for importing a Property resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Property to import
    * @param importFromId The id of the existing Property that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Property to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/property akamai_property} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PropertyConfig
    */
    constructor(scope: Construct, id: string, config: PropertyConfig);
    private _contractId?;
    get contractId(): string;
    set contractId(value: string);
    get contractIdInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get latestVersion(): number;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _productId?;
    get productId(): string;
    set productId(value: string);
    get productIdInput(): string | undefined;
    get productionVersion(): number;
    private _propertyId?;
    get propertyId(): string;
    set propertyId(value: string);
    resetPropertyId(): void;
    get propertyIdInput(): string | undefined;
    get readVersion(): number;
    private _ruleErrors;
    get ruleErrors(): PropertyRuleErrorsList;
    private _ruleFormat?;
    get ruleFormat(): string;
    set ruleFormat(value: string);
    resetRuleFormat(): void;
    get ruleFormatInput(): string | undefined;
    private _ruleWarnings;
    get ruleWarnings(): PropertyRuleWarningsList;
    private _rules?;
    get rules(): string;
    set rules(value: string);
    resetRules(): void;
    get rulesInput(): string | undefined;
    get stagingVersion(): number;
    private _versionNotes?;
    get versionNotes(): string;
    set versionNotes(value: string);
    resetVersionNotes(): void;
    get versionNotesInput(): string | undefined;
    private _hostnames;
    get hostnames(): PropertyHostnamesList;
    putHostnames(value: PropertyHostnames[] | cdktf.IResolvable): void;
    resetHostnames(): void;
    get hostnamesInput(): cdktf.IResolvable | PropertyHostnames[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
