import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AkamaiProviderConfig {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#cache_enabled AkamaiProvider#cache_enabled}
    */
    readonly cacheEnabled?: boolean | cdktf.IResolvable;
    /**
    * The section of the edgerc file to use for configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#config_section AkamaiProvider#config_section}
    */
    readonly configSection?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#edgerc AkamaiProvider#edgerc}
    */
    readonly edgerc?: string;
    /**
    * The maximum number of API requests to be made per second (0 for no limit)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#request_limit AkamaiProvider#request_limit}
    */
    readonly requestLimit?: number;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#alias AkamaiProvider#alias}
    */
    readonly alias?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#config AkamaiProvider#config}
    */
    readonly config?: AkamaiProviderConfigA[] | cdktf.IResolvable;
}
export interface AkamaiProviderConfigA {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#access_token AkamaiProvider#access_token}
    */
    readonly accessToken: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#account_key AkamaiProvider#account_key}
    */
    readonly accountKey?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#client_secret AkamaiProvider#client_secret}
    */
    readonly clientSecret: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#client_token AkamaiProvider#client_token}
    */
    readonly clientToken: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#host AkamaiProvider#host}
    */
    readonly host: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#max_body AkamaiProvider#max_body}
    */
    readonly maxBody?: number;
}
export declare function akamaiProviderConfigAToTerraform(struct?: AkamaiProviderConfigA | cdktf.IResolvable): any;
export declare function akamaiProviderConfigAToHclTerraform(struct?: AkamaiProviderConfigA | cdktf.IResolvable): any;
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs akamai}
*/
export declare class AkamaiProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "akamai";
    /**
    * Generates CDKTF code for importing a AkamaiProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AkamaiProvider to import
    * @param importFromId The id of the existing AkamaiProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AkamaiProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs akamai} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AkamaiProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: AkamaiProviderConfig);
    private _cacheEnabled?;
    get cacheEnabled(): boolean | cdktf.IResolvable | undefined;
    set cacheEnabled(value: boolean | cdktf.IResolvable | undefined);
    resetCacheEnabled(): void;
    get cacheEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _configSection?;
    get configSection(): string | undefined;
    set configSection(value: string | undefined);
    resetConfigSection(): void;
    get configSectionInput(): string | undefined;
    private _edgerc?;
    get edgerc(): string | undefined;
    set edgerc(value: string | undefined);
    resetEdgerc(): void;
    get edgercInput(): string | undefined;
    private _requestLimit?;
    get requestLimit(): number | undefined;
    set requestLimit(value: number | undefined);
    resetRequestLimit(): void;
    get requestLimitInput(): number | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    private _config?;
    get config(): AkamaiProviderConfigA[] | cdktf.IResolvable | undefined;
    set config(value: AkamaiProviderConfigA[] | cdktf.IResolvable | undefined);
    resetConfig(): void;
    get configInput(): cdktf.IResolvable | AkamaiProviderConfigA[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
