import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppsecMalwarePolicyActionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Action to be taken for requests scanned according to the malware policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#action AppsecMalwarePolicyAction#action}
    */
    readonly action: string;
    /**
    * Unique identifier of the security configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#config_id AppsecMalwarePolicyAction#config_id}
    */
    readonly configId: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#id AppsecMalwarePolicyAction#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique identifier of the malware policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#malware_policy_id AppsecMalwarePolicyAction#malware_policy_id}
    */
    readonly malwarePolicyId: number;
    /**
    * Unique identifier of the security policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#security_policy_id AppsecMalwarePolicyAction#security_policy_id}
    */
    readonly securityPolicyId: string;
    /**
    * Action to be taken for requests not scanned according to the malware policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#unscanned_action AppsecMalwarePolicyAction#unscanned_action}
    */
    readonly unscannedAction: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action akamai_appsec_malware_policy_action}
*/
export declare class AppsecMalwarePolicyAction extends cdktf.TerraformResource {
    static readonly tfResourceType = "akamai_appsec_malware_policy_action";
    /**
    * Generates CDKTF code for importing a AppsecMalwarePolicyAction resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AppsecMalwarePolicyAction to import
    * @param importFromId The id of the existing AppsecMalwarePolicyAction that should be imported. Refer to the {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AppsecMalwarePolicyAction to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/akamai/akamai/5.6.0/docs/resources/appsec_malware_policy_action akamai_appsec_malware_policy_action} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AppsecMalwarePolicyActionConfig
    */
    constructor(scope: Construct, id: string, config: AppsecMalwarePolicyActionConfig);
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _configId?;
    get configId(): number;
    set configId(value: number);
    get configIdInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _malwarePolicyId?;
    get malwarePolicyId(): number;
    set malwarePolicyId(value: number);
    get malwarePolicyIdInput(): number | undefined;
    private _securityPolicyId?;
    get securityPolicyId(): string;
    set securityPolicyId(value: string);
    get securityPolicyIdInput(): string | undefined;
    private _unscannedAction?;
    get unscannedAction(): string;
    set unscannedAction(value: string);
    get unscannedActionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
